(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    306553,      12899]*)
(*NotebookOutlinePosition[    307701,      12934]*)
(*  CellTagsIndexPosition[    307657,      12930]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Average Lattice of the Penrose tiling with quasiperiodic \
grids\
\>", "Title",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Utils", "Section",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["Cuts the array lattice up to a radius r", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(SphericalCut[lattice_, r_] := 
      Select[lattice, # . # \[LessEqual] r\^2 &]\)], "Input",
  CellLabel->"In[47]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inserts a zero at z in array lts", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(To3D[lst_] := Insert[lst, 0, 3]\)], "Input",
  CellLabel->"In[48]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Draws the tiling of list PTS with bondlenght RAD ant tolerance \
T\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(tiling2D[pts_, rad_, t_:  Automatic] := 
      Module[{tol = t, bonds}, 
        dist[x_, y_] := \@\(\((x - y)\) . \((x - y)\)\); 
        drawbond[{p1_, p2_}] := 
          Line[{pts\[LeftDoubleBracket]p1\[RightDoubleBracket], 
              pts\[LeftDoubleBracket]p2\[RightDoubleBracket]}]; 
        If[t === Automatic, tol = 0.1]; 
        bonds = Select[
            Flatten[Table[
                If[Abs[dist[pts\[LeftDoubleBracket]i\[RightDoubleBracket], 
                          pts\[LeftDoubleBracket]j\[RightDoubleBracket]] - 
                        rad] < tol, {i, j}, {0, 0}], {i, 1, 
                  Length[pts] - 1}, {j, i + 1, Length[pts]}], 
              1], #1 \[NotEqual] {0, 0} &]; 
        Show[Graphics[drawbond /@ bonds], 
          AspectRatio \[Rule] Automatic]]\)], "Input",
  CellLabel->"In[49]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Draws the diffraction pattern: disks at position given by list PTS \
with radius given by INTS with a Gray Level of GRAY (white=1, black=0)\
\>", \
"Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(DrawPattern[pts_, \ ins_, \ gray_] := \ 
      Show[Graphics[
          Table[{GrayLevel[gray], 
              Disk[{pts[\([i, 1]\)], \ pts[\([i, 2]\)]}, ins[\([i]\)]]}, {i, 
              Length[ins]}]], AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[50]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Extracts k-vectors (PTS) which fulfills Brag's condition \
(Indeterminate in the list of intensities INTS)\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(ExtractBragg[lst_, \ ins_]\  := \ 
      Module[{pst = 
            Flatten[Position[ins, \ 
                Indeterminate]]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Return[
          Table[lst[\([pst[\([i]\)]]\)], {i, 
              Length[pst]}]]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\)], "Input",
  CellLabel->"In[51]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saves the list LST as a 3D .DAT file", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(SaveDat[lst_, \ fname_]\  := \ 
      Module[{}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
Put[Length[lst], \ 
          fname]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ LTC3D = 
          Map[To3D, 
            lst]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ tosave = 
          PaddedForm[
            TableForm[Chop[LTC3D, 0.00001], TableSpacing \[Rule] {0, 2}], {7, 
              6}]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ PutAppend[OutputForm[tosave], \ 
          fname]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ ]\)], "Input",
  CellLabel->"In[52]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Star vector", "Section",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[{
    \(\(e[1]\  = \ {1, 0};\)\), "\[IndentingNewLine]", 
    \(\(e[2]\  = \ {Cos[2\ \[Pi]/5], 
          Sin[2\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(e[3]\  = \ {Cos[4\ \[Pi]/5], 
          Sin[4\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(e[4]\  = \ {Cos[6\ \[Pi]/5], 
          Sin[6\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(e[5]\  = \ {Cos[8\ \[Pi]/5], 
          Sin[8\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(star\  = \ {e[1], \ e[2], \ e[3], \ e[4], \ e[5]};\)\)}], "Input",
  CellLabel->"In[62]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[star, Axes \[Rule] True, Prolog \[Rule] PointSize[0.05], 
      PlotRange\  \[Rule] \ {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[68]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 .4875 -6 -9 ]
[.08333 .4875 6 0 ]
[.29167 .4875 -12 -9 ]
[.29167 .4875 12 0 ]
[.70833 .4875 -9 -9 ]
[.70833 .4875 9 0 ]
[.91667 .4875 -3 -9 ]
[.91667 .4875 3 0 ]
[.4875 .08333 -12 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .29167 -24 -4.5 ]
[.4875 .29167 0 4.5 ]
[.4875 .70833 -18 -4.5 ]
[.4875 .70833 0 4.5 ]
[.4875 .91667 -6 -4.5 ]
[.4875 .91667 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 .5 m
.08333 .50625 L
s
[(-1)] .08333 .4875 0 1 Mshowa
.29167 .5 m
.29167 .50625 L
s
[(-0.5)] .29167 .4875 0 1 Mshowa
.70833 .5 m
.70833 .50625 L
s
[(0.5)] .70833 .4875 0 1 Mshowa
.91667 .5 m
.91667 .50625 L
s
[(1)] .91667 .4875 0 1 Mshowa
.125 Mabswid
.125 .5 m
.125 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.33333 .5 m
.33333 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.66667 .5 m
.66667 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.875 .5 m
.875 .50375 L
s
.04167 .5 m
.04167 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .08333 m
.50625 .08333 L
s
[(-1)] .4875 .08333 1 0 Mshowa
.5 .29167 m
.50625 .29167 L
s
[(-0.5)] .4875 .29167 1 0 Mshowa
.5 .70833 m
.50625 .70833 L
s
[(0.5)] .4875 .70833 1 0 Mshowa
.5 .91667 m
.50625 .91667 L
s
[(1)] .4875 .91667 1 0 Mshowa
.125 Mabswid
.5 .125 m
.50375 .125 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .33333 m
.50375 .33333 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .66667 m
.50375 .66667 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .875 m
.50375 .875 L
s
.5 .04167 m
.50375 .04167 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.91667 .5 Mdot
.62876 .89627 Mdot
.16291 .74491 Mdot
.16291 .25509 Mdot
.62876 .10373 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[68]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00OSgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo0026Ool5
0004Ool00`00Oomoo`2>Ool008Qoo`03001oogoo00Aoo`03001oogoo08ioo`00R7oo00<007ooOol0
17oo0`007goo1P00JGoo0020Ool40004Ool00`00Oomoo`04Ool00`00Oomoo`0NOol8001XOol008Qo
o`03001oogoo00Aoo`03001oogoo01eoo`X006Moo`00Qgoo0P001Woo00<007ooOol077oo3000IWoo
002?Ool00`00Oomoo`0KOol>001UOol008moo`03001oogoo01]oo`h006Eoo`00Sgoo00<007ooOol0
6goo3P00IGoo002?Ool00`00Oomoo`0KOol>001UOol008moo`03001oogoo01]oo`h006Eoo`00Sgoo
00<007ooOol06goo3P00IGoo002?Ool00`00Oomoo`0LOol<001VOol008moo`03001oogoo01eoo`X0
06Moo`00Sgoo0P007goo2000J7oo002?Ool00`00Oomoo`0OOol6001YOol008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00
Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo000/Ool6001MOol00`00
Oomoo`2>Ool002]oo`P005aoo`03001oogoo08ioo`00:Woo2P00Fgoo00<007ooOol0SWoo000YOol<
001JOol00`00Oomoo`2>Ool002Qoo`h005Uoo`03001oogoo08ioo`00:7oo3P00FGoo0P00Sgoo000X
Ool>001IOol00`00Oomoo`2>Ool002Qoo`h005Uoo`03001oogoo08ioo`00:7oo3P00FGoo00<007oo
Ool0SWoo000XOol>001IOol00`00Oomoo`2>Ool002Uoo``005Yoo`03001oogoo08ioo`00:Woo2P00
Fgoo00<007ooOol0SWoo000[Ool8001LOol00`00Oomoo`2>Ool002aoo`H005eoo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo001kOol20004Ool20004Ool20006Ool00`00Oomoo`2>Ool007Yoo`04
001oogoo0008Ool01000Oomoo`001Goo00<007ooOol0SWoo001jOol01000Oomoo`002goo00<007oo
Ool00goo0`00SWoo001dOol40002Ool01000Oomoo`002Goo0P001Woo00<007ooOol0SWoo001jOol0
1000Oomoo`002Goo00<007ooOol01Goo00<007ooOol0SWoo001kOol2000:Ool30005Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo
08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001o
ogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo000HOol5000bOol20004Ool20004Ool2000bOol2000cOol20004Ool20004
Ool2000cOol5000FOol001Yoo`03001oogoo035oo`04001oogoo0008Ool01000Oomoo`00<Goo00<0
07ooOol0<Goo00@007ooOol000Qoo`04001oogoo000dOol00`00Oomoo`0FOol001Yoo`03001oogoo
035oo`04001oogoo000;Ool00`00Oomoo`0_Ool00`00Oomoo`0aOol01000Oomoo`002goo00<007oo
Ool0<Woo00<007ooOol05Woo000BOol40004Ool00`00Oomoo`0[Ool40002Ool01000Oomoo`002Goo
0P00<Woo00<007ooOol0<Goo00@007ooOol000Uoo`8003Eoo`03001oogoo01Ioo`006Woo00<007oo
Ool0<Goo00@007ooOol000Uoo`03001oogoo035oo`03001oogoo035oo`04001oogoo0009Ool00`00
Oomoo`0dOol00`00Oomoo`0FOol001Uoo`8003Aoo`8000Yoo`<0035oo`03001oogoo039oo`8000Yo
o`<003=oo`8001Qoo`00Sgoo00<007ooOol0LWoo1P005Woo002?Ool00`00Oomoo`1aOol8000EOol0
08moo`03001oogoo071oo`X001Aoo`00Sgoo00<007ooOol0Kgoo30004goo002?Ool00`00Oomoo`1^
Ool>000BOol008moo`03001oogoo06ioo`h0019oo`00o`008@00000;Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`02Ool>0005
Ool00`00Oomoo`0:Ool001Moo`03001oogoo03Uoo`03001oogoo03Uoo`03001oogoo03Uoo`03001o
ogoo039oo`h0019oo`00Sgoo00<007ooOol0KWoo3P004Woo002?Ool00`00Oomoo`1_Ool<000COol0
08moo`03001oogoo071oo`X001Aoo`00Sgoo00<007ooOol0LGoo20005Goo002?Ool00`00Oomoo`1b
Ool6000FOol008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00
Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo001kOol2
0004Ool20004Ool20006Ool00`00Oomoo`2>Ool007Yoo`04001oogoo0008Ool01000Oomoo`001Goo
00<007ooOol0SWoo001jOol01000Oomoo`002goo00<007ooOol00goo0`00SWoo001jOol01000Oomo
o`002Goo0P001Woo00<007ooOol0SWoo001jOol01000Oomoo`002Goo00<007ooOol01Goo00<007oo
Ool0SWoo001kOol2000:Ool30005Ool00`00Oomoo`2>Ool002aoo`H005eoo`03001oogoo08ioo`00
:goo2000G7oo00<007ooOol0SWoo000ZOol:001KOol00`00Oomoo`2>Ool002Uoo``005Yoo`03001o
ogoo08ioo`00:7oo3P00FGoo00<007ooOol0SWoo000XOol>001IOol00`00Oomoo`2>Ool002Qoo`h0
05Uoo`03001oogoo08ioo`00:7oo3P00FGoo00<007ooOol0SWoo000XOol>001IOol2002?Ool002Qo
o`h005Uoo`03001oogoo08ioo`00:Goo3000FWoo00<007ooOol0SWoo000ZOol:001KOol00`00Oomo
o`2>Ool002]oo`P005aoo`03001oogoo08ioo`00;7oo1P00GGoo00<007ooOol0SWoo002?Ool00`00
Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol07goo1P00JGoo002?Ool2000OOol8001XOol008moo`03001oogoo01eoo`X006Moo`00Sgoo
00<007ooOol077oo3000IWoo002?Ool00`00Oomoo`0KOol>001UOol008moo`03001oogoo01]oo`h0
06Eoo`00Sgoo00<007ooOol06goo3P00IGoo002?Ool00`00Oomoo`0KOol>001UOol008moo`03001o
ogoo01]oo`h006Eoo`00Sgoo00<007ooOol06goo3P00IGoo002?Ool00`00Oomoo`0LOol<001VOol0
08Ioo`D000Aoo`03001oogoo01eoo`X006Moo`00R7oo00<007ooOol017oo00<007ooOol07Woo2000
J7oo0028Ool00`00Oomoo`04Ool3000OOol6001YOol008Qoo`03001oogoo00Aoo`03001oogoo08io
o`00R7oo00<007ooOol017oo00<007ooOol0SWoo0027Ool20006Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.20001, -1.20001, 0.00836245, \
0.00836245}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[BoxData[
    \(\(a = 
        FullSimplify[Table[Det[{e[m], e[n]}], {m, 5}, {n, 5}]];\)\)], "Input",\

  CellLabel->"In[69]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[%]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\
\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \
\((5 + \@5)\)\)\)},
            {\(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \@5)\)\)\), 
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\
\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\)},
            {\(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\), \(\(-\(1\/2\)\)\ \
\@\(1\/2\ \((5 + \@5)\)\)\), 
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\
\)},
            {\(\@\(5\/8 - \@5\/8\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \
\@5)\)\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \@5)\)\)\), 
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\)},
            {\(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\), \(\
\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \
\@5)\)\)\), "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[61]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The quasiperiodic tiling", "Subtitle",
  Background->RGBColor[1, 0, 1]],

Cell[CellGroupData[{

Cell["Formulae for the quasilattice.", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(In\ my\ \(notes : \ 
          e\_k\%\[VerticalSeparator]\) = \ \((e\_k\%y, \ \(-e\_k\%x\))\), 
    e\_j\%\(\('\)\(\[VerticalSeparator]\)\) = \ \(\((\(-e\_j\%y\), \ 
              e\_j\%x)\) . \ 
            In\ the\ paper\ the\ notation\ was\ changed\ to\ b\_jl = \ \(e\_k\
\%\[VerticalSeparator] . 
            e\_l = \(epk[k] . 
                e[l]\ and\ b\_kl = \ \
\(e\_j\%\(\('\)\(\[VerticalSeparator]\)\) . e\_l = 
              epj[j] . e[l]\)\)\)\)\)], "DisplayFormula",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
    \(epk[
        k_] := {\(e[
            k]\)[\([2]\)], \(-\(e[k]\)[\([1]\)]\)}\), "\[IndentingNewLine]", 
    \(epj[j_] := {\(-\(e[j]\)[\([2]\)]\), \(e[j]\)[\([1]\)]}\)}], "Input",
  CellLabel->"In[70]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation (5) Acta. Cryst.:", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(Xns[m_, s_]\  := \ 
      m\  + \ \ \[Alpha][\([s]\)]\  + \ 
        1\/\[Rho][\([s]\)]\ Floor[
            m\ \[Sigma][\([s]\)]\  + \ \[Beta][\([s]\)]]\)], "Input",
  CellLabel->"In[72]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gerardo's correction", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(Frac[x_]\  := \ x\  - \ Floor[x]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(U[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_] := \ \ \((Xns[m, 
              j]\ epk[k] . e[l]\/a[\([j, k]\)]\  + \ 
          Xns[n, k]\ epj[j] . e[l]\/a[\([j, k]\)]\  - \ \[Alpha][\([l]\)]\  - \
\ \[Beta][\([l]\)]\/\[Rho][\([l]\)])\)\)], "Input",
  CellLabel->"In[73]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gerardo's new formulae", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(T[l_, \ \[Rho]_, \ \[Sigma]_]\  := \ \(\(1\/\[Sigma][\([l]\)]\)\(\ \
\)\(+\)\(\ \)\(1\/\[Rho][\([l]\)]\)\(\ \)\)\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[{
    \(S[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_]\  := \ 
      Floor[Floor[
            U[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]]\/T[l, \
\[Rho], \[Sigma]]]\ 1\/\[Sigma][\([l]\)]]\), "\[IndentingNewLine]", 
    \(\(\(SD[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_]\)\(\ \
\)\(:=\)\(Floor[
        U[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]]\/T[l, \[Rho], \
\[Sigma]]]\)\(\ \)\)\)}], "Input",
  CellLabel->"In[75]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Coeficients of e[l] for several cases: Coef1 \[Rule] \[Rho] + \
\[Sigma] > 1; Coef2  and Coef3 are the two cases of \[Rho] + \[Sigma] < \
1\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(Coef1[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_]\  := \ 
      Floor[U[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]]\  + \ 
            1\/\(\[Rho][\([l]\)] + \[Sigma][\([l]\)]\)\ \ Frac[\((Floor[
                          U[j, k, l, m, 
                            n, \[Rho], \[Sigma], \[Beta], \[Alpha]]]\  + 
                        1)\)\ \[Sigma][\([l]\)]\  + \ \[Beta][\([l]\)]]]\  + \
\ 1\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(\(\(Coef2[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_]\)\(\ \
\)\(:=\)\(If[
        SD[j, \ k, \ l, \ m, \ 
            n, \ \[Rho], \ \[Sigma], \ \[Beta], \ \[Alpha]]\  == \(-1\), \(-1\
\), \ Floor[\((SD[j, \ k, \ l, \ m, \ 
                  n, \ \[Rho], \ \[Sigma], \ \[Beta], \ \[Alpha]]\  + \ 
                1)\)\ 1\/\[Sigma][\([l]\)]]]\)\(\ \)\)\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(Coef3[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_]\  := 
      If[SD[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]] == 0, 
        Floor[U[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]]], \ 
        Floor[U[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]]\  - \ 
            1\/\[Rho][\([l]\)]\ \((Floor[
                    S[j, k, l, m, 
                        n, \[Rho], \[Sigma], \[Beta], \[Alpha]]\ \
\[Sigma][\([l]\)]]\  + \ 1)\)]\ ]\)], "Input",
  CellLabel->"In[79]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
rmass = \[Rho] + \[Sigma]  (calculated below)\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(L[j_, \ k_, \ m_, \ 
        n_, \ \[Rho]_, \ \[Sigma]_, \ \[Beta]_, \ \[Alpha]_, \ rmass_]\  := \ 
      If[rmass\  > \ 1, 
        m\ e[j]\  + \ 
          n\ e[k]\  + \ \[Sum]\+\(l = 1\)\%5 If[\((l != j)\) && \((l != k)\), 
              Coef1[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]]*e[l], 
              0], \[IndentingNewLine]m\ e[j]\  + \ 
          n\ e[k]\  + \ \[Sum]\+\(l = 1\)\%5 If[\((l != j)\) && \((l != k)\), 
              If[Frac[U[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \
\[Alpha]]\/T[l, \[Rho], \[Sigma]]]\ T[l, \[Rho], \[Sigma]]\  > \ 
                    1\/\[Sigma][\([l]\)], 
                  Coef2[j, k, l, m, n, \[Rho], \[Sigma], \[Beta], \[Alpha]] + 
                    1, \ Coef3[j, k, l, m, 
                      n, \[Rho], \[Sigma], \[Beta], \[Alpha]] + 1]*e[l], 
              0]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[80]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters:", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[{
    \(\(\[Alpha]\  = \ {\(-0.100000\), 0.30000, \(-0.30000\), 0.20000, 
          0.0000};\)\), "\[IndentingNewLine]", 
    \(\(\[Beta]\  = \ {0.0, 0.0, \ 0.0, \ 0.0, \ 
          0.0};\)\), "\[IndentingNewLine]", 
    \(\(\[Sigma]\  = \ {3\^\(-\(3\/2\)\), 3\^\(-\(3\/2\)\), 3\^\(-\(3\/2\)\), 
          3\^\(-\(3\/2\)\), 3\^\(-\(3\/2\)\)};\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\  = \ {2\^\(-\(5\/2\)\), 2\^\(-\(5\/2\)\), 2\^\(-\(5\/2\)\), 
          2\^\(-\(5\/2\)\), 2\^\(-\(5\/2\)\)};\)\), "\[IndentingNewLine]", 
    \(\(Nmin\  = \ \(-5\);\)\), "\[IndentingNewLine]", 
    \(\(Nmax\  = \ 5;\)\), "\[IndentingNewLine]", 
    \(\(rmass\  = \ 
        Max[Table[\[Rho][\([i]\)] + \[Sigma][\([i]\)], \ {i, 
              5}]];\)\)}], "Input",
  CellLabel->"In[81]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lattices\ of\ t\^0\)], "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
    \(\(QL021 = \ 
        Flatten[Table[
            L[2, 1, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL031 = \ 
        Flatten[Table[
            L[3, 1, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL032 = \ 
        Flatten[Table[
            L[3, 2, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL041 = \ 
        Flatten[Table[
            L[4, 1, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL042 = \ 
        Flatten[Table[
            L[4, 2, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL043 = \ 
        Flatten[Table[
            L[4, 3, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL051 = \ 
        Flatten[Table[
            L[5, 1, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL052 = \ 
        Flatten[Table[
            L[5, 2, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL053 = \ 
        Flatten[Table[
            L[5, 3, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL054 = \ 
        Flatten[Table[
            L[5, 4, m, \ n, \ \[Rho], \[Sigma], \[Beta], \[Alpha], 
              rmass], {m, Nmin, Nmax}, {n, Nmin, Nmax}], 1];\)\)}], "Input",
  CellLabel->"In[98]:="]
}, Open  ]],

Cell[BoxData[
    \(\(\(QL0 = 
        Union[QL021, QL031, QL032, QL041, QL042, QL043, \ QL051, \ QL052, 
          QL053, QL054];\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\)\)],\
 "Input",
  CellLabel->"In[108]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = 
      ListPlot[SphericalCut[N[QL0], 10], Axes \[Rule] True, 
        Prolog \[Rule] AbsolutePointSize[10.5], 
        AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[109]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.02828 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.510498 0.0491645 0.514141 0.0491645 [
[.01885 .50164 -9 -9 ]
[.01885 .50164 9 0 ]
[.26468 .50164 -6 -9 ]
[.26468 .50164 6 0 ]
[.75632 .50164 -3 -9 ]
[.75632 .50164 3 0 ]
[.498 .0225 -18 -4.5 ]
[.498 .0225 0 4.5 ]
[.498 .26832 -12 -4.5 ]
[.498 .26832 0 4.5 ]
[.498 .75996 -6 -4.5 ]
[.498 .75996 0 4.5 ]
[.498 1.00579 -12 -4.5 ]
[.498 1.00579 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.02828 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01885 .51414 m
.01885 .52039 L
s
[(-10)] .01885 .50164 0 1 Mshowa
.26468 .51414 m
.26468 .52039 L
s
[(-5)] .26468 .50164 0 1 Mshowa
.75632 .51414 m
.75632 .52039 L
s
[(5)] .75632 .50164 0 1 Mshowa
.125 Mabswid
.06802 .51414 m
.06802 .51789 L
s
.11718 .51414 m
.11718 .51789 L
s
.16635 .51414 m
.16635 .51789 L
s
.21551 .51414 m
.21551 .51789 L
s
.31384 .51414 m
.31384 .51789 L
s
.363 .51414 m
.363 .51789 L
s
.41217 .51414 m
.41217 .51789 L
s
.46133 .51414 m
.46133 .51789 L
s
.55966 .51414 m
.55966 .51789 L
s
.60883 .51414 m
.60883 .51789 L
s
.65799 .51414 m
.65799 .51789 L
s
.70716 .51414 m
.70716 .51789 L
s
.80548 .51414 m
.80548 .51789 L
s
.85465 .51414 m
.85465 .51789 L
s
.90381 .51414 m
.90381 .51789 L
s
.95298 .51414 m
.95298 .51789 L
s
.25 Mabswid
0 .51414 m
1 .51414 L
s
.5105 .0225 m
.51675 .0225 L
s
[(-10)] .498 .0225 1 0 Mshowa
.5105 .26832 m
.51675 .26832 L
s
[(-5)] .498 .26832 1 0 Mshowa
.5105 .75996 m
.51675 .75996 L
s
[(5)] .498 .75996 1 0 Mshowa
.5105 1.00579 m
.51675 1.00579 L
s
[(10)] .498 1.00579 1 0 Mshowa
.125 Mabswid
.5105 .07166 m
.51425 .07166 L
s
.5105 .12083 m
.51425 .12083 L
s
.5105 .16999 m
.51425 .16999 L
s
.5105 .21915 m
.51425 .21915 L
s
.5105 .31748 m
.51425 .31748 L
s
.5105 .36665 m
.51425 .36665 L
s
.5105 .41581 m
.51425 .41581 L
s
.5105 .46498 m
.51425 .46498 L
s
.5105 .56331 m
.51425 .56331 L
s
.5105 .61247 m
.51425 .61247 L
s
.5105 .66163 m
.51425 .66163 L
s
.5105 .7108 m
.51425 .7108 L
s
.5105 .80913 m
.51425 .80913 L
s
.5105 .85829 m
.51425 .85829 L
s
.5105 .90746 m
.51425 .90746 L
s
.5105 .95662 m
.51425 .95662 L
s
.25 Mabswid
.5105 0 m
.5105 1.02828 L
s
0 0 m
1 0 L
1 1.02828 L
0 1.02828 L
closepath
clip
newpath
10.5 Mabswid
.41217 .21152 Mdot
.41217 .81677 Mdot
.1923 .51414 Mdot
.47072 .54304 Mdot
.43095 .51414 Mdot
.43095 .57194 Mdot
.39117 .54304 Mdot
.3514 .51414 Mdot
.3514 .57194 Mdot
.31162 .48524 Mdot
.31162 .54304 Mdot
.27185 .51414 Mdot
.23207 .60084 Mdot
.1923 .45634 Mdot
.1923 .57194 Mdot
.15252 .60084 Mdot
.11275 .51414 Mdot
.6696 .32711 Mdot
.71876 .32711 Mdot
.71876 .70117 Mdot
.76793 .32711 Mdot
.76793 .70117 Mdot
.81709 .32711 Mdot
.81709 .70117 Mdot
.86626 .51414 Mdot
.86626 .42062 Mdot
.86626 .60766 Mdot
.86626 .32711 Mdot
.51989 .54304 Mdot
.58066 .29821 Mdot
.62982 .29821 Mdot
.62982 .73007 Mdot
.67899 .73007 Mdot
.27185 .57194 Mdot
.49172 .26931 Mdot
.54088 .26931 Mdot
.54088 .75897 Mdot
.59005 .75897 Mdot
.23207 .48524 Mdot
.23207 .54304 Mdot
.45194 .24041 Mdot
.45194 .78787 Mdot
.50111 .78787 Mdot
.15252 .54304 Mdot
.15252 .48524 Mdot
.37239 .18262 Mdot
.37239 .84566 Mdot
.06358 .57194 Mdot
.11275 .45634 Mdot
.33262 .15372 Mdot
.02381 .48524 Mdot
.02381 .54304 Mdot
.31743 .92132 Mdot
.27765 .13586 Mdot
.27765 .89242 Mdot
.22268 .118 Mdot
.57486 .46738 Mdot
.57486 .5609 Mdot
.62402 .46738 Mdot
.62402 .5609 Mdot
.67318 .46738 Mdot
.67318 .5609 Mdot
.36659 .40959 Mdot
.36659 .6187 Mdot
.48592 .43848 Mdot
.48592 .49628 Mdot
.48592 .5898 Mdot
.53508 .5898 Mdot
.32682 .64759 Mdot
.44614 .46738 Mdot
.44614 .6187 Mdot
.28704 .40959 Mdot
.40637 .43848 Mdot
.40637 .64759 Mdot
.32682 .43848 Mdot
.28704 .67649 Mdot
.07878 .40959 Mdot
.07878 .6187 Mdot
.24727 .38069 Mdot
.24727 .64759 Mdot
.20749 .40959 Mdot
.20749 .67649 Mdot
.16772 .38069 Mdot
.16772 .64759 Mdot
.59005 .42062 Mdot
.63921 .42062 Mdot
.63921 .60766 Mdot
.68838 .51414 Mdot
.68838 .42062 Mdot
.68838 .60766 Mdot
.73754 .51414 Mdot
.73754 .42062 Mdot
.73754 .60766 Mdot
.38178 .36283 Mdot
.38178 .72325 Mdot
.50111 .39173 Mdot
.55027 .39173 Mdot
.55027 .63656 Mdot
.34201 .33393 Mdot
.46133 .36283 Mdot
.46133 .66545 Mdot
.42156 .33393 Mdot
.42156 .69435 Mdot
.34201 .75215 Mdot
.30223 .30503 Mdot
.30223 .72325 Mdot
.09397 .36283 Mdot
.26246 .33393 Mdot
.26246 .75215 Mdot
.22268 .30503 Mdot
.22268 .72325 Mdot
.13374 .69435 Mdot
.18291 .33393 Mdot
.07878 .31607 Mdot
.11855 .74111 Mdot
.6544 .37387 Mdot
.6544 .65442 Mdot
.70357 .37387 Mdot
.70357 .65442 Mdot
.75273 .37387 Mdot
.75273 .46738 Mdot
.75273 .5609 Mdot
.75273 .65442 Mdot
.8019 .37387 Mdot
.8019 .46738 Mdot
.8019 .5609 Mdot
.8019 .65442 Mdot
.85106 .37387 Mdot
.85106 .46738 Mdot
.85106 .5609 Mdot
.85106 .65442 Mdot
.39698 .25827 Mdot
.39698 .77001 Mdot
.56547 .34497 Mdot
.56547 .68331 Mdot
.61463 .68331 Mdot
.47653 .31607 Mdot
.47653 .71221 Mdot
.52569 .71221 Mdot
.43675 .28717 Mdot
.43675 .74111 Mdot
.3572 .22938 Mdot
.3572 .79891 Mdot
.31743 .25827 Mdot
.31743 .8278 Mdot
.27765 .22938 Mdot
.27765 .79891 Mdot
.09397 .26931 Mdot
.17352 .81677 Mdot
.22268 .21152 Mdot
.22268 .81677 Mdot
.13374 .24041 Mdot
.13374 .78787 Mdot
.18291 .24041 Mdot
.73395 .28035 Mdot
.78312 .28035 Mdot
.78312 .74793 Mdot
.83228 .28035 Mdot
.83228 .74793 Mdot
.42736 .16476 Mdot
.42736 .86352 Mdot
.64502 .25145 Mdot
.69418 .77683 Mdot
.55608 .22255 Mdot
.60524 .80573 Mdot
.46714 .19366 Mdot
.5163 .83463 Mdot
.38759 .13586 Mdot
.38759 .89242 Mdot
.33262 .0602 Mdot
.33262 .96808 Mdot
.74915 .23359 Mdot
.79831 .23359 Mdot
.79831 .79469 Mdot
.44255 .91028 Mdot
.66021 .20469 Mdot
.70937 .20469 Mdot
.70937 .82359 Mdot
.57127 .1758 Mdot
.62043 .1758 Mdot
.62043 .85249 Mdot
.6696 .85249 Mdot
.48233 .1469 Mdot
.53149 .1469 Mdot
.53149 .88138 Mdot
.58066 .88138 Mdot
.42736 .07124 Mdot
.47653 .07124 Mdot
.47653 .95704 Mdot
.52569 .95704 Mdot
.6544 .12904 Mdot
.56547 .10014 Mdot
.61463 .92814 Mdot
.38759 .04234 Mdot
.38759 .98594 Mdot
.5105 .02448 Mdot
.5105 1.0038 Mdot
.59944 .05338 Mdot
.90603 .73007 Mdot
.92122 .34497 Mdot
.92122 .68331 Mdot
.92122 .25145 Mdot
.92122 .43848 Mdot
.92122 .49628 Mdot
.92122 .5898 Mdot
.92122 .77683 Mdot
.88725 .20469 Mdot
.88725 .82359 Mdot
.79831 .1758 Mdot
.79831 .85249 Mdot
.75854 .88138 Mdot
.6696 .91028 Mdot
.56547 .98594 Mdot
.74334 .10014 Mdot
.6544 .07124 Mdot
.6544 .95704 Mdot
.97619 .36283 Mdot
.97619 .66545 Mdot
.961 .46738 Mdot
.97619 .57194 Mdot
.79831 .91028 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[109]:=",
  ImageSize->{288, 296.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001:1000`40O003h00Oogoo8Goo003oOolQ
Ool009Aoo`03001oogoo08Uoo`00U7oo00<007ooOol0RGoo002DOol00`00Oomoo`29Ool0099oo`@0
08Yoo`00T7oo2000R7oo0025Ool50002Ool20002Ool80028Ool008Moo`05001oogooOol00002Ool;
0027Ool008Moo`05001oogooOol00002Ool;0027Ool006moo`@000aoo`@000Aoo`05001oogooOol0
0002Ool;0027Ool006eoo`P0019oo`05001oogooOol00002Ool;0027Ool006eoo`P0015oo`8000Ao
o`80009oo`P008Qoo`00K7oo2P006Woo20004goo1000LGoo001/Ool:000LOol4000COol8001_Ool0
061oo`@000Qoo`X001ioo`03001oogoo019oo`P006moo`00GWoo20001Woo2P007Woo00<007ooOol0
4Goo2P00KWoo001NOol80007Ool8000OOol00`00Oomoo`0AOol:001^Ool005eoo`X000Ioo`P000Eo
o`@000Yoo`@000Qoo`03001oogoo015oo`X000Uoo`@0065oo`00GGoo2P0027oo10001Goo20001Woo
20001Woo00<007ooOol04Goo2P001goo2000Ggoo001MOol:000AOol80006Ool80006Ool00`00Oomo
o`0BOol80008Ool8001OOol005eoo`X0011oo`X000Aoo`X000Eoo`03001oogoo019oo`P000Moo`X0
05ioo`00GWoo20004Goo2P0017oo2P001Goo00<007ooOol057oo10002Goo2P00GWoo001NOol8000A
Ool:0004Ool:0005Ool2000ROol:001NOol0061oo`@001=oo`X000Aoo`X000Eoo`03001oogoo025o
o`X005ioo`00N7oo20001Woo20001Woo00<007ooOol08Woo2000Ggoo001hOol80006Ool80006Ool0
0`00Oomoo`0;Ool4000COol8000COol40018Ool007Yoo`@000Yoo`@000Qoo`03001oogoo00Uoo`P0
01=oo`@001=oo`P004Ioo`00U7oo00<007ooOol02Goo2000:Woo2000AWoo002DOol00`00Oomoo`08
Ool:000XOol:0015Ool009Aoo`03001oogoo00Qoo`X002Qoo`X004Eoo`00@Goo1000Cgoo00<007oo
Ool027oo2P00:7oo2P00AGoo000oOol8001=Ool00`00Oomoo`08Ool:000XOol:0015Ool003moo`P0
04eoo`03001oogoo00Uoo`P002Yoo`P004Ioo`00?Woo2P00C7oo00<007ooOol02Goo2000:Woo2000
AWoo000nOol:001<Ool00`00Oomoo`0;Ool4000EOol4000EOol40018Ool003ioo`X004aoo`8002=o
o`P005moo`00?Woo2P0027oo10006goo10008Goo00<007ooOol08Woo2000Ggoo000oOol80007Ool8
000GOol8000OOol00`00Oomoo`0QOol:001NOol003moo`P000Moo`P001Moo`P001moo`03001oogoo
025oo`X005ioo`00@Goo100027oo2P005Goo2P0057oo10001Woo00@007ooOomoo`@001aoo`X005io
o`00CGoo2P005Goo2P004Woo200017oo00<007oo00001`006Woo2P00GWoo001=Ool:0009Ool40008
Ool:000BOol80004Ool00`00Ool00007000KOol8001OOol004eoo`X000Moo`P000Ioo`X0015oo`X0
00=oo`/001Yoo`P005moo`00CWoo200027oo20001goo20004Woo2P000goo2`0077oo1000HGoo001>
Ool80007Ool:0006Ool80005Ool40009Ool:0003Ool;0021Ool0051oo`@000Uoo`X000Qoo`@000Eo
o`P000Moo`X000=oo`/0085oo`00GGoo2P004Goo200027oo200017oo00<007oo00001`00PWoo001M
Ool:000@Ool:0007Ool80004Ool00`00Ool000070005Ool4000:Ool4000_Ool4000hOol005ioo`P0
015oo`X000Uoo`@000Ioo`04001oogooOol40005Ool80006Ool8000[Ool8000fOol005ioo`P000Eo
o`@000Qoo`X001=oo`8000]oo`P000Ioo`P002]oo`P003Ioo`00H7oo10001Goo20001Woo2P004goo
00<007ooOol02Goo2P0017oo2P00:Goo2P00=Goo001YOol80007Ool8000DOol00`00Oomoo`09Ool:
0004Ool:000YOol:000eOol006Qoo`X000Ioo`P000Ioo`@000Yoo`03001oogoo00Uoo`X000Aoo`X0
02Uoo`X003Eoo`00J7oo2P0027oo10001Woo200027oo00<007ooOol02Goo2P0017oo2P00:Goo2P00
=Goo001XOol:000BOol80008Ool00`00Oomoo`0:Ool80006Ool8000[Ool8000fOol006Qoo`X0015o
o`X000Moo`03001oogoo00Yoo`P000Ioo`P000Eoo`@000Yoo`@001Aoo`P001=oo`@001moo`00JGoo
20004Woo2P001goo00<007ooOol037oo10002Woo10001Goo20001Woo200057oo10004goo20007Goo
0011Ool4000TOol80005Ool40009Ool:0007Ool00`00Oomoo`0SOol80006Ool8000[Ool8000MOol0
03moo`P002Aoo`@000Eoo`P000Moo`X000Moo`03001oogoo029oo`X000Aoo`X002Uoo`X001aoo`00
?goo2000;Goo200027oo200027oo00<007ooOol08Woo2P0017oo2P00:Goo2P0077oo000nOol:000[
Ool:0007Ool80008Ool00`00Oomoo`08Ool4000FOol:0004Ool:000YOol:000LOol003ioo`X002]o
o`X000Uoo`@000Yoo`03001oogoo00Ioo`P001Aoo`X000Aoo`X002Uoo`X001aoo`00?Woo2P0027oo
10004goo100027oo2P005goo00<007ooOol01Woo20005Goo20001Woo2000:goo20007Goo000nOol:
0006Ool8000?Ool80006Ool:000GOol20006Ool:000DOol80006Ool80006Ool4000:Ool4000COol8
000MOol003moo`P000Moo`P000moo`P000Moo`P001Qoo`03001oogoo00Eoo`X001Ioo`@000Yoo`@0
00Ioo`P000Ioo`P001=oo`@001moo`009goo10002Woo10001Woo20001Woo2P003Goo2P001Woo2000
1Goo10003goo00<007ooOol01Goo2P00;Woo20001Woo2000=Woo000UOol80006Ool80006Ool40008
Ool:000=Ool:0008Ool40005Ool8000=Ool00`00Oomoo`05Ool:000]Ool:0004Ool:000eOol002Eo
o`P000Ioo`P0019oo`X000eoo`X0015oo`P000eoo`03001oogoo00Ioo`P002ioo`X000Aoo`X003Eo
o`0097oo2P0017oo2P004Goo2P003Goo2P0047oo2P0037oo00<007ooOol01Woo20004goo10005goo
2P0017oo2P006goo10005Woo000TOol:0004Ool:000BOol8000?Ool8000AOol:000<Ool00`00Oomo
o`08Ool4000COol8000EOol:0004Ool:000IOol8000DOol002Aoo`X000Aoo`X0019oo`P000Eoo`@0
00Ioo`P000Eoo`@000Qoo`X000aoo`03001oogoo01moo`P001Ioo`P000Ioo`P001Yoo`P001Aoo`00
97oo2P0017oo2P0057oo10001Goo20001Woo10001Goo20001Woo2P0037oo00<007ooOol07Woo2P00
5Goo20001Woo20006Goo2P004goo000UOol80006Ool8000NOol8000?Ool80007Ool8000=Ool00`00
Oomoo`0NOol:000GOol4000:Ool4000KOol:000COol001aoo`@000Eoo`P000Ioo`P001eoo`X000eo
o`X000Ioo`P000Ioo`@000=oo`03001oogoo00Aoo`@001Ioo`X004Aoo`X001=oo`006Woo20001Goo
10002Woo10007goo2P003Goo2P0027oo10001Woo200000=oo`00Ool00goo200057oo2P00A7oo2P00
4goo000JOol8000fOol:000=Ool:000BOol800000goo001oo`03Ool8000EOol80016Ool8000DOol0
01Uoo`X003Eoo`X000eoo`X0015oo`/000=oo`X001Aoo`P001=oo`@000Yoo`@000Yoo`@001=oo`P0
01Aoo`006Goo2P00=Woo20003goo20004Woo3@0000=oo`00000020005Woo10004goo20001Woo2000
1Woo20004goo10005Woo000IOol:000fOol8000?Ool80005Ool40004Ool400000goo000000090003
Ool:000]Ool80006Ool80006Ool8000]Ool001Uoo`X003Qoo`@001=oo`@000Eoo`P000Moo`/000=o
o`X002aoo`X000Aoo`X000Aoo`X002aoo`006Woo2000FGoo200027oo200000=oo`00Ool00goo2000
;Goo2P0017oo2P0017oo2P00;7oo000JOol8001HOol:0007Ool800000goo001oo`03Ool8000]Ool:
0004Ool:0004Ool:000/Ool001aoo`@005Yoo`X000Uoo`@000=oo`03001oogoo00Aoo`@000Moo`@0
00Yoo`@001Ioo`X000Aoo`X000Aoo`X002aoo`00@Goo10004Woo10007goo2P0047oo00<007ooOol0
3Goo20001Woo20005Goo20001Woo20001Woo2000;Goo000oOol8000>Ool8000MOol:000@Ool00`00
Oomoo`0=Ool80006Ool8000EOol80006Ool80006Ool8000]Ool003moo`P000ioo`P001ioo`P0015o
o`03001oogoo00aoo`X000Aoo`X001Ioo`@000Yoo`@000Yoo`@002moo`00?Woo2P0037oo2P007Goo
20004Goo00<007ooOol037oo2P0017oo2P00IGoo000HOol4000ROol:000<Ool:000OOol40007Ool4
0008Ool00`00Oomoo`0<Ool:0004Ool:001UOol001Ioo`P0021oo`X000aoo`X002Qoo`P000Ioo`03
001oogoo00aoo`X000Aoo`X006Eoo`005Woo200087oo2P0037oo2P00:7oo20001Woo00<007ooOol0
3Goo20001Woo2000IWoo000EOol:000POol8000>Ool8000XOol:0005Ool00`00Oomoo`0=Ool80006
Ool80005Ool4000:Ool4000:Ool4000:Ool4000:Ool4000UOol001Eoo`X0021oo`P000ioo`P002Qo
o`X000Eoo`80011oo`@000Yoo`@000Eoo`P000Ioo`P000Ioo`P000Ioo`P000Ioo`P002=oo`005Goo
2P005Woo100027oo10001goo10001goo10001goo10004goo100027oo2P001Goo00<007ooOol09Woo
20001Woo20001Woo20001Woo20001Woo20008goo000EOol:000DOol8000?Ool8000>Ool8000?Ool8
0006Ool:0005Ool00`00Oomoo`0UOol:0004Ool:0004Ool:0004Ool:0004Ool:000ROol001Ioo`P0
01Eoo`P000moo`P000ioo`P000moo`P000Moo`P000Ioo`03001oogoo02Eoo`X000Aoo`X000Aoo`X0
00Aoo`X000Aoo`X0029oo`005Woo200057oo2P003Goo2P0037oo2P003Goo2P001Woo20001Woo00<0
07ooOol02goo10005Woo2P0017oo2P0017oo2P0017oo2P0017oo2P0027oo10005Woo000HOol4000F
Ool:000=Ool:000<Ool:000=Ool:0008Ool40008Ool00`00Oomoo`09Ool8000DOol:0004Ool:0004
Ool:0004Ool:0004Ool:0006Ool8000DOol0039oo`X000eoo`X000aoo`X000eoo`X001Aoo`03001o
ogoo00Uoo`P001Eoo`P000Ioo`P000Ioo`P000Ioo`P000Ioo`P000Moo`P001Aoo`00<Woo2P003Goo
2P0037oo2P003Goo2P0057oo00<007ooOol027oo2P0057oo20001Woo20001Woo20001Woo20001Woo
20001Woo2P004goo000cOol8000?Ool8000>Ool8000?Ool8000EOol00`00Oomoo`08Ool:000FOol4
000:Ool4000:Ool4000:Ool4000:Ool40008Ool:000COol001aoo`@001=oo`P000moo`P000ioo`P0
00Ioo`@000Eoo`P000Eoo`@000aoo`03001oogoo00Qoo`X005Yoo`X000Uoo`@000Ioo`006Woo2000
4goo10004goo10004Woo10001Woo20001Goo10001Goo20002Woo00<007ooOol027oo2P00FWoo2P00
1goo200017oo000JOol8001:Ool8000>Ool8000:Ool00`00Oomoo`09Ool8001LOol80008Ool80004
Ool001Uoo`X004Qoo`X000aoo`X000Uoo`03001oogoo00Uoo`P001=oo`@000Yoo`@000Yoo`@000Yo
o`@000Yoo`@000eoo`P000Moo`X000=oo`006Goo2P00B7oo2P0037oo2P002Goo00<007ooOol02goo
10004goo20001Woo20001Woo20001Woo20001Woo20003Goo10002Goo2P000goo000IOol:000>Ool4
000BOol4000POol:000<Ool:0009Ool2000SOol80006Ool80006Ool80006Ool80006Ool8000JOol:
0003Ool001Uoo`X000aoo`P000ioo`P001ioo`X000aoo`X000Uoo`03001oogoo025oo`X000Aoo`X0
00Aoo`X000Aoo`X000Aoo`X001Uoo`X000=oo`006Woo20003Goo20003Woo20007goo20003Woo2000
2Woo00<007ooOol08Goo2P0017oo2P0017oo2P0017oo2P0017oo2P006Woo200017oo000JOol8000<
Ool:000<Ool:000NOol8000>Ool80005Ool400000goo001oo`07Ool4000GOol:0004Ool:0004Ool:
0004Ool:0004Ool:000JOol80004Ool001aoo`@000ioo`X000aoo`X0021oo`@0019oo`@000Eoo`P0
00Ioo`P001Eoo`X000Aoo`X000Aoo`X000Aoo`X000Aoo`X001aoo`@000Ioo`00;Woo2P0037oo2P00
?goo20001Woo20005Woo20001Woo20001Woo20001Woo20001Woo20009goo000^Ool:000<Ool:000n
Ool:0004Ool:000EOol80006Ool80006Ool80006Ool80006Ool8000WOol002moo`P000ioo`P003mo
o`X000Aoo`X001Moo`@000Yoo`@000Yoo`@000Yoo`@000Yoo`@002Uoo`0067oo10004goo20001Goo
10001Goo20001Woo10004Woo10007goo2P0017oo2P00O7oo000FOol8000COol40005Ool80005Ool4
0006Ool8000>Ool8000MOol:0004Ool:001lOol001Ioo`P001aoo`P000moo`P000ioo`P001ioo`P0
00Ioo`P007eoo`005Goo2P006Woo2P003Goo2P0037oo2P007Goo20001Woo20001Woo10002Woo1000
2Goo10002Woo10008Goo10009Goo000EOol:000JOol:000=Ool:000<Ool:000OOol400000goo001o
o`07Ool40006Ool80006Ool80005Ool80006Ool8000MOol8000SOol001Eoo`X001Yoo`X000eoo`X0
00aoo`X002Aoo`03001oogoo011oo`P000Ioo`P000Eoo`P000Ioo`P001eoo`P002=oo`005Goo2P00
6Woo2P003Goo2P0037oo2P0097oo0P0047oo2P0017oo2P000goo2P0017oo2P006goo2P008Woo000F
Ool8000LOol8000?Ool8000>Ool8000UOol00`00Oomoo`0?Ool:0004Ool:0003Ool:0004Ool:000K
Ool:000ROol001Ioo`P001aoo`P000moo`P000Eoo`@000Eoo`P000Ioo`@0019oo`@000Eoo`03001o
ogoo00moo`X000Aoo`X000=oo`X000Aoo`X001]oo`X000Qoo`@001Ioo`0067oo100087oo10004goo
10001Goo20001Goo10001Woo20003Woo20000goo00<007ooOol03goo2P0017oo2P000goo2P0017oo
2P006goo2P001Woo200057oo001LOol8000?Ool8000>Ool80003Ool00`00Oomoo`0@Ool80006Ool8
0005Ool80006Ool8000MOol80007Ool8000DOol005]oo`X000eoo`X000aoo`X0009oo`03001oogoo
011oo`P000Ioo`P000Eoo`P000Ioo`P001eoo`P000Ioo`X001=oo`00Fgoo2P003Goo2P0037oo2P00
0Woo00<007ooOol04Woo10002Woo10002Goo10002Woo10008Goo100027oo2P004goo000QOol4000C
Ool4000OOol:000=Ool:000<Ool:0002Ool00`00Oomoo`1/Ool:000COol001moo`P000moo`P001eo
o`X000eoo`X000aoo`X0009oo`03001oogoo06aoo`X001=oo`007goo20003goo20007Woo20003goo
20003Woo20000goo00<007ooOol0KGoo200057oo000NOol:000=Ool:000MOol8000?Ool80005Ool4
0005Ool80003Ool00`00Oomoo`0=Ool4000:Ool4000:Ool4000COol4000:Ool4000:Ool4000=Ool8
0006Ool4000:Ool001ioo`X000eoo`X001moo`@001=oo`@000Eoo`P000Eoo`@000Eoo`03001oogoo
00]oo`P000Ioo`P000Ioo`P000moo`P000Ioo`P000Ioo`P000eoo`@000Ioo`P000Qoo`007Woo2P00
3Goo2P00?goo20003Woo00<007ooOol02goo20001Woo20001Woo20003goo20001Woo20001Woo2000
5goo200027oo000NOol:000=Ool:000nOol:000=Ool00`00Oomoo`0:Ool:0004Ool:0004Ool:000=
Ool:0004Ool:0004Ool:000EOol:0007Ool001moo`P000moo`P003moo`X000eoo`8000]oo`X000Ao
o`X000Aoo`X000eoo`X000Aoo`X000Aoo`X001Eoo`X000Moo`0027oo10004goo20001Woo10001Goo
20001Goo10004goo10007goo2P003Goo00<007ooOol02Woo2P0017oo2P0017oo2P003Goo2P0017oo
2P0017oo2P005Goo2P001goo0006Ool:000AOol40006Ool80005Ool40005Ool80007Ool20006Ool8
000MOol:000=Ool00`00Oomoo`0:Ool:0004Ool:0004Ool:000=Ool:0004Ool:0004Ool:000EOol:
0007Ool000Ioo`P0009oo`03001oogoo01Qoo`P000ioo`P000Ioo`04001oogoo0005Ool8000NOol8
000>Ool00`00Oomoo`0;Ool80006Ool80006Ool8000?Ool80006Ool80006Ool8000GOol80008Ool0
00Eoo`X00003Ool007oo01Qoo`X000aoo`X000Qoo`03001oogoo009oo`X001eoo`P000ioo`03001o
ogoo00]oo`P000Ioo`P000Ioo`P000moo`P000Ioo`P000Ioo`P001Moo`P000Qoo`0000=oo`000000
300000=oo`00Ool067oo2P0037oo3@000goo0P001Goo2P007goo10001goo10001Goo00<007ooOol0
3Goo10002Woo10002Woo10004goo10002Woo10002Woo10003goo100027oo10002Woo0005Ool:0000
0goo001oo`0HOol:000<Ool:0006Ool00`00Oomoo`04Ool:000XOol80003Ool00`00Oomoo`11Ool0
0`00Oomoo`0YOol8000DOol000Eoo`/001Yoo`X000aoo`X000Ioo`<000Aoo`X002Qoo`P000=oo`03
001oogoo045oo`<002Uoo`P001Aoo`001Woo20007Goo20003Woo20003goo2000:7oo2P000Woo00<0
07ooOol0K7oo2P004goo0006Ool8000MOol8000>Ool8000?Ool8000XOol:0002Ool00`00Oomoo`1/
Ool:000COol000Qoo`@001Eoo`@000Qoo`@000Moo`@000Moo`@000Moo`@000Qoo`@000Moo`@001=o
o`@000Qoo`X0009oo`03001oogoo02eoo`@000Yoo`@0025oo`@000Qoo`X001=oo`007goo20003goo
20003Woo20003goo20003goo20001Woo2P000Woo00<007ooOol0:goo20001Woo20007Goo20001Woo
2P004goo000OOol8000?Ool8000>Ool8000?Ool8000?Ool80007Ool80003Ool00`00Oomoo`0[Ool8
0006Ool8000MOol80007Ool8000DOol001ioo`X000eoo`X000aoo`X000eoo`X000eoo`X000Ioo`P0
00=oo`03001oogoo02Yoo`X000Aoo`X001]oo`X000Ioo`P001Aoo`000gooo`007P000009Ool00`00
Oomoo`0:Ool00`00Oomoo`05Ool:000:Ool00`00Oomoo`0:00000goo001oo`09Ool:0007Ool00`00
Oomoo`03Ool:000<Ool;0003Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`0:000017oo001oogoo2`003Goo00<007ooOol02Woo2P001Goo00<007oo
Ool02goo00<007ooOol037oo0009Ool00`00Oomoo`0BOol:000=Ool:000<Ool:000=Ool:000=Ool:
000AOol00`00Oomoo`0ZOol:0004Ool;000JOol:000ROol001moo`P000moo`P000ioo`P000moo`P0
00moo`P0019oo`03001oogoo02]oo`P000Ioo`P001eoo`P002=oo`0027oo10004goo20001Woo1000
1Goo20001Goo10001Goo20001Woo10001Goo20001Goo10001Woo20001Goo10002Goo1@00:Goo2000
1Woo20007Goo20008goo0006Ool8000COol40006Ool80005Ool40005Ool80005Ool40006Ool80005
Ool40005Ool80006Ool40005Ool80006Ool8000YOol4000:Ool4000QOol4000UOol000Ioo`P001eo
o`P000ioo`P000moo`P000ioo`P000moo`P000Ioo`P008Eoo`001Goo2P006goo2P0037oo2P003Goo
2P0037oo2P003Goo2P0017oo2P00Q7oo0005Ool:000KOol:000<Ool:000=Ool:000<Ool:000=Ool:
0004Ool:0024Ool000Eoo`X001]oo`X000aoo`X000eoo`X000aoo`X000eoo`X000Aoo`X000Qoo`@0
00Yoo`@000Yoo`@001=oo`@000Yoo`@000Yoo`@002Uoo`001Goo2P006goo2P0037oo2P003Goo2P00
37oo2P003Goo2P0017oo2P001Woo20001Woo20001Woo20003goo20001Woo20001Woo20009goo0006
Ool8000MOol8000>Ool8000?Ool8000>Ool8000?Ool80006Ool80007Ool80006Ool80006Ool8000?
Ool80006Ool80006Ool8000WOol000Ioo`P000Eoo`@001Aoo`P000Eoo`@000Eoo`P000Eoo`@000Io
o`P000Eoo`@000Eoo`P000Ioo`@000Eoo`P000Ioo`P000Ioo`X000Aoo`X000Aoo`X000eoo`X000Ao
o`X000Aoo`X001aoo`@000Ioo`0027oo10001Goo200057oo10001Goo20001Goo10001Goo20001Woo
10001Goo20001Goo10001Woo20001Goo10002Goo1@0027oo2P0017oo2P0017oo2P003Goo2P0017oo
2P0017oo2P006Woo200017oo000AOol8000MOol8000>Ool8000?Ool8000?Ool8000BOol2000;Ool:
0004Ool:0004Ool:000=Ool:0004Ool:0004Ool:000JOol80004Ool0011oo`X001]oo`X000aoo`X0
00eoo`X000eoo`X0015oo`03001oogoo00Yoo`X000Aoo`X000Aoo`X000eoo`X000Aoo`X000Aoo`X0
01Uoo`X000=oo`0047oo2P006goo2P0037oo2P003Goo2P003Goo2P004Goo00<007ooOol02goo2000
1Woo20001Woo20003goo20001Woo20001Woo20006Woo2P000goo000@Ool:000KOol:000<Ool:000=
Ool:000=Ool:0008Ool40005Ool00`00Oomoo`02Ool40005Ool80006Ool80006Ool8000?Ool80006
Ool80006Ool8000=Ool40009Ool:0003Ool0011oo`X001]oo`X000aoo`X000eoo`X000eoo`X000Io
o`P000=oo`03001oogoo00P000Eoo`@000Yoo`@000Yoo`@001=oo`@000Yoo`@000Yoo`@000eoo`P0
00Moo`X000=oo`004Goo20007Goo20003Woo20003goo20003goo20001goo20000goo00<007ooOol0
2000IGoo200027oo200017oo000AOol8000DOol40005Ool80005Ool40005Ool8000?Ool8000?Ool8
0006Ool:0002Ool00`00Ool00009001SOol:0007Ool80004Ool001=oo`@001Aoo`P000Eoo`@000Eo
o`P000Eoo`@001=oo`@001=oo`@000Qoo`X0009oo`03001oo`0000T006=oo`X000Uoo`@000Ioo`00
:goo20003Woo2000?goo2P000Woo00<007oo00002@005goo10002Goo10002Woo10008Goo100027oo
2P004goo000ZOol:000<Ool:000nOol:0002Ool00`00Ool00009000EOol80005Ool80006Ool8000M
Ool80006Ool:000COol002Yoo`X000aoo`X003moo`P000=oo`03001oogoo00P001Ioo`P000Eoo`P0
00Ioo`P001eoo`P000Moo`P001Aoo`0067oo10003Woo2P0037oo2P007goo10004goo10001Goo2000
0goo00<007ooOol020005Goo2P000goo2P0017oo2P006goo2P001Woo200057oo000FOol8000<Ool:
000<Ool:000MOol8000?Ool80005Ool40005Ool00`00Oomoo`02Ool4000GOol:0003Ool:0004Ool:
000KOol:0008Ool4000FOol001Ioo`P000eoo`P000ioo`P001ioo`P000moo`P000ioo`03001oogoo
01eoo`X000=oo`X000Aoo`X001]oo`X0029oo`005Goo2P0037oo20003Woo20007Goo2P003Goo2P00
3Goo0P007Woo2P000goo2P0017oo2P006goo2P008Woo000EOol:000>Ool4000BOol4000OOol:000=
Ool:000=Ool00`00Oomoo`0NOol80005Ool80006Ool8000MOol8000SOol001Eoo`X004Moo`X000eo
o`X000eoo`03001oogoo00Ioo`@001Aoo`P000Eoo`P000Ioo`P001eoo`P002=oo`005Goo2P00Agoo
2P003Goo2P003Goo00<007ooOol017oo200057oo10002Goo10002Woo10008Goo10009Goo000FOol8
0019Ool8000?Ool8000>Ool00`00Oomoo`04Ool8001mOol001Ioo`P001=oo`@0019oo`@001=oo`@0
00Eoo`P000Ioo`@000Eoo`P000ioo`03001oogoo00=oo`X007aoo`0067oo10004goo20003Woo2000
3goo20001Goo10001Woo20001Goo100047oo00<007ooOol00goo2P00O7oo000_Ool8000>Ool8000?
Ool8000?Ool8000IOol00`00Oomoo`03Ool:000GOol4000:Ool4000:Ool4000:Ool4000:Ool4000Y
Ool002ioo`X000aoo`X000eoo`X000eoo`X001Qoo`03001oogoo00=oo`X001Eoo`P000Ioo`P000Io
o`P000Ioo`P000Ioo`P002Moo`00;Woo2P0037oo2P003Goo2P003Goo2P0067oo00<007ooOol017oo
20005Woo20001Woo20001Woo20001Woo20001Woo20009goo000^Ool:000<Ool:000=Ool:000=Ool:
000HOol00`00Oomoo`04Ool8000EOol:0004Ool:0004Ool:0004Ool:0004Ool:000VOol002ioo`X0
00aoo`X000eoo`X000eoo`X000Qoo`@000aoo`03001oogoo00Ioo`@001Moo`X000Aoo`X000Aoo`X0
00Aoo`X000Aoo`X001aoo`@000Ioo`00;goo20003Woo20003goo20003goo20001goo20002Woo00<0
07ooOol08Goo2P0017oo2P0017oo2P0017oo2P0017oo2P006Woo200017oo000_Ool8000>Ool8000?
Ool8000?Ool80007Ool8000:Ool00`00Oomoo`0QOol:0004Ool:0004Ool:0004Ool:0004Ool:000J
Ool80004Ool0035oo`@000Moo`@000Moo`@000Qoo`@000Moo`@001=oo`@000Qoo`X000Uoo`8002=o
o`P000Ioo`P000Ioo`P000Ioo`P000Ioo`P001Yoo`X000=oo`00>Woo20003goo2000:7oo2P002Goo
00<007ooOol08Woo20001Woo20001Woo20001Woo20001Woo20006Woo2P000goo000jOol8000?Ool8
000XOol:0009Ool00`00Oomoo`0;Ool4000:Ool40007Ool4000:Ool4000:Ool4000:Ool4000:Ool4
000?Ool40009Ool:0003Ool003Uoo`X000eoo`X002Moo`X000Uoo`03001oogoo00Uoo`P000Ioo`P0
04ioo`P000Moo`X000=oo`00>Goo2P003Goo2P00:7oo20002Woo00<007ooOol02Goo20001Woo2000
CWoo200027oo200017oo000WOol4000>Ool:000=Ool:000OOol40005Ool8000:Ool00`00Oomoo`08
Ool:0004Ool:001<Ool:0007Ool80004Ool002Eoo`P000aoo`X000eoo`X001eoo`P000Eoo`@000ao
o`03001oogoo00Qoo`X000Aoo`X004aoo`X000Uoo`@000Ioo`009Goo20003Goo20003goo20007Woo
20005Goo00<007ooOol027oo2P0017oo2P005Woo10002Woo10002Woo10005Woo2P004goo000TOol:
000<Ool8000?Ool8000MOol:000DOol00`00Oomoo`08Ool:0004Ool:000DOol80006Ool80006Ool8
000DOol:000COol002Aoo`X000ioo`@001=oo`@001moo`X001Aoo`03001oogoo00Uoo`P000Ioo`P0
01Eoo`P000Ioo`P000Ioo`P001Eoo`P001Aoo`0097oo2P00B7oo2P0027oo100027oo00<007oo0000
0`001Woo20001Woo200057oo2P0017oo2P0017oo2P0057oo200057oo000TOol:0018Ool:0006Ool8
0006Ool80006Ool4000:Ool4000FOol:0004Ool:0004Ool:000FOol4000FOol002Eoo`P004Yoo`P0
00Moo`P000Ioo`P002ioo`X000Aoo`X000Aoo`X0031oo`009Goo200057oo10004Woo10004goo1000
1Goo20001Woo2P0017oo2P00;Goo2P0017oo2P0017oo2P00<7oo000WOol4000DOol8000>Ool8000?
Ool80005Ool40008Ool:0004Ool:000^Ool80006Ool80006Ool8000aOol003moo`P000ioo`P000mo
o`P0015oo`X000Aoo`X001Moo`@000Yoo`@000Eoo`P000Ioo`P000Ioo`P001=oo`@001Yoo`00?Woo
2P0037oo2P003Goo2P0047oo2P0017oo2P005Goo20001Woo20001Goo10002Woo10002Woo10004goo
200067oo000nOol:000<Ool:000=Ool:000AOol80006Ool8000FOol80006Ool8000hOol8000HOol0
02=oo`@001Moo`X000aoo`X000eoo`X000Qoo`@000Eoo`P000Ioo`P001Eoo`X000Aoo`X003Ioo`X0
01Moo`008Goo20005Goo2P0037oo2P003Goo2P001Woo20001Goo100027oo00<007oo00000`005goo
2P0017oo2P00=Woo2P005goo000QOol8000FOol8000>Ool8000?Ool80007Ool8000AOol00`00Oomo
o`0JOol:0004Ool:000FOol4000:Ool4000>Ool:000GOol0021oo`X001Eoo`P000Eoo`@000Eoo`P0
00Eoo`@000Ioo`P000Ioo`X0011oo`03001oogoo01Yoo`X000Aoo`X001Aoo`P000Ioo`P000aoo`X0
01Moo`0087oo2P005goo10001Goo20001Goo10001Goo20001Woo100027oo2P0047oo00<007ooOol0
6goo20001Woo20005Goo20001Woo20003Goo200067oo000POol:000POol8000>Ool8000BOol:000@
Ool00`00Oomoo`04Ool4000:Ool40005Ool80006Ool8000DOol:0004Ool:000<Ool8000HOol0021o
o`X001moo`X000aoo`X0015oo`X0011oo`03001oogoo009oo`P000Ioo`P000Eoo`@000Yoo`@001Io
o`X000Aoo`X000ioo`@001Yoo`008Goo200087oo2P0037oo2P004Woo20004Goo00<007ooOol00Woo
20001Woo2000;Goo2P0017oo2P00;7oo000QOol8000POol:000<Ool:0009Ool40005Ool80009Ool2
0006Ool01000Oomoogoo2P0017oo2P00;7oo2P0017oo2P00;7oo000SOol4000ROol:000<Ool:0007
Ool80005Ool4000:Ool01000Oomoo`001Goo00@007ooOomoo`X000Aoo`X002eoo`P000Ioo`P002eo
o`00BWoo20003Woo200027oo20005Woo00<007ooOol00goo0`0000=oo`000000200017oo2P005Woo
10004goo20001Woo20004goo10005Woo001:Ool8000>Ool80007Ool:000COol20006Ool01000Oomo
ogoo2P0017oo2P0057oo20004goo10002Woo10004goo200057oo001<Ool4000BOol40009Ool:000C
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool80006Ool8000EOol8000hOol8000DOol002Moo`@004Ao
o`X000Qoo`@000Moo`L00003Ool007oo00=oo`P000Ioo`P001Aoo`X003Ioo`X001=oo`009Goo2000
@Woo2P001Woo20001Woo20001Woo10002Woo10005Woo2P00=Woo2P004goo000UOol80013Ool80007
Ool80006Ool8000^Ool:000GOol4000KOol:000COol002Aoo`X0029oo`@001=oo`@000Eoo`P000Io
o`X000Aoo`X002eoo`X001Eoo`P001Uoo`X001=oo`0097oo2P0087oo20003goo20001Goo100027oo
2P0017oo2P00;Woo20005Woo20006Woo200057oo000TOol:000POol8000?Ool8000AOol:0004Ool:
000GOol4000COol8000EOol:000IOol8000DOol002Aoo`X001moo`X000eoo`X0011oo`X000Aoo`X0
01Eoo`P001=oo`@001Moo`X001]oo`@001Ioo`009Goo200087oo2P003Goo2P004Goo20001Woo2000
5Woo2000;Woo2P00=Goo000UOol80006Ool4000:Ool40008Ool:000=Ool:0008Ool40005Ool80006
Ool8000EOol:000]Ool:000eOol002Moo`@000Ioo`P000Ioo`P000Ioo`X000eoo`X000Ioo`P000Eo
o`@000Yoo`@00003Ool007oo01Aoo`X002ioo`P003Ioo`00<Goo20001Woo20001goo20003goo2000
1goo200067oo00<007ooOol04goo2P005Woo100057oo20004goo10007goo000`Ool:0004Ool:0006
Ool8000?Ool80006Ool:000GOol2000DOol:000DOol8000DOol4000COol8000MOol0031oo`X000Ao
o`X000Qoo`@000Moo`@000Qoo`@000Qoo`X001Moo`03001oogoo01Aoo`P001Eoo`P002]oo`P001eo
o`00<7oo2P0017oo2P004Goo20004Woo2P005goo10004goo200057oo2P00:Goo2P0077oo000`Ool:
0004Ool:000AOol8000BOol:000EOol8000COol4000FOol:000YOol:000LOol0035oo`P000Ioo`P0
015oo`X0019oo`P001Ioo`P002eoo`X002Uoo`X001aoo`00<Goo20001Woo20004Goo2P004Woo2000
5Goo2P00;7oo2P00:Goo2P0077oo000cOol4000:Ool4000COol:0009Ool40007Ool4000GOol:000]
Ool8000[Ool8000MOol005Qoo`X000Moo`P0021oo`X002eoo`P002]oo`P001eoo`00FGoo200027oo
200087oo2P005Woo10002Woo10001goo10005Woo10005Goo10007goo001IOol80007Ool:000POol8
000EOol80006Ool8000MOol8000fOol005]oo`@000Uoo`X0021oo`P001Eoo`P000Ioo`P001eoo`P0
03Ioo`00J7oo2P0027oo10005Woo10005Woo2P0017oo2P006goo2P00=Goo001XOol:0006Ool8000D
Ool00`00Oomoo`0GOol:0004Ool:000KOol:000eOol006Uoo`P000Moo`P001Aoo`8001Qoo`X000Ao
o`X001]oo`X003Eoo`00JGoo20001Woo2P004goo00<007ooOol05goo2P0017oo2P006goo2P00=Goo
001[Ool40008Ool:000COol00`00Oomoo`0HOol80006Ool8000MOol8000fOol007Moo`X001=oo`04
001oogooOol4000:Ool40005Ool80006Ool8000COol40006Ool8000fOol007Moo`X001=oo`03001o
o`0000L000Ioo`P000Eoo`@000Yoo`@001=oo`P000Ioo`@003Qoo`00N7oo200057oo00<007oo0000
1`001Woo2000:Woo2000@Woo001@Ool4000KOol40005Ool8000DOol;0004Ool:000XOol:0011Ool0
04ioo`P001Moo`P000Eoo`@001Ioo`/000Aoo`X002Qoo`X0045oo`00CWoo20005goo20007goo2`00
17oo2P00:7oo2P00@Goo001=Ool:000EOol:000NOol;0004Ool:000XOol:0011Ool004eoo`X001Eo
o`X001ioo`03001oo`0000L000Ioo`P002Yoo`P0049oo`00CGoo2P005Goo2P002Goo10004Goo00<0
07oo00001`001Woo20004goo10004goo20001Woo1000>7oo001=Ool:000EOol:0007Ool8000?Ool0
1000Oomoogoo10002Woo10004goo20004goo10001Woo2000=Woo001>Ool8000GOol80008Ool8000?
Ool00`00Oomoo`0VOol8000MOol8000fOol004ioo`P000Eoo`@000ioo`P000Moo`X000ioo`8002Io
o`X001]oo`X003Eoo`00D7oo10001Goo20003Woo10002Goo2P003Woo00<007ooOol09Goo2P006goo
2P00=Goo001IOol8000KOol:000>Ool00`00Oomoo`0IOol40008Ool:000KOol:000eOol005Qoo`X0
01Yoo`X000ioo`03001oogoo01Moo`P000Ioo`X001]oo`X003Eoo`00F7oo2P006goo20003goo00<0
07ooOol05goo20001goo20007Goo2000=Woo001HOol:000KOol8000?Ool00`00Oomoo`0FOol:0006
Ool8000MOol8000fOol005Qoo`X001eoo`@0015oo`03001oogoo01Ioo`X000Qoo`@0025oo`@003Qo
o`00FGoo2000<goo00<007ooOol05Woo2P00JGoo001IOol8000cOol00`00Oomoo`0FOol:001YOol0
05]oo`@003Eoo`03001oogoo01Moo`P006Yoo`00R7oo100027oo00<007oo00000`0057oo20001Goo
1000HGoo0026Ool80006Ool8000DOol40005Ool8001OOol008Ioo`P000Ioo`P001eoo`P005moo`00
H7oo10008Goo2P0017oo2P006goo2P00GWoo001NOol8000OOol:0004Ool:000KOol:001NOol005io
o`P001moo`X000Aoo`X001]oo`X005ioo`00GGoo2P007Woo2P0017oo2P006goo2P00GWoo001MOol:
000OOol80006Ool8000MOol8001OOol005eoo`X000Qoo`@001=oo`P000Ioo`P000Ioo`@001=oo`P0
05moo`00GGoo2P001Woo20004goo100027oo00<007oo00000`001Woo20004goo1000HGoo001NOol8
0007Ool8000OOol00`00Oomoo`09Ool8001hOol005ioo`P000Ioo`X001ioo`03001oogoo00Qoo`X0
07Moo`00H7oo100027oo2P007Woo00<007ooOol027oo2P00Mgoo001/Ool:000LOol40009Ool:001g
Ool006aoo`X001Yoo`P000Moo`X007Moo`00KGoo20006goo200027oo2000N7oo001]Ool8000@Ool5
0002Ool200000goo000000080007Ool8001hOol006moo`@001Aoo`05001oogooOol00002Ool;0009
Ool4001jOol008Moo`05001oogooOol00002Ool;0027Ool008Moo`05001oogooOol00002Ool;0027
Ool008Moo`05001oogooOol00002Ool00`00Ool000070028Ool008Ioo`8000Aoo`80009oo`P008Qo
o`00TWoo1000RWoo002DOol00`00Oomoo`29Ool009Aoo`03001oogoo08Uoo`00U7oo00<007ooOol0
RGoo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {295.125, 0}} -> {-10.6462, -10.593, \
0.0717866, 0.0717866}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generating the remainig regions", "Subsection"],

Cell[BoxData[{
    \(\(QL121 = 
        Table[QL021[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL131 = 
        Table[QL031[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL132 = 
        Table[QL032[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL141 = 
        Table[QL041[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                QL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL142 = 
        Table[QL042[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                QL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL143 = 
        Table[QL043[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                QL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL151 = 
        Table[QL051[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                QL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL152 = 
        Table[QL052[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                QL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL153 = 
        Table[QL053[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                QL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL154 = 
        Table[QL054[\([i]\)]\  + 
            e[5], {i, \(Dimensions[QL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[{
    \(\(QL221 = 
        Table[QL021[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL231 = 
        Table[QL031[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL232 = 
        Table[QL032[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL241 = 
        Table[QL041[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL242 = 
        Table[QL042[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL243 = 
        Table[QL043[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL251 = 
        Table[QL051[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL252 = 
        Table[QL052[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL253 = 
        Table[QL053[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL254 = 
        Table[QL054[\([i]\)]\  + 
            e[4], {i, \(Dimensions[QL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[120]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(QL321 = 
        Table[QL021[\([i]\)]\  + e[2] + 
            e[1], {i, \(Dimensions[
                QL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL331 = 
        Table[QL031[\([i]\)]\  + e[3] + 
            e[1], {i, \(Dimensions[
                QL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL332 = 
        Table[QL032[\([i]\)]\  + e[3] + 
            e[2], {i, \(Dimensions[
                QL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL341 = 
        Table[QL041[\([i]\)]\  + e[4] + 
            e[1], {i, \(Dimensions[
                QL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL342 = 
        Table[QL042[\([i]\)]\  + e[4] + 
            e[2], {i, \(Dimensions[
                QL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL343 = 
        Table[QL043[\([i]\)]\  + e[4] + 
            e[3], {i, \(Dimensions[
                QL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL351 = 
        Table[QL051[\([i]\)]\  + e[5] + 
            e[1], {i, \(Dimensions[
                QL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL352 = 
        Table[QL052[\([i]\)]\  + e[5] + 
            e[2], {i, \(Dimensions[
                QL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL353 = 
        Table[QL053[\([i]\)]\  + e[5] + 
            e[3], {i, \(Dimensions[
                QL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL354 = 
        Table[QL054[\([i]\)]\  + e[5] + 
            e[4], {i, \(Dimensions[QL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(QL321\)\" is similar to \
existing symbol \"\!\(QL231\)\"."\)], "Message",
  CellLabel->"From In[130]:="]
}, Open  ]],

Cell[BoxData[
    \(\(QL = 
        Union[QL021, QL031, QL032, QL041, QL042, QL043, \ QL051, QL052, 
          QL053, QL054, QL121, QL131, QL132, QL141, QL142, QL143, \ QL151, 
          QL152, QL153, QL154, QL221, QL231, QL232, QL241, QL242, QL243, \ 
          QL251, QL252, QL253, QL254, QL321, QL331, QL332, QL341, QL342, 
          QL343, QL351, QL352, QL353, QL354];\)\)], "Input",
  CellLabel->"In[140]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[SphericalCut[N[QL], 15], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.02], 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[141]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99466 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.498097 0.0322465 0.49371 0.0322465 [
[.0144 .48121 -9 -9 ]
[.0144 .48121 9 0 ]
[.17563 .48121 -9 -9 ]
[.17563 .48121 9 0 ]
[.33686 .48121 -6 -9 ]
[.33686 .48121 6 0 ]
[.65933 .48121 -3 -9 ]
[.65933 .48121 3 0 ]
[.82056 .48121 -6 -9 ]
[.82056 .48121 6 0 ]
[.98179 .48121 -6 -9 ]
[.98179 .48121 6 0 ]
[.4856 .01001 -18 -4.5 ]
[.4856 .01001 0 4.5 ]
[.4856 .17125 -18 -4.5 ]
[.4856 .17125 0 4.5 ]
[.4856 .33248 -12 -4.5 ]
[.4856 .33248 0 4.5 ]
[.4856 .65494 -6 -4.5 ]
[.4856 .65494 0 4.5 ]
[.4856 .81618 -12 -4.5 ]
[.4856 .81618 0 4.5 ]
[.4856 .97741 -12 -4.5 ]
[.4856 .97741 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .99466 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0144 .49371 m
.0144 .49996 L
s
[(-15)] .0144 .48121 0 1 Mshowa
.17563 .49371 m
.17563 .49996 L
s
[(-10)] .17563 .48121 0 1 Mshowa
.33686 .49371 m
.33686 .49996 L
s
[(-5)] .33686 .48121 0 1 Mshowa
.65933 .49371 m
.65933 .49996 L
s
[(5)] .65933 .48121 0 1 Mshowa
.82056 .49371 m
.82056 .49996 L
s
[(10)] .82056 .48121 0 1 Mshowa
.98179 .49371 m
.98179 .49996 L
s
[(15)] .98179 .48121 0 1 Mshowa
.125 Mabswid
.04665 .49371 m
.04665 .49746 L
s
.07889 .49371 m
.07889 .49746 L
s
.11114 .49371 m
.11114 .49746 L
s
.14339 .49371 m
.14339 .49746 L
s
.20788 .49371 m
.20788 .49746 L
s
.24013 .49371 m
.24013 .49746 L
s
.27237 .49371 m
.27237 .49746 L
s
.30462 .49371 m
.30462 .49746 L
s
.36911 .49371 m
.36911 .49746 L
s
.40136 .49371 m
.40136 .49746 L
s
.4336 .49371 m
.4336 .49746 L
s
.46585 .49371 m
.46585 .49746 L
s
.53034 .49371 m
.53034 .49746 L
s
.56259 .49371 m
.56259 .49746 L
s
.59484 .49371 m
.59484 .49746 L
s
.62708 .49371 m
.62708 .49746 L
s
.69158 .49371 m
.69158 .49746 L
s
.72382 .49371 m
.72382 .49746 L
s
.75607 .49371 m
.75607 .49746 L
s
.78831 .49371 m
.78831 .49746 L
s
.85281 .49371 m
.85281 .49746 L
s
.88505 .49371 m
.88505 .49746 L
s
.9173 .49371 m
.9173 .49746 L
s
.94955 .49371 m
.94955 .49746 L
s
.25 Mabswid
0 .49371 m
1 .49371 L
s
.4981 .01001 m
.50435 .01001 L
s
[(-15)] .4856 .01001 1 0 Mshowa
.4981 .17125 m
.50435 .17125 L
s
[(-10)] .4856 .17125 1 0 Mshowa
.4981 .33248 m
.50435 .33248 L
s
[(-5)] .4856 .33248 1 0 Mshowa
.4981 .65494 m
.50435 .65494 L
s
[(5)] .4856 .65494 1 0 Mshowa
.4981 .81618 m
.50435 .81618 L
s
[(10)] .4856 .81618 1 0 Mshowa
.4981 .97741 m
.50435 .97741 L
s
[(15)] .4856 .97741 1 0 Mshowa
.125 Mabswid
.4981 .04226 m
.50185 .04226 L
s
.4981 .07451 m
.50185 .07451 L
s
.4981 .10675 m
.50185 .10675 L
s
.4981 .139 m
.50185 .139 L
s
.4981 .20349 m
.50185 .20349 L
s
.4981 .23574 m
.50185 .23574 L
s
.4981 .26799 m
.50185 .26799 L
s
.4981 .30023 m
.50185 .30023 L
s
.4981 .36472 m
.50185 .36472 L
s
.4981 .39697 m
.50185 .39697 L
s
.4981 .42922 m
.50185 .42922 L
s
.4981 .46146 m
.50185 .46146 L
s
.4981 .52596 m
.50185 .52596 L
s
.4981 .5582 m
.50185 .5582 L
s
.4981 .59045 m
.50185 .59045 L
s
.4981 .6227 m
.50185 .6227 L
s
.4981 .68719 m
.50185 .68719 L
s
.4981 .71944 m
.50185 .71944 L
s
.4981 .75168 m
.50185 .75168 L
s
.4981 .78393 m
.50185 .78393 L
s
.4981 .84842 m
.50185 .84842 L
s
.4981 .88067 m
.50185 .88067 L
s
.4981 .91291 m
.50185 .91291 L
s
.4981 .94516 m
.50185 .94516 L
s
.25 Mabswid
.4981 0 m
.4981 .99466 L
s
0 0 m
1 0 L
1 .99466 L
0 .99466 L
closepath
clip
newpath
.02 w
.4336 .29522 Mdot
.4336 .6922 Mdot
.46585 .6922 Mdot
.4981 .17255 Mdot
.28939 .49371 Mdot
.28939 .4558 Mdot
.28939 .53162 Mdot
.47201 .51266 Mdot
.47201 .15359 Mdot
.44592 .49371 Mdot
.44592 .53162 Mdot
.41983 .51266 Mdot
.39375 .49371 Mdot
.39375 .53162 Mdot
.36766 .47476 Mdot
.36766 .51266 Mdot
.34157 .49371 Mdot
.34157 .53162 Mdot
.31548 .47476 Mdot
.31548 .51266 Mdot
.31548 .55057 Mdot
.28939 .49371 Mdot
.28939 .4558 Mdot
.28939 .53162 Mdot
.26331 .47476 Mdot
.26331 .51266 Mdot
.26331 .55057 Mdot
.23722 .49371 Mdot
.23722 .53162 Mdot
.21113 .47476 Mdot
.21113 .51266 Mdot
.18504 .49371 Mdot
.52418 .15359 Mdot
.60245 .37104 Mdot
.6347 .37104 Mdot
.6347 .61638 Mdot
.66694 .49371 Mdot
.66694 .43237 Mdot
.66694 .55505 Mdot
.66694 .37104 Mdot
.66694 .61638 Mdot
.66694 .13464 Mdot
.69919 .49371 Mdot
.69919 .43237 Mdot
.69919 .55505 Mdot
.69919 .37104 Mdot
.69919 .61638 Mdot
.69919 .0733 Mdot
.69919 .13464 Mdot
.69919 .13464 Mdot
.69919 .89069 Mdot
.73143 .49371 Mdot
.73143 .43237 Mdot
.73143 .55505 Mdot
.73143 .37104 Mdot
.73143 .61638 Mdot
.87564 .49371 Mdot
.87564 .43237 Mdot
.87564 .59295 Mdot
.92782 .49371 Mdot
.92782 .43237 Mdot
.96007 .49371 Mdot
.96007 .43237 Mdot
.90173 .51266 Mdot
.90173 .41342 Mdot
.64085 .87173 Mdot
.6731 .87173 Mdot
.95391 .51266 Mdot
.40752 .27627 Mdot
.40752 .71115 Mdot
.50426 .51266 Mdot
.26331 .47476 Mdot
.26331 .51266 Mdot
.36766 .47476 Mdot
.36766 .51266 Mdot
.54411 .35208 Mdot
.57636 .35208 Mdot
.57636 .63534 Mdot
.60861 .35208 Mdot
.60861 .63534 Mdot
.64085 .15359 Mdot
.64085 .63534 Mdot
.6731 .87173 Mdot
.23722 .49371 Mdot
.34157 .49371 Mdot
.34157 .53162 Mdot
.48578 .33313 Mdot
.51803 .33313 Mdot
.51803 .65429 Mdot
.55027 .33313 Mdot
.55027 .65429 Mdot
.58252 .65429 Mdot
.75136 .13464 Mdot
.78361 .13464 Mdot
.31548 .47476 Mdot
.31548 .51266 Mdot
.31548 .55057 Mdot
.45969 .31418 Mdot
.45969 .67325 Mdot
.49194 .31418 Mdot
.49194 .67325 Mdot
.52418 .67325 Mdot
.72528 .11569 Mdot
.72528 .87173 Mdot
.75752 .87173 Mdot
.26331 .47476 Mdot
.26331 .51266 Mdot
.26331 .47476 Mdot
.26331 .51266 Mdot
.40752 .27627 Mdot
.40752 .71115 Mdot
.43976 .15359 Mdot
.47201 .15359 Mdot
.47201 .83383 Mdot
.6731 .05435 Mdot
.14048 .27179 Mdot
.14048 .71563 Mdot
.14048 .21046 Mdot
.17272 .27179 Mdot
.17272 .71563 Mdot
.17272 .21046 Mdot
.20497 .53162 Mdot
.23722 .49371 Mdot
.23722 .53162 Mdot
.23722 .4558 Mdot
.38143 .13464 Mdot
.38143 .25731 Mdot
.38143 .29522 Mdot
.38143 .73011 Mdot
.38143 .85278 Mdot
.41367 .13464 Mdot
.41367 .85278 Mdot
.44592 .85278 Mdot
.08214 .73458 Mdot
.11439 .29075 Mdot
.11439 .69667 Mdot
.11439 .73458 Mdot
.11439 .22941 Mdot
.17888 .51266 Mdot
.21113 .51266 Mdot
.21113 .47476 Mdot
.35534 .15359 Mdot
.35534 .27627 Mdot
.35534 .27627 Mdot
.35534 .71115 Mdot
.0883 .71563 Mdot
.32925 .29522 Mdot
.32925 .6922 Mdot
.19881 .13017 Mdot
.19881 .79592 Mdot
.14048 .81487 Mdot
.17272 .81487 Mdot
.08214 .29075 Mdot
.11439 .29075 Mdot
.11439 .22941 Mdot
.14664 .51266 Mdot
.17888 .47476 Mdot
.17888 .51266 Mdot
.05606 .49371 Mdot
.05606 .3097 Mdot
.0883 .49371 Mdot
.0883 .71563 Mdot
.12055 .49371 Mdot
.1528 .49371 Mdot
.23487 .3638 Mdot
.23487 .3638 Mdot
.26711 .3638 Mdot
.37146 .76078 Mdot
.34538 .2456 Mdot
.34538 .74182 Mdot
.28704 .72287 Mdot
.28704 .7842 Mdot
.31929 .26455 Mdot
.31929 .32589 Mdot
.31929 .66153 Mdot
.31929 .72287 Mdot
.26095 .64258 Mdot
.26095 .22217 Mdot
.26095 .28351 Mdot
.26095 .64258 Mdot
.26095 .70391 Mdot
.2932 .28351 Mdot
.2932 .28351 Mdot
.2932 .34484 Mdot
.2932 .34484 Mdot
.2932 .64258 Mdot
.2932 .64258 Mdot
.26711 .3638 Mdot
.04609 .34037 Mdot
.04609 .46304 Mdot
.04609 .52438 Mdot
.19265 .27179 Mdot
.19265 .33313 Mdot
.19265 .65429 Mdot
.2249 .27179 Mdot
.2249 .33313 Mdot
.16657 .35208 Mdot
.33541 .77249 Mdot
.24483 .81487 Mdot
.27708 .75354 Mdot
.27708 .81487 Mdot
.30932 .23389 Mdot
.30932 .75354 Mdot
.21874 .73458 Mdot
.21874 .1915 Mdot
.21874 .25284 Mdot
.21874 .67325 Mdot
.21874 .73458 Mdot
.21874 .79592 Mdot
.25099 .25284 Mdot
.25099 .73458 Mdot
.25099 .1915 Mdot
.25099 .31418 Mdot
.25099 .25284 Mdot
.25099 .67325 Mdot
.25099 .73458 Mdot
.25099 .73458 Mdot
.28323 .25284 Mdot
.28323 .25284 Mdot
.19265 .71563 Mdot
.19265 .21046 Mdot
.19265 .27179 Mdot
.19265 .65429 Mdot
.19265 .71563 Mdot
.2249 .27179 Mdot
.2249 .33313 Mdot
.2249 .27179 Mdot
.16657 .35208 Mdot
.23487 .7842 Mdot
.26711 .7842 Mdot
.17653 .76525 Mdot
.20878 .22217 Mdot
.20878 .76525 Mdot
.20878 .76525 Mdot
.24102 .22217 Mdot
.24102 .76525 Mdot
.24102 .76525 Mdot
.15044 .7463 Mdot
.18269 .24113 Mdot
.18269 .7463 Mdot
.44357 .26455 Mdot
.44357 .72287 Mdot
.47582 .72287 Mdot
.54031 .46304 Mdot
.54031 .52438 Mdot
.57255 .46304 Mdot
.57255 .52438 Mdot
.6048 .46304 Mdot
.6048 .52438 Mdot
.29936 .42513 Mdot
.40371 .46304 Mdot
.40371 .42513 Mdot
.40371 .56229 Mdot
.64466 .34037 Mdot
.67691 .34037 Mdot
.67691 .64705 Mdot
.70915 .34037 Mdot
.70915 .64705 Mdot
.7414 .40171 Mdot
.7414 .46304 Mdot
.7414 .52438 Mdot
.7414 .58572 Mdot
.7414 .34037 Mdot
.7414 .40171 Mdot
.7414 .64705 Mdot
.41748 .2456 Mdot
.41748 .74182 Mdot
.48197 .44409 Mdot
.48197 .482 Mdot
.48197 .54333 Mdot
.51422 .44409 Mdot
.51422 .482 Mdot
.51422 .54333 Mdot
.54647 .54333 Mdot
.37762 .44409 Mdot
.37762 .54333 Mdot
.37762 .58124 Mdot
.37762 .58124 Mdot
.58633 .32142 Mdot
.61857 .32142 Mdot
.61857 .66601 Mdot
.65082 .66601 Mdot
.45589 .46304 Mdot
.45589 .56229 Mdot
.48813 .46304 Mdot
.48813 .56229 Mdot
.35153 .42513 Mdot
.35153 .56229 Mdot
.35153 .60019 Mdot
.35153 .56229 Mdot
.52799 .30246 Mdot
.56024 .30246 Mdot
.56024 .68496 Mdot
.59248 .68496 Mdot
.4298 .44409 Mdot
.4298 .482 Mdot
.4298 .54333 Mdot
.4298 .58124 Mdot
.32545 .40618 Mdot
.32545 .44409 Mdot
.32545 .58124 Mdot
.46966 .28351 Mdot
.5019 .28351 Mdot
.5019 .70391 Mdot
.53415 .70391 Mdot
.37762 .44409 Mdot
.37762 .54333 Mdot
.27327 .44409 Mdot
.41748 .2456 Mdot
.41748 .74182 Mdot
.35153 .46304 Mdot
.35153 .04264 Mdot
.35153 .42513 Mdot
.35153 .56229 Mdot
.35153 .60019 Mdot
.35153 .94478 Mdot
.38378 .04264 Mdot
.15044 .24113 Mdot
.15044 .30246 Mdot
.15044 .68496 Mdot
.15044 .7463 Mdot
.15044 .17979 Mdot
.15044 .24113 Mdot
.18269 .24113 Mdot
.18269 .30246 Mdot
.18269 .56229 Mdot
.18269 .68496 Mdot
.18269 .7463 Mdot
.18269 .17979 Mdot
.18269 .24113 Mdot
.21494 .42513 Mdot
.21494 .56229 Mdot
.24718 .42513 Mdot
.24718 .56229 Mdot
.39139 .22665 Mdot
.39139 .76078 Mdot
.2932 .06159 Mdot
.2932 .92583 Mdot
.32545 .06159 Mdot
.32545 .40618 Mdot
.32545 .44409 Mdot
.32545 .58124 Mdot
.32545 .58124 Mdot
.12436 .26008 Mdot
.12436 .32142 Mdot
.12436 .66601 Mdot
.12436 .76525 Mdot
.12436 .26008 Mdot
.12436 .76525 Mdot
.1566 .54333 Mdot
.18885 .44409 Mdot
.18885 .54333 Mdot
.22109 .44409 Mdot
.3653 .2456 Mdot
.26711 .08054 Mdot
.29936 .42513 Mdot
.29936 .56229 Mdot
.29936 .60019 Mdot
.17653 .16083 Mdot
.20878 .16083 Mdot
.20878 .86449 Mdot
.20878 .76525 Mdot
.20878 .82659 Mdot
.27327 .40618 Mdot
.27327 .44409 Mdot
.27327 .58124 Mdot
.27327 .58124 Mdot
.15044 .7842 Mdot
.18269 .7842 Mdot
.18269 .84554 Mdot
.24718 .42513 Mdot
.24718 .56229 Mdot
.09211 .26008 Mdot
.09211 .32142 Mdot
.09211 .26008 Mdot
.12436 .26008 Mdot
.12436 .32142 Mdot
.12436 .54333 Mdot
.12436 .26008 Mdot
.12436 .76525 Mdot
.1566 .44409 Mdot
.1566 .54333 Mdot
.18885 .44409 Mdot
.18885 .54333 Mdot
.22109 .44409 Mdot
.06602 .34037 Mdot
.06602 .46304 Mdot
.06602 .52438 Mdot
.06602 .68496 Mdot
.09827 .46304 Mdot
.09827 .52438 Mdot
.09827 .68496 Mdot
.13051 .46304 Mdot
.13051 .52438 Mdot
.16276 .46304 Mdot
.38143 .73011 Mdot
.38143 .79144 Mdot
.35534 .27627 Mdot
.35534 .21493 Mdot
.35534 .71115 Mdot
.35534 .77249 Mdot
.32925 .29522 Mdot
.32925 .23389 Mdot
.32925 .6922 Mdot
.11439 .574 Mdot
.14664 .574 Mdot
.02381 .49371 Mdot
.02381 .43237 Mdot
.02381 .55505 Mdot
.05606 .49371 Mdot
.05606 .3097 Mdot
.05606 .43237 Mdot
.05606 .55505 Mdot
.05606 .37104 Mdot
.05606 .65429 Mdot
.0883 .43237 Mdot
.0883 .55505 Mdot
.12055 .43237 Mdot
.34538 .74182 Mdot
.34538 .80316 Mdot
.28704 .72287 Mdot
.28704 .7842 Mdot
.31929 .20322 Mdot
.31929 .26455 Mdot
.31929 .72287 Mdot
.31929 .7842 Mdot
.26095 .22217 Mdot
.26095 .28351 Mdot
.26095 .70391 Mdot
.2932 .22217 Mdot
.2932 .22217 Mdot
.2932 .28351 Mdot
.2932 .28351 Mdot
.04609 .40171 Mdot
.04609 .58572 Mdot
.55027 .49371 Mdot
.55027 .43237 Mdot
.58252 .49371 Mdot
.58252 .43237 Mdot
.58252 .55505 Mdot
.61477 .49371 Mdot
.61477 .43237 Mdot
.61477 .55505 Mdot
.64701 .49371 Mdot
.64701 .43237 Mdot
.64701 .55505 Mdot
.41367 .39447 Mdot
.41367 .59295 Mdot
.41367 .63086 Mdot
.47817 .95202 Mdot
.75136 .49371 Mdot
.75136 .43237 Mdot
.75136 .55505 Mdot
.75136 .37104 Mdot
.85572 .43237 Mdot
.82963 .61191 Mdot
.49194 .41342 Mdot
.52418 .51266 Mdot
.52418 .41342 Mdot
.52418 .574 Mdot
.55643 .41342 Mdot
.55643 .574 Mdot
.38759 .37551 Mdot
.38759 .41342 Mdot
.38759 .37551 Mdot
.38759 .61191 Mdot
.38759 .61191 Mdot
.38759 .64982 Mdot
.82963 .41342 Mdot
.46585 .43237 Mdot
.46585 .39447 Mdot
.46585 .59295 Mdot
.4981 .39447 Mdot
.4981 .59295 Mdot
.3615 .39447 Mdot
.3615 .35656 Mdot
.3615 .39447 Mdot
.3615 .63086 Mdot
.43976 .37551 Mdot
.43976 .41342 Mdot
.43976 .61191 Mdot
.50426 .97098 Mdot
.5365 .97098 Mdot
.33541 .37551 Mdot
.38759 .41342 Mdot
.38759 .61191 Mdot
.38759 .64982 Mdot
.32925 .91412 Mdot
.3615 .0733 Mdot
.3615 .39447 Mdot
.3615 .35656 Mdot
.3615 .63086 Mdot
.3615 .91412 Mdot
.3615 .85278 Mdot
.39375 .0733 Mdot
.19265 .27179 Mdot
.19265 .59295 Mdot
.19265 .71563 Mdot
.19265 .21046 Mdot
.2249 .39447 Mdot
.2249 .59295 Mdot
.25715 .39447 Mdot
.25715 .59295 Mdot
.30316 .09226 Mdot
.30316 .89516 Mdot
.30316 .83383 Mdot
.33541 .09226 Mdot
.33541 .37551 Mdot
.33541 .37551 Mdot
.33541 .61191 Mdot
.33541 .64982 Mdot
.33541 .61191 Mdot
.33541 .64982 Mdot
.33541 .15359 Mdot
.33541 .83383 Mdot
.16657 .574 Mdot
.19881 .41342 Mdot
.24483 .11121 Mdot
.27708 .11121 Mdot
.27708 .91412 Mdot
.27708 .17255 Mdot
.27708 .81487 Mdot
.30932 .39447 Mdot
.30932 .35656 Mdot
.30932 .63086 Mdot
.30932 .17255 Mdot
.30932 .81487 Mdot
.21874 .13017 Mdot
.21874 .13017 Mdot
.21874 .79592 Mdot
.25099 .61191 Mdot
.25099 .1915 Mdot
.28323 .37551 Mdot
.28323 .37551 Mdot
.28323 .61191 Mdot
.28323 .61191 Mdot
.2249 .59295 Mdot
.25715 .39447 Mdot
.25715 .59295 Mdot
.16657 .41342 Mdot
.19881 .41342 Mdot
.14048 .43237 Mdot
.15044 .62362 Mdot
.18269 .3638 Mdot
.18269 .62362 Mdot
.21494 .3638 Mdot
.21494 .62362 Mdot
.39139 .76078 Mdot
.12436 .60467 Mdot
.1566 .38275 Mdot
.1566 .60467 Mdot
.18885 .38275 Mdot
.3653 .2456 Mdot
.24102 .64258 Mdot
.21494 .62362 Mdot
.09211 .60467 Mdot
.12436 .38275 Mdot
.12436 .54333 Mdot
.12436 .60467 Mdot
.1566 .38275 Mdot
.1566 .54333 Mdot
.1566 .60467 Mdot
.18885 .38275 Mdot
.06602 .34037 Mdot
.06602 .40171 Mdot
.06602 .46304 Mdot
.06602 .52438 Mdot
.06602 .58572 Mdot
.06602 .68496 Mdot
.09827 .40171 Mdot
.09827 .46304 Mdot
.09827 .52438 Mdot
.09827 .58572 Mdot
.13051 .40171 Mdot
.13051 .46304 Mdot
.14048 .65429 Mdot
.17272 .65429 Mdot
.11439 .63534 Mdot
.35534 .77249 Mdot
.32925 .23389 Mdot
.08214 .63534 Mdot
.11439 .35208 Mdot
.11439 .63534 Mdot
.14664 .35208 Mdot
.02381 .43237 Mdot
.05606 .43237 Mdot
.05606 .55505 Mdot
.05606 .37104 Mdot
.05606 .61638 Mdot
.0883 .37104 Mdot
.02997 .574 Mdot
.59248 .40171 Mdot
.59248 .58572 Mdot
.62473 .40171 Mdot
.62473 .46304 Mdot
.62473 .52438 Mdot
.62473 .58572 Mdot
.65698 .40171 Mdot
.65698 .46304 Mdot
.65698 .52438 Mdot
.65698 .58572 Mdot
.65698 .10397 Mdot
.65698 .92136 Mdot
.68922 .40171 Mdot
.68922 .46304 Mdot
.68922 .52438 Mdot
.68922 .58572 Mdot
.68922 .10397 Mdot
.68922 .10397 Mdot
.68922 .92136 Mdot
.72147 .40171 Mdot
.72147 .46304 Mdot
.72147 .52438 Mdot
.72147 .58572 Mdot
.42364 .3638 Mdot
.42364 .32589 Mdot
.42364 .66153 Mdot
.48813 .14188 Mdot
.86568 .40171 Mdot
.86568 .46304 Mdot
.86568 .52438 Mdot
.86568 .56229 Mdot
.91786 .46304 Mdot
.9501 .46304 Mdot
.89177 .44409 Mdot
.89177 .482 Mdot
.63089 .9024 Mdot
.66314 .9024 Mdot
.83959 .64258 Mdot
.94394 .54333 Mdot
.97619 .54333 Mdot
.53415 .38275 Mdot
.53415 .60467 Mdot
.5664 .38275 Mdot
.5664 .60467 Mdot
.59864 .60467 Mdot
.63089 .08502 Mdot
.63089 .12293 Mdot
.63089 .9024 Mdot
.63089 .94031 Mdot
.66314 .08502 Mdot
.66314 .9024 Mdot
.39755 .34484 Mdot
.39755 .30694 Mdot
.39755 .34484 Mdot
.39755 .68049 Mdot
.46204 .12293 Mdot
.83959 .38275 Mdot
.83959 .44409 Mdot
.83959 .482 Mdot
.47582 .3638 Mdot
.47582 .62362 Mdot
.50806 .3638 Mdot
.50806 .62362 Mdot
.54031 .62362 Mdot
.57255 .92136 Mdot
.6048 .10397 Mdot
.6048 .92136 Mdot
.37146 .32589 Mdot
.7414 .10397 Mdot
.77365 .10397 Mdot
.8135 .46304 Mdot
.44973 .34484 Mdot
.44973 .64258 Mdot
.48197 .64258 Mdot
.54647 .9024 Mdot
.54647 .02368 Mdot
.57871 .9024 Mdot
.71531 .08502 Mdot
.71531 .9024 Mdot
.74756 .08502 Mdot
.74756 .9024 Mdot
.39755 .30694 Mdot
.39755 .34484 Mdot
.39755 .68049 Mdot
.4298 .12293 Mdot
.46204 .12293 Mdot
.46204 .86449 Mdot
.37146 .10397 Mdot
.37146 .32589 Mdot
.37146 .69944 Mdot
.37146 .66153 Mdot
.37146 .88345 Mdot
.37146 .82211 Mdot
.37146 .88345 Mdot
.40371 .10397 Mdot
.40371 .88345 Mdot
.43596 .10397 Mdot
.43596 .88345 Mdot
.23487 .3638 Mdot
.26711 .3638 Mdot
.31313 .86449 Mdot
.34538 .12293 Mdot
.34538 .30694 Mdot
.34538 .34484 Mdot
.34538 .30694 Mdot
.34538 .34484 Mdot
.34538 .68049 Mdot
.34538 .68049 Mdot
.34538 .12293 Mdot
.34538 .18426 Mdot
.34538 .80316 Mdot
.34538 .86449 Mdot
.28704 .14188 Mdot
.28704 .20322 Mdot
.28704 .7842 Mdot
.31929 .32589 Mdot
.31929 .66153 Mdot
.31929 .14188 Mdot
.31929 .20322 Mdot
.31929 .7842 Mdot
.26095 .64258 Mdot
.26095 .22217 Mdot
.2932 .34484 Mdot
.2932 .34484 Mdot
.2932 .64258 Mdot
.2932 .64258 Mdot
.26711 .3638 Mdot
.19265 .59295 Mdot
.19265 .33313 Mdot
.19265 .65429 Mdot
.2249 .39447 Mdot
.2249 .59295 Mdot
.2249 .33313 Mdot
.2249 .65429 Mdot
.25715 .33313 Mdot
.16657 .574 Mdot
.16657 .35208 Mdot
.19881 .41342 Mdot
.27708 .6922 Mdot
.30932 .29522 Mdot
.30932 .6922 Mdot
.21874 .67325 Mdot
.25099 .61191 Mdot
.25099 .31418 Mdot
.25099 .67325 Mdot
.25099 .67325 Mdot
.28323 .31418 Mdot
.28323 .31418 Mdot
.28323 .67325 Mdot
.28323 .67325 Mdot
.19265 .65429 Mdot
.2249 .59295 Mdot
.2249 .33313 Mdot
.2249 .65429 Mdot
.25715 .33313 Mdot
.16657 .41342 Mdot
.16657 .574 Mdot
.19881 .41342 Mdot
.14048 .43237 Mdot
.15044 .30246 Mdot
.15044 .62362 Mdot
.15044 .68496 Mdot
.18269 .30246 Mdot
.18269 .62362 Mdot
.18269 .68496 Mdot
.21494 .30246 Mdot
.12436 .32142 Mdot
.12436 .60467 Mdot
.12436 .66601 Mdot
.1566 .32142 Mdot
.20878 .70391 Mdot
.24102 .28351 Mdot
.24102 .70391 Mdot
.18269 .68496 Mdot
.21494 .30246 Mdot
.09211 .32142 Mdot
.09211 .60467 Mdot
.09211 .66601 Mdot
.12436 .32142 Mdot
.12436 .32142 Mdot
.12436 .38275 Mdot
.12436 .60467 Mdot
.12436 .66601 Mdot
.1566 .32142 Mdot
.1566 .38275 Mdot
.06602 .34037 Mdot
.06602 .40171 Mdot
.06602 .58572 Mdot
.06602 .34037 Mdot
.06602 .40171 Mdot
.06602 .58572 Mdot
.09827 .34037 Mdot
.09827 .34037 Mdot
.09827 .40171 Mdot
.64466 .34037 Mdot
.67691 .34037 Mdot
.67691 .64705 Mdot
.70915 .34037 Mdot
.70915 .64705 Mdot
.7414 .34037 Mdot
.7414 .40171 Mdot
.7414 .46304 Mdot
.7414 .52438 Mdot
.7414 .58572 Mdot
.7414 .64705 Mdot
.44357 .26455 Mdot
.44357 .72287 Mdot
.47582 .72287 Mdot
.97003 .46304 Mdot
.81966 .70391 Mdot
.58633 .32142 Mdot
.61857 .32142 Mdot
.61857 .66601 Mdot
.65082 .66601 Mdot
.41748 .2456 Mdot
.41748 .74182 Mdot
.52799 .30246 Mdot
.56024 .30246 Mdot
.56024 .68496 Mdot
.59248 .68496 Mdot
.97003 .46304 Mdot
.46966 .28351 Mdot
.5019 .28351 Mdot
.5019 .70391 Mdot
.53415 .70391 Mdot
.41748 .2456 Mdot
.41748 .74182 Mdot
.39139 .22665 Mdot
.39139 .76078 Mdot
.2932 .86449 Mdot
.23487 .84554 Mdot
.26711 .14188 Mdot
.26711 .84554 Mdot
.17653 .16083 Mdot
.20878 .16083 Mdot
.20878 .86449 Mdot
.20878 .82659 Mdot
.24102 .16083 Mdot
.24102 .16083 Mdot
.15044 .17979 Mdot
.18269 .17979 Mdot
.18269 .84554 Mdot
.38143 .19598 Mdot
.38143 .79144 Mdot
.35534 .21493 Mdot
.32925 .29522 Mdot
.32925 .6922 Mdot
.37146 .16531 Mdot
.37146 .82211 Mdot
.34538 .18426 Mdot
.34538 .80316 Mdot
.28704 .20322 Mdot
.31929 .20322 Mdot
.26095 .22217 Mdot
.26095 .28351 Mdot
.26095 .70391 Mdot
.2932 .22217 Mdot
.65462 .3097 Mdot
.68687 .3097 Mdot
.68687 .67772 Mdot
.71912 .3097 Mdot
.71912 .67772 Mdot
.75136 .3097 Mdot
.75136 .67772 Mdot
.47817 .95202 Mdot
.51041 .95202 Mdot
.45353 .23389 Mdot
.45353 .75354 Mdot
.48578 .23389 Mdot
.48578 .75354 Mdot
.51803 .23389 Mdot
.51803 .75354 Mdot
.55027 .75354 Mdot
.64701 .95202 Mdot
.85572 .49371 Mdot
.85572 .23389 Mdot
.85572 .79144 Mdot
.85572 .75354 Mdot
.85572 .6922 Mdot
.8818 .77249 Mdot
.82963 .25284 Mdot
.82963 .73458 Mdot
.82963 .77249 Mdot
.82963 .31418 Mdot
.82963 .67325 Mdot
.62092 .05435 Mdot
.59629 .29075 Mdot
.62854 .29075 Mdot
.62854 .69667 Mdot
.66078 .29075 Mdot
.66078 .69667 Mdot
.69303 .29075 Mdot
.69303 .69667 Mdot
.42745 .21493 Mdot
.42745 .77249 Mdot
.45969 .77249 Mdot
.82963 .51266 Mdot
.82963 .21493 Mdot
.82963 .25284 Mdot
.82963 .73458 Mdot
.82963 .77249 Mdot
.82963 .67325 Mdot
.53796 .27179 Mdot
.5702 .27179 Mdot
.5702 .71563 Mdot
.60245 .27179 Mdot
.60245 .71563 Mdot
.6347 .27179 Mdot
.6347 .71563 Mdot
.56259 .0354 Mdot
.56259 .95202 Mdot
.59484 .0354 Mdot
.59484 .95202 Mdot
.80354 .23389 Mdot
.80354 .75354 Mdot
.80354 .79144 Mdot
.47962 .25284 Mdot
.51187 .25284 Mdot
.51187 .73458 Mdot
.54411 .25284 Mdot
.54411 .73458 Mdot
.57636 .25284 Mdot
.57636 .73458 Mdot
.60861 .73458 Mdot
.50426 .97098 Mdot
.5365 .05435 Mdot
.5365 .97098 Mdot
.5365 .93307 Mdot
.5365 .97098 Mdot
.56875 .05435 Mdot
.77745 .77249 Mdot
.42745 .21493 Mdot
.42745 .77249 Mdot
.45208 .09226 Mdot
.40136 .19598 Mdot
.40136 .79144 Mdot
.59484 .95202 Mdot
.32925 .91412 Mdot
.3615 .0733 Mdot
.3615 .91412 Mdot
.39375 .0733 Mdot
.39375 .91412 Mdot
.42599 .0733 Mdot
.27092 .89516 Mdot
.30316 .09226 Mdot
.30316 .89516 Mdot
.30316 .83383 Mdot
.33541 .09226 Mdot
.33541 .89516 Mdot
.24483 .11121 Mdot
.24483 .87621 Mdot
.24483 .81487 Mdot
.27708 .17255 Mdot
.27708 .11121 Mdot
.27708 .87621 Mdot
.27708 .81487 Mdot
.30932 .11121 Mdot
.21874 .1915 Mdot
.21874 .13017 Mdot
.21874 .13017 Mdot
.21874 .79592 Mdot
.25099 .1915 Mdot
.25099 .1915 Mdot
.25099 .13017 Mdot
.25099 .13017 Mdot
.19265 .21046 Mdot
.67691 .82211 Mdot
.70915 .82211 Mdot
.70915 .82211 Mdot
.44357 .20322 Mdot
.47582 .20322 Mdot
.47582 .7842 Mdot
.50806 .20322 Mdot
.50806 .7842 Mdot
.54031 .20322 Mdot
.54031 .7842 Mdot
.84575 .16531 Mdot
.84575 .20322 Mdot
.84575 .82211 Mdot
.81966 .18426 Mdot
.65082 .80316 Mdot
.68306 .80316 Mdot
.41748 .18426 Mdot
.44973 .18426 Mdot
.44973 .80316 Mdot
.48197 .80316 Mdot
.81966 .18426 Mdot
.81966 .80316 Mdot
.81966 .84107 Mdot
.81966 .80316 Mdot
.59248 .24113 Mdot
.62473 .24113 Mdot
.76133 .82211 Mdot
.79357 .20322 Mdot
.79357 .16531 Mdot
.79357 .82211 Mdot
.79357 .82211 Mdot
.53415 .22217 Mdot
.5664 .22217 Mdot
.5664 .76525 Mdot
.59864 .22217 Mdot
.73524 .80316 Mdot
.73524 .84107 Mdot
.76749 .18426 Mdot
.76749 .80316 Mdot
.76749 .84107 Mdot
.41748 .18426 Mdot
.41748 .80316 Mdot
.44973 .80316 Mdot
.39139 .16531 Mdot
.39139 .22665 Mdot
.39139 .76078 Mdot
.39139 .82211 Mdot
.42364 .82211 Mdot
.3653 .2456 Mdot
.66694 .13464 Mdot
.66694 .85278 Mdot
.69919 .13464 Mdot
.69919 .13464 Mdot
.69919 .85278 Mdot
.69919 .85278 Mdot
.69919 .89069 Mdot
.46585 .17255 Mdot
.4981 .17255 Mdot
.4981 .81487 Mdot
.53034 .17255 Mdot
.64085 .15359 Mdot
.64085 .83383 Mdot
.64085 .87173 Mdot
.6731 .15359 Mdot
.6731 .87173 Mdot
.43976 .15359 Mdot
.47201 .15359 Mdot
.47201 .83383 Mdot
.8097 .15359 Mdot
.8097 .15359 Mdot
.61477 .85278 Mdot
.75136 .13464 Mdot
.78361 .13464 Mdot
.78361 .85278 Mdot
.55643 .1915 Mdot
.72528 .11569 Mdot
.72528 .15359 Mdot
.72528 .87173 Mdot
.75752 .15359 Mdot
.75752 .87173 Mdot
.40752 .15359 Mdot
.43976 .15359 Mdot
.43976 .83383 Mdot
.47201 .83383 Mdot
.6731 .87173 Mdot
.38143 .19598 Mdot
.38143 .79144 Mdot
.38143 .13464 Mdot
.38143 .85278 Mdot
.41367 .13464 Mdot
.41367 .85278 Mdot
.44592 .85278 Mdot
.35534 .21493 Mdot
.35534 .77249 Mdot
.35534 .15359 Mdot
.32925 .23389 Mdot
.65698 .92136 Mdot
.86568 .40171 Mdot
.86568 .46304 Mdot
.86568 .52438 Mdot
.86568 .26455 Mdot
.86568 .3638 Mdot
.86568 .72287 Mdot
.86568 .66153 Mdot
.86568 .72287 Mdot
.89177 .74182 Mdot
.83959 .28351 Mdot
.83959 .70391 Mdot
.83959 .28351 Mdot
.83959 .64258 Mdot
.63089 .08502 Mdot
.94394 .38275 Mdot
.63089 .94031 Mdot
.83959 .28351 Mdot
.83959 .482 Mdot
.83959 .54333 Mdot
.83959 .70391 Mdot
.83959 .64258 Mdot
.83959 .70391 Mdot
.57255 .92136 Mdot
.6048 .92136 Mdot
.54647 .9024 Mdot
.63089 .94031 Mdot
.46204 .12293 Mdot
.6048 .92136 Mdot
.37146 .10397 Mdot
.37146 .88345 Mdot
.40371 .10397 Mdot
.40371 .88345 Mdot
.43596 .10397 Mdot
.31313 .86449 Mdot
.34538 .12293 Mdot
.34538 .86449 Mdot
.28704 .14188 Mdot
.31929 .14188 Mdot
.45353 .23389 Mdot
.48578 .23389 Mdot
.48578 .75354 Mdot
.51803 .23389 Mdot
.51803 .75354 Mdot
.55027 .75354 Mdot
.85572 .23389 Mdot
.85572 .79144 Mdot
.8818 .21493 Mdot
.8818 .77249 Mdot
.42745 .21493 Mdot
.45969 .77249 Mdot
.82963 .21493 Mdot
.82963 .77249 Mdot
.82963 .77249 Mdot
.60245 .27179 Mdot
.6347 .27179 Mdot
.80354 .23389 Mdot
.80354 .79144 Mdot
.54411 .25284 Mdot
.57636 .25284 Mdot
.57636 .73458 Mdot
.77745 .77249 Mdot
.42745 .21493 Mdot
.42745 .77249 Mdot
.45969 .77249 Mdot
.40136 .19598 Mdot
.40136 .79144 Mdot
.67691 .82211 Mdot
.70915 .82211 Mdot
.70915 .82211 Mdot
.47582 .20322 Mdot
.50806 .20322 Mdot
.50806 .7842 Mdot
.54031 .20322 Mdot
.84575 .16531 Mdot
.84575 .82211 Mdot
.81966 .84107 Mdot
.65082 .80316 Mdot
.44973 .18426 Mdot
.48197 .80316 Mdot
.81966 .18426 Mdot
.81966 .18426 Mdot
.81966 .84107 Mdot
.79357 .16531 Mdot
.79357 .82211 Mdot
.5664 .22217 Mdot
.73524 .84107 Mdot
.76749 .18426 Mdot
.76749 .84107 Mdot
.41748 .18426 Mdot
.44973 .18426 Mdot
.44973 .80316 Mdot
.48197 .80316 Mdot
.39139 .16531 Mdot
.39139 .82211 Mdot
.39139 .16531 Mdot
.39139 .82211 Mdot
.42364 .82211 Mdot
.87564 .49371 Mdot
.87564 .43237 Mdot
.87564 .33313 Mdot
.87564 .6922 Mdot
.96007 .59295 Mdot
.64085 .05435 Mdot
.6731 .05435 Mdot
.95391 .41342 Mdot
.95391 .35208 Mdot
.6731 .05435 Mdot
.55643 .15359 Mdot
.75752 .63534 Mdot
.90173 .51266 Mdot
.87564 .59295 Mdot
.4981 .17255 Mdot
.73143 .61638 Mdot
.4981 .85278 Mdot
.53034 .85278 Mdot
.47201 .83383 Mdot
.76749 .38275 Mdot
.76749 .60467 Mdot
.76749 .66601 Mdot
.7414 .40171 Mdot
.7414 .58572 Mdot
.7414 .64705 Mdot
.40987 .02368 Mdot
.40987 .96374 Mdot
.44211 .02368 Mdot
.35153 .04264 Mdot
.35153 .94478 Mdot
.38378 .04264 Mdot
.77745 .35208 Mdot
.77745 .41342 Mdot
.77745 .63534 Mdot
.77745 .574 Mdot
.85572 .59295 Mdot
.75136 .37104 Mdot
.75136 .43237 Mdot
.75136 .55505 Mdot
.38759 .93307 Mdot
.41983 .05435 Mdot
.41983 .93307 Mdot
.45208 .05435 Mdot
.3615 .91412 Mdot
.39375 .0733 Mdot
.51422 .12293 Mdot
.54647 .12293 Mdot
.57871 .9024 Mdot
.78742 .38275 Mdot
.86568 .56229 Mdot
.86568 .62362 Mdot
.48813 .14188 Mdot
.48813 .10397 Mdot
.52038 .10397 Mdot
.46204 .12293 Mdot
.48813 .88345 Mdot
.52038 .88345 Mdot
.4298 .9024 Mdot
.46204 .86449 Mdot
.46204 .9024 Mdot
.40371 .88345 Mdot
.43596 .88345 Mdot
.76749 .32142 Mdot
.76749 .44409 Mdot
.76749 .482 Mdot
.76749 .54333 Mdot
.76749 .66601 Mdot
.7414 .34037 Mdot
.7414 .46304 Mdot
.7414 .52438 Mdot
.7414 .64705 Mdot
.74521 .29075 Mdot
.74521 .69667 Mdot
.77745 .51266 Mdot
.77745 .25284 Mdot
.77745 .29075 Mdot
.77745 .41342 Mdot
.77745 .574 Mdot
.77745 .69667 Mdot
.77745 .73458 Mdot
.77745 .35208 Mdot
.56875 .05435 Mdot
.57636 .73458 Mdot
.60861 .73458 Mdot
.60861 .73458 Mdot
.8818 .21493 Mdot
.8818 .25284 Mdot
.8818 .77249 Mdot
.85572 .23389 Mdot
.85572 .33313 Mdot
.68687 .27179 Mdot
.68687 .71563 Mdot
.71912 .3097 Mdot
.71912 .67772 Mdot
.71912 .27179 Mdot
.71912 .71563 Mdot
.75136 .49371 Mdot
.75136 .3097 Mdot
.75136 .43237 Mdot
.75136 .55505 Mdot
.75136 .67772 Mdot
.75136 .37104 Mdot
.85572 .23389 Mdot
.66078 .25284 Mdot
.66078 .29075 Mdot
.66078 .69667 Mdot
.66078 .73458 Mdot
.69303 .25284 Mdot
.69303 .29075 Mdot
.69303 .69667 Mdot
.69303 .73458 Mdot
.60245 .75354 Mdot
.6347 .27179 Mdot
.6347 .71563 Mdot
.6347 .75354 Mdot
.47817 .0733 Mdot
.51041 .0733 Mdot
.38759 .93307 Mdot
.41983 .05435 Mdot
.41983 .93307 Mdot
.45208 .05435 Mdot
.45208 .09226 Mdot
.45208 .93307 Mdot
.3615 .91412 Mdot
.39375 .0733 Mdot
.39375 .91412 Mdot
.42599 .0733 Mdot
.73524 .80316 Mdot
.76749 .80316 Mdot
.53415 .80316 Mdot
.5664 .22217 Mdot
.5664 .76525 Mdot
.5664 .80316 Mdot
.59864 .22217 Mdot
.59864 .22217 Mdot
.59864 .80316 Mdot
.70915 .82211 Mdot
.70915 .7842 Mdot
.50806 .7842 Mdot
.54031 .7842 Mdot
.65082 .22217 Mdot
.68306 .22217 Mdot
.68306 .80316 Mdot
.59248 .20322 Mdot
.59248 .7842 Mdot
.62473 .24113 Mdot
.62473 .20322 Mdot
.62473 .7842 Mdot
.54031 .7842 Mdot
.72528 .15359 Mdot
.75752 .15359 Mdot
.75752 .87173 Mdot
.52418 .15359 Mdot
.52418 .83383 Mdot
.55643 .15359 Mdot
.55643 .1915 Mdot
.55643 .83383 Mdot
.58868 .15359 Mdot
.69919 .13464 Mdot
.69919 .17255 Mdot
.4981 .17255 Mdot
.4981 .81487 Mdot
.4981 .85278 Mdot
.53034 .17255 Mdot
.53034 .85278 Mdot
.6731 .15359 Mdot
.47201 .83383 Mdot
.58252 .17255 Mdot
.61477 .17255 Mdot
.53034 .17255 Mdot
.78742 .54333 Mdot
.89177 .28351 Mdot
.89177 .64258 Mdot
.89177 .70391 Mdot
.89177 .74182 Mdot
.91786 .26455 Mdot
.91786 .72287 Mdot
.86568 .72287 Mdot
.86568 .30246 Mdot
.86568 .3638 Mdot
.86568 .26455 Mdot
.86568 .30246 Mdot
.86568 .66153 Mdot
.86568 .62362 Mdot
.86568 .72287 Mdot
.83959 .28351 Mdot
.83959 .64258 Mdot
.48813 .10397 Mdot
.52038 .10397 Mdot
.4298 .9024 Mdot
.46204 .12293 Mdot
.46204 .9024 Mdot
.40371 .88345 Mdot
.74521 .77249 Mdot
.77745 .77249 Mdot
.57636 .73458 Mdot
.71912 .75354 Mdot
.66078 .25284 Mdot
.69303 .25284 Mdot
.60245 .75354 Mdot
.6347 .27179 Mdot
.6347 .75354 Mdot
.73524 .18426 Mdot
.76749 .18426 Mdot
.53415 .80316 Mdot
.5664 .22217 Mdot
.5664 .80316 Mdot
.70915 .20322 Mdot
.50806 .7842 Mdot
.59248 .20322 Mdot
.62473 .20322 Mdot
.90173 .41342 Mdot
.90173 .61191 Mdot
.90173 .31418 Mdot
.90173 .67325 Mdot
.92782 .6922 Mdot
.87564 .33313 Mdot
.87564 .59295 Mdot
.87564 .33313 Mdot
.87564 .6922 Mdot
.58252 .13464 Mdot
.58252 .85278 Mdot
.61477 .13464 Mdot
.61477 .13464 Mdot
.61477 .85278 Mdot
.92782 .49371 Mdot
.92782 .53162 Mdot
.92782 .59295 Mdot
.96007 .49371 Mdot
.96007 .59295 Mdot
.90173 .51266 Mdot
.90173 .41342 Mdot
.90173 .574 Mdot
.55643 .15359 Mdot
.55643 .87173 Mdot
.75752 .87173 Mdot
.90173 .51266 Mdot
.90173 .574 Mdot
.64085 .15359 Mdot
.55643 .87173 Mdot
.53034 .85278 Mdot
.79357 .62362 Mdot
.97003 .46304 Mdot
.76749 .60467 Mdot
.52654 .02368 Mdot
.40987 .96374 Mdot
.44211 .02368 Mdot
.80354 .39447 Mdot
.80354 .65429 Mdot
.80354 .59295 Mdot
.77745 .41342 Mdot
.77745 .63534 Mdot
.77745 .574 Mdot
.5365 .05435 Mdot
.44592 .95202 Mdot
.47817 .0354 Mdot
.47817 .95202 Mdot
.51041 .0354 Mdot
.41983 .93307 Mdot
.45208 .05435 Mdot
.57255 .10397 Mdot
.57255 .88345 Mdot
.6048 .10397 Mdot
.6048 .10397 Mdot
.6048 .88345 Mdot
.6048 .92136 Mdot
.8135 .3638 Mdot
.8135 .56229 Mdot
.8135 .62362 Mdot
.91786 .56229 Mdot
.9501 .56229 Mdot
.89177 .44409 Mdot
.89177 .482 Mdot
.89177 .54333 Mdot
.74756 .9024 Mdot
.54647 .08502 Mdot
.54647 .12293 Mdot
.54647 .9024 Mdot
.57871 .9024 Mdot
.78742 .38275 Mdot
.78742 .54333 Mdot
.89177 .54333 Mdot
.52038 .10397 Mdot
.63089 .12293 Mdot
.51422 .9024 Mdot
.54647 .9024 Mdot
.48813 .88345 Mdot
.48813 .92136 Mdot
.52038 .88345 Mdot
.52038 .92136 Mdot
.46204 .9024 Mdot
.79357 .46304 Mdot
.79357 .30246 Mdot
.79357 .68496 Mdot
.76749 .32142 Mdot
.76749 .44409 Mdot
.76749 .482 Mdot
.76749 .66601 Mdot
.7414 .46304 Mdot
.77129 .27179 Mdot
.77129 .71563 Mdot
.77129 .75354 Mdot
.80354 .49371 Mdot
.80354 .53162 Mdot
.80354 .43237 Mdot
.80354 .27179 Mdot
.80354 .23389 Mdot
.80354 .71563 Mdot
.80354 .75354 Mdot
.80354 .33313 Mdot
.80354 .65429 Mdot
.56259 .0733 Mdot
.59484 .0354 Mdot
.59484 .0733 Mdot
.6347 .75354 Mdot
.74521 .25284 Mdot
.74521 .29075 Mdot
.74521 .69667 Mdot
.74521 .73458 Mdot
.74521 .73458 Mdot
.74521 .77249 Mdot
.77745 .51266 Mdot
.77745 .25284 Mdot
.77745 .29075 Mdot
.77745 .41342 Mdot
.77745 .69667 Mdot
.77745 .73458 Mdot
.77745 .73458 Mdot
.77745 .77249 Mdot
.77745 .35208 Mdot
.77745 .63534 Mdot
.5365 .05435 Mdot
.56875 .05435 Mdot
.68687 .75354 Mdot
.71912 .27179 Mdot
.71912 .23389 Mdot
.71912 .71563 Mdot
.71912 .75354 Mdot
.66078 .73458 Mdot
.66078 .77249 Mdot
.69303 .25284 Mdot
.69303 .73458 Mdot
.69303 .73458 Mdot
.69303 .77249 Mdot
.50426 .05435 Mdot
.5365 .05435 Mdot
.5365 .93307 Mdot
.44592 .95202 Mdot
.47817 .0733 Mdot
.47817 .0354 Mdot
.47817 .95202 Mdot
.51041 .0733 Mdot
.51041 .0354 Mdot
.51041 .95202 Mdot
.41983 .93307 Mdot
.45208 .05435 Mdot
.45208 .93307 Mdot
.76133 .20322 Mdot
.79357 .20322 Mdot
.59248 .82211 Mdot
.62473 .20322 Mdot
.62473 .82211 Mdot
.62473 .7842 Mdot
.62473 .82211 Mdot
.73524 .22217 Mdot
.73524 .18426 Mdot
.73524 .22217 Mdot
.76749 .22217 Mdot
.76749 .18426 Mdot
.76749 .22217 Mdot
.5664 .80316 Mdot
.59864 .80316 Mdot
.67691 .20322 Mdot
.70915 .20322 Mdot
.70915 .7842 Mdot
.65082 .18426 Mdot
.65082 .22217 Mdot
.65082 .80316 Mdot
.68306 .22217 Mdot
.68306 .80316 Mdot
.68306 .80316 Mdot
.59864 .80316 Mdot
.78361 .85278 Mdot
.58252 .13464 Mdot
.58252 .85278 Mdot
.61477 .13464 Mdot
.61477 .17255 Mdot
.61477 .13464 Mdot
.61477 .85278 Mdot
.61477 .85278 Mdot
.55643 .15359 Mdot
.55643 .83383 Mdot
.55643 .87173 Mdot
.58868 .15359 Mdot
.66694 .17255 Mdot
.69919 .17255 Mdot
.53034 .85278 Mdot
.64085 .15359 Mdot
.64085 .15359 Mdot
.64085 .83383 Mdot
.6731 .15359 Mdot
.58868 .15359 Mdot
.8135 .46304 Mdot
.8135 .30246 Mdot
.8135 .56229 Mdot
.8135 .30246 Mdot
.8135 .3638 Mdot
.8135 .62362 Mdot
.57255 .10397 Mdot
.6048 .10397 Mdot
.91786 .30246 Mdot
.91786 .26455 Mdot
.91786 .30246 Mdot
.91786 .3638 Mdot
.91786 .62362 Mdot
.9501 .62362 Mdot
.89177 .28351 Mdot
.89177 .38275 Mdot
.78742 .54333 Mdot
.78742 .38275 Mdot
.54647 .08502 Mdot
.89177 .28351 Mdot
.89177 .38275 Mdot
.89177 .64258 Mdot
.54647 .08502 Mdot
.54647 .9024 Mdot
.48813 .92136 Mdot
.52038 .10397 Mdot
.52038 .92136 Mdot
.46204 .9024 Mdot
.80354 .23389 Mdot
.6347 .75354 Mdot
.74521 .25284 Mdot
.77745 .25284 Mdot
.77745 .25284 Mdot
.71912 .23389 Mdot
.71912 .75354 Mdot
.66078 .77249 Mdot
.69303 .25284 Mdot
.69303 .77249 Mdot
.69303 .77249 Mdot
.79357 .82211 Mdot
.59248 .82211 Mdot
.62473 .20322 Mdot
.62473 .82211 Mdot
.62473 .82211 Mdot
.5664 .80316 Mdot
.67691 .20322 Mdot
.70915 .20322 Mdot
.65082 .18426 Mdot
.65082 .18426 Mdot
.65082 .80316 Mdot
.92782 .43237 Mdot
.92782 .39447 Mdot
.92782 .59295 Mdot
.92782 .33313 Mdot
.92782 .65429 Mdot
.92782 .6922 Mdot
.92782 .65429 Mdot
.96007 .43237 Mdot
.96007 .59295 Mdot
.90173 .41342 Mdot
.90173 .35208 Mdot
.90173 .67325 Mdot
.90173 .41342 Mdot
.90173 .574 Mdot
.90173 .61191 Mdot
.90173 .31418 Mdot
.90173 .35208 Mdot
.90173 .67325 Mdot
.87564 .59295 Mdot
.87564 .33313 Mdot
.97003 .46304 Mdot
.82963 .41342 Mdot
.82963 .574 Mdot
.82963 .61191 Mdot
.80354 .43237 Mdot
.80354 .39447 Mdot
.80354 .59295 Mdot
.77745 .41342 Mdot
.83959 .38275 Mdot
.83959 .44409 Mdot
.83959 .54333 Mdot
.83959 .64258 Mdot
.8135 .3638 Mdot
.8135 .46304 Mdot
.8135 .56229 Mdot
.82963 .51266 Mdot
.82963 .31418 Mdot
.82963 .35208 Mdot
.80354 .49371 Mdot
.80354 .53162 Mdot
.80354 .33313 Mdot
.77745 .51266 Mdot
.83959 .38275 Mdot
.83959 .482 Mdot
.83959 .54333 Mdot
.83959 .28351 Mdot
.83959 .38275 Mdot
.8135 .46304 Mdot
.8135 .56229 Mdot
.8135 .3638 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[141]:=",
  ImageSize->{288, 286.438},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00017Q000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002AOol00`00Oomoo`2<Ool0089oo`D0009oo`8000Ioo`03001oogoo
08aoo`00Q7oo00D007ooOomoo`00009oo`03001oogoo00=oo`03001oogoo08aoo`00Q7oo00<007oo
Ool017oo00<007ooOol00goo0P00SGoo001lOol40004Ool00`00Oomoo`02Ool20006Ool00`00Oomo
o`2<Ool007Ioo`<000Ioo`<0009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00=oo`<0
00=oo`<0081oo`00MGoo1@0017oo1`0017oo0`001Goo00<007ooOol00Woo1@0000=oo`0000000`00
Ogoo001eOol50004Ool5000>Ool00`00Oomoo`02Ool500000goo00000003001oOol007Eoo`D000Ao
o`D000Moo`<000Aoo`03001oo`0000L00003Ool0000000H000Ioo`<007=oo`00MWoo0`001Woo0`00
1goo1@000goo2@000goo200017oo1@00LWoo001VOol30006Ool3000GOol50003Ool60009Ool50004
Ool5001bOol006Eoo`D000Aoo`D001Ioo`D000=oo`H000Uoo`D000Aoo`D0079oo`00IGoo1@0017oo
1@005goo0`0017oo1@002goo0`001Woo0`00Lgoo001UOol50004Ool50006Ool30006Ool3000<Ool3
0006Ool30006Ool3000<Ool30002Ool30006Ool3001MOol006Ioo`<000Ioo`<000Ioo`D000Aoo`D0
00Yoo`D000Aoo`D000Aoo`D000Yoo`X000Aoo`D005aoo`00EWoo0`001Woo0`005Woo1@0017oo1@00
2Woo1@0017oo1@0017oo1@002Woo2P0017oo1@00G7oo001EOol50004Ool5000EOol50004Ool5000:
Ool50004Ool50004Ool5000:Ool:0004Ool5001LOol005Eoo`D000Aoo`D001Ioo`<000Ioo`<000ao
o`<000Ioo`<000Ioo`<000aoo`<0009oo`<000Ioo`<005eoo`00EGoo1@0017oo1@00;Woo00<007oo
Ool0S7oo001FOol30006Ool30007Ool30006Ool30006Ool3000<Ool30004Ool00`00Ool00002000;
Ool30006Ool3000KOol3001EOol006Qoo`D000Aoo`D000Aoo`D000Yoo`D000=oo`H000Uoo`D000Ao
o`D001Uoo`D005Aoo`00CWoo0`005goo1@0017oo1@0017oo1@002Woo1@000goo1P002Goo1@0017oo
1@006Goo1@00E7oo001=Ool5000FOol50004Ool50004Ool5000:Ool50003Ool60006Ool80004Ool5
0007Ool30006Ool30006Ool80006Ool30018Ool004eoo`D001Moo`<000Ioo`<000Ioo`<000aoo`<0
00Aoo`03001oo`00008000Ioo`P000Ioo`<000Moo`D000Aoo`D000Ioo`P000Aoo`D004Moo`00CGoo
1@001Woo0`001Woo0`007Woo0`0037oo00<007ooOol027oo1@004goo1@0017oo1@002Goo1@0017oo
1@00Agoo001>Ool30006Ool50004Ool5000LOol5000;Ool00`00Oomoo`08Ool5000COol50004Ool5
0009Ool50004Ool50017Ool005Moo`D000Aoo`D001aoo`D000]oo`03001oogoo00Uoo`<001Eoo`<0
00Ioo`<000]oo`<000Ioo`<004Qoo`00Egoo1@0017oo1@001goo0`001Woo0`001Woo20001Woo0`00
0Woo00@007ooOomoo`<000aoo`<000Ioo`<000aoo`<000Ioo`<000aoo`<000Ioo`<0041oo`00F7oo
0`001Woo0`001goo1@0017oo1@0017oo20001Woo1@0000Aoo`00Oomoo`D000Yoo`D000Aoo`D000Yo
o`D000Aoo`D000Yoo`D000Aoo`D003moo`00B7oo0`001Woo0`001Woo0`003Woo1@0017oo1@0017oo
1@002Goo1@0000Aoo`00Oomoo`D000Yoo`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D000Aoo`D003mo
o`00Agoo1@0017oo1@0017oo1@003Goo1@0017oo1@0017oo1@002Goo1@0000Aoo`00001oo`D000Yo
o`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D000Aoo`D003moo`00Agoo1@0017oo1@0017oo1@003Woo
0`001Woo0`001Woo0`002goo0`000Woo00@007ooOomoo`<000aoo`<000Ioo`<000aoo`<000Ioo`<0
00Moo`<0009oo`<000Ioo`<0041oo`00Agoo1@0017oo1@0017oo1@00<goo00<007ooOol0>Woo1@00
CGoo0018Ool30006Ool30006Ool30007Ool3000EOol30006Ool30009Ool00`00Oomoo`030006Ool3
000EOol3000FOol5001=Ool006=oo`D001=oo`D000Aoo`D000Qoo`03001oo`0000@000Aoo`D001=o
o`D001Eoo`D004eoo`00>goo0`000goo0`001Woo0`005Woo1@004goo1@0017oo1@0027oo00<007oo
0000100017oo1@004goo1@005Woo0`00CWoo000jOol500000goo000000030004Ool5000EOol50006
Ool30006Ool300000goo000000030004Ool50008Ool00`00Ool000040004Ool50006Ool30006Ool3
00000goo000000030006Ool30006Ool3000;Ool30006Ool3000nOol003Yoo`D00003Ool0000000<0
00Aoo`D001Ioo`<000Ioo`D000Aoo`D00004Ool000000006Ool30009Ool00`00Oomoo`030006Ool3
0006Ool50004Ool5000017oo000000001Woo1@0017oo1@002Goo1@0017oo1@00?Goo000jOol50000
0goo000000030004Ool80003Ool30006Ool3000=Ool50004Ool5000AOol30002Ool00`00Oomoo`0B
Ool50004Ool5000:Ool50004Ool50009Ool50004Ool5000mOol003]oo`<000=oo`<000Ioo`P00003
Ool0000000<000Aoo`D000aoo`D000Aoo`D0011oo`D00003Ool0000001=oo`D000Aoo`D000Yoo`D0
00Aoo`D000Uoo`D000Aoo`D003eoo`00CGoo1@0000=oo`0000000`0017oo1@003Goo0`001Woo0`00
4Goo1@0000=oo`00Ool057oo0`001Woo0`0037oo0`001Woo0`002goo0`001Woo0`00?Woo001=Ool5
00000goo000000030004Ool80003Ool3000<Ool30006Ool30006Ool800000goo001oo`04Ool30006
Ool30006Ool3000;Ool30006Ool3000<Ool30006Ool3000<Ool3000fOol004ioo`<000=oo`<000Io
o`P00003Ool0000000<000Yoo`D000Aoo`D000Aoo`P0009oo`03001oogoo009oo`D000Aoo`D000Ao
o`D000Uoo`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D003Eoo`00=Goo0`001Woo0`001Woo0`005Woo
1@0000=oo`0000000`002Woo1@0017oo1@0017oo1@001Goo00<007ooOol00Woo1@0017oo1@0017oo
1@002Goo1@0017oo1@002Woo1@0017oo1@002Woo1@00=Goo000dOol50004Ool50004Ool5000EOol5
00000goo00000003000:Ool50004Ool50004Ool50005Ool00`00Oomoo`02Ool50004Ool50004Ool5
0009Ool50004Ool5000:Ool50004Ool5000:Ool5000eOol003Aoo`D000Aoo`D000Aoo`D001Ioo`<0
00=oo`<0009oo`<0009oo`<0009oo`<000Ioo`<000Ioo`<000Ioo`03001oogoo00=oo`<000Ioo`<0
00Ioo`<000]oo`<000Ioo`<000aoo`<000Ioo`<000Moo`<0009oo`<000Moo`<002aoo`00=7oo1@00
17oo1@0017oo1@0087oo2P003Goo1@000Woo0P001Woo00<007ooOol0CGoo1@002Woo1@00:goo000e
Ool30006Ool30006Ool30007Ool30006Ool3000>Ool:000?Ool00`00Ool000020002Ool01000Oomo
ogoo0`001Woo0`0037oo0`001Woo0`0037oo0`001Woo0`005Woo1@002Woo1@00:goo001@Ool50004
Ool5000=Ool:000?Ool6000017oo001oogoo1@0017oo1@002Woo1@0017oo1@002Woo1@0017oo1@00
5Goo1@002Woo1@00:goo000]Ool30007Ool3000FOol50004Ool5000>Ool30002Ool30008Ool40004
Ool6000017oo001oogoo1@0017oo1@002Woo1@0017oo1@002Woo1@0017oo1@005Woo0`0037oo0`00
;7oo000/Ool50005Ool5000EOol50004Ool50006Ool3000BOol30006Ool8000017oo001oogoo1@00
17oo1@002Woo1@0017oo1@001Woo0`0000=oo`0000000`0017oo1@001Woo0`001Woo0`0037oo0`00
<goo000/Ool50005Ool5000FOol30006Ool30006Ool5000@Ool50004Ool:0004Ool30006Ool3000<
Ool30006Ool30006Ool5000017oo000000001Woo0`001Woo1@0017oo1@002Woo1@00<Woo000/Ool5
0005Ool50006Ool30006Ool3000FOol5000@Ool50004Ool5000;Ool00`00Oomoo`0<Ool3000FOol5
000COol50004Ool5000:Ool5000bOol002eoo`<000Moo`<000Ioo`D000Aoo`D001Eoo`D000Ioo`<0
00=oo`<00003Ool0000000<000Aoo`D000]oo`03001oogoo00]oo`D001Eoo`D001=oo`D000Aoo`D0
00Yoo`D0039oo`00@7oo1@0017oo1@005Woo0`001Woo1@0000=oo`0000000`0000Aoo`00000000Io
o`<000aoo`03001oogoo00]oo`D001Ioo`<001Eoo`<000Ioo`<000aoo`<003=oo`00@7oo1@0017oo
1@001Woo0`001Woo0`003Goo1@0000=oo`0000000`0027oo0`001Woo0`001Goo10001Woo0`0000=o
o`0000000`001Woo0`001Woo0`002goo0`001goo0`002goo0`001Woo0`0037oo0`00;7oo0011Ool3
0006Ool30006Ool50004Ool5000<Ool500000goo000000030007Ool50004Ool50004Ool50004Ool5
000017oo000000001Woo1@0017oo1@002Goo1@001Goo1@002Goo1@0017oo1@002Woo1@00:goo000[
Ool30006Ool30002Ool3000GOol50004Ool5000=Ool30003Ool30008Ool50004Ool50004Ool50004
Ool5000:Ool50004Ool50009Ool50005Ool50009Ool50004Ool5000:Ool5000[Ool002Yoo`D000Ao
o`X001Ioo`D000Aoo`D001ioo`D000Aoo`D000Aoo`D000Aoo`D000Yoo`D000Aoo`D000Uoo`D000Eo
o`D000Uoo`D000Aoo`D000Yoo`D002]oo`00:Woo1@0017oo2P005goo0`001Woo0`001goo0`004Goo
0`000Woo0`001Woo0`001Goo10001Woo0`0037oo0`001Woo0`002goo0`001goo0`002goo0`001Woo
0`001goo0`000Woo0`001goo0`008Woo000ZOol50004Ool:000YOol5000?Ool5000BOol00`00Oomo
o`1GOol5000:Ool5000QOol002]oo`<000Ioo`<0009oo`<0009oo`<000Ioo`<000=oo`<000Ioo`<0
00eoo`D000moo`D0019oo`03001oogoo00Eoo`<000Ioo`<000Ioo`<000aoo`<000Ioo`<000aoo`<0
00Ioo`<000eoo`D000Yoo`D0025oo`00?Goo1@0017oo1@0000=oo`0000000`0017oo1@0037oo1@00
1Woo0`001Woo1@004Woo00<007ooOol017oo1@0017oo1@0017oo1@002Woo1@0017oo1@002Woo1@00
17oo1@0037oo1@002Woo1@008Goo000SOol3000GOol50004Ool500000goo000000030004Ool5000=
Ool30006Ool50006Ool3000COol00`00Oomoo`04Ool50004Ool50004Ool5000:Ool50004Ool5000:
Ool50004Ool5000=Ool3000<Ool3000ROol0029oo`D001Ioo`D000Aoo`D00003Ool0000000<000Ao
o`P000=oo`<000eoo`D000ioo`<000Ioo`<0009oo`04001oogooOol80004Ool50004Ool5000:Ool5
0004Ool50006Ool300000goo000000030004Ool50006Ool3000<Ool3000YOol0029oo`D001Moo`<0
00Ioo`<000=oo`<000Ioo`P00003Ool0000000<000aoo`D000eoo`D000Aoo`D00004Ool007ooOol8
0006Ool30006Ool3000<Ool30006Ool30006Ool5000017oo000000001Woo0`001Woo1@002Woo1@00
:7oo000ROol50006Ool30007Ool3000OOol500000goo00000003000=Ool3000>Ool50004Ool50000
17oo000007oo1@004Goo0`001Woo0`005Woo1@004goo1@002Woo1@00:7oo000SOol30006Ool50005
Ool5000NOol500000goo000000060003Ool3000<Ool30006Ool50004Ool5000017oo001oogoo1@00
47oo1@0017oo1@005Goo1@004goo1@002Woo1@00:7oo000/Ool50005Ool5000OOol30003Ool80000
0goo00000003000:Ool50006Ool30006Ool30002Ool01000Oomoogoo0`004Goo1@0017oo1@005Woo
0`005Goo0`0037oo0`00:Goo000/Ool50005Ool50006Ool30006Ool30006Ool3000=Ool500000goo
00000003000:Ool5000=Ool30004Ool00`00Ool000020006Ool30006Ool300000goo000000030004
Ool50006Ool30006Ool3000<Ool30006Ool3000;Ool3000<Ool3000ROol002eoo`<000Moo`<000Io
o`D000Aoo`D000Aoo`D000aoo`D00003Ool0000000H000Moo`D000aoo`D000=oo`H000Aoo`D000Ao
o`D00004Ool000000006Ool30006Ool50004Ool5000:Ool50004Ool50009Ool5000:Ool5000QOol0
01eoo`<000Ioo`<001Moo`D000Aoo`D000Aoo`D000eoo`<000=oo`P000Moo`<000eoo`D000=oo`H0
00Aoo`D000Aoo`D001=oo`D000Aoo`D000Yoo`D000Aoo`D000Uoo`D000Yoo`D0025oo`0077oo1@00
17oo1@005Woo1@0017oo1@0017oo1@001Woo0`003Goo1@003Woo0`001Woo1@000goo1P0017oo1@00
17oo1@004goo1@0017oo1@002Woo1@0017oo1@002Goo1@001goo20001Woo0`0067oo000LOol50004
Ool5000GOol30006Ool30006Ool30006Ool5000<Ool5000=Ool50006Ool30004Ool00`00Ool00002
0006Ool30006Ool3000EOol30006Ool3000<Ool30006Ool3000;Ool30007Ool80006Ool5000GOol0
01aoo`D000Aoo`D0039oo`D000eoo`<000ioo`D000eoo`03001oogoo069oo`D000Uoo`D001Moo`00
7Goo0`001Woo0`000Woo0`001Woo0`000Woo0`001Woo0`005goo1@007Woo1@003Goo0P001goo0`00
1Woo0`001goo0`001Woo0`002goo0`001Woo0`0037oo0`001Woo0`003Woo1@002Goo1@005goo000Z
Ool50004Ool:0004Ool5000GOol30007Ool3000<Ool30007Ool3000>Ool00`00Oomoo`05Ool50004
Ool50005Ool50004Ool50009Ool50004Ool5000:Ool50004Ool5000>Ool3000;Ool3000HOol002Yo
o`D000Aoo`X000Aoo`D0021oo`D000Yoo`D001Moo`03001oogoo00Eoo`D000Aoo`D000Eoo`D000Ao
o`D000Uoo`D000Aoo`D000Yoo`D000Aoo`D003Moo`00:Woo1@0017oo2P0017oo1@0000Aoo`000000
00=oo`<000Ioo`<000eoo`D000Yoo`D000eoo`<000Ioo`<000Ioo`D000Aoo`D000Eoo`D000Aoo`D0
00Uoo`D000Aoo`D000Yoo`D000Aoo`D000Ioo`<000aoo`<001moo`00:goo0`001Woo0`000Woo0`00
1Woo0`0000=oo`0000000`0000=oo`0000000`0017oo1@0037oo1@002Woo1@0037oo1@0017oo1@00
1Woo0`001Woo0`001goo0`001Woo0`002goo0`001Woo0`0037oo0`001Woo0`001Woo1@002Woo1@00
7Woo000JOol30006Ool3000POol500000goo000000030004Ool5000=Ool3000<Ool3000=Ool50004
Ool5000GOol30006Ool30006Ool30006Ool3000<Ool30006Ool3000=Ool5000:Ool5000NOol001Uo
o`D000Aoo`D001moo`D00003Ool0000000<000Aoo`P000=oo`<000]oo`<000aoo`<000Ioo`D000Ao
o`D001Ioo`D000Aoo`D000Aoo`D000Aoo`D000Yoo`D000Aoo`D000aoo`D000Yoo`D001ioo`006Goo
1@0017oo1@0087oo0`000goo0`001Woo200000=oo`0000000`002Goo1@002Woo1@001Woo0`001Woo
0`005goo1@0017oo1@0017oo1@0017oo1@002Woo1@0017oo1@003Goo0`0037oo0`007goo000IOol5
0004Ool50006Ool30007Ool30006Ool3000FOol500000goo000000030009Ool5000:Ool5000@Ool0
0`00Oomoo`04Ool30006Ool30006Ool50004Ool50004Ool50004Ool5000:Ool50004Ool80003Ool3
000<Ool3000;Ool3000HOol001Yoo`<000Ioo`<000Ioo`D000Eoo`D000Aoo`D001Eoo`D00003Ool0
000000H000Ioo`D00004Ool000000006Ool5000@Ool20004Ool50004Ool50006Ool30006Ool30006
Ool30006Ool3000<Ool30006Ool800000goo00000003000:Ool50009Ool5000GOol001=oo`<001Io
o`D000Eoo`D000Aoo`D001Ioo`<000=oo`P000Ioo`<00003Ool0000000<000Ioo`<0015oo`03001o
ogoo00=oo`D000Aoo`D001Ioo`<000Ioo`<000Ioo`<000Ioo`<000Qoo`D00003Ool0000000<000Yo
o`D000Uoo`D001Moo`004Woo1@005Goo1@001Goo1@0017oo1@001Woo0`001Woo0`003Goo1@002Woo
1@003Goo0`001Woo0`0000=oo`00Ool017oo1@0017oo1@005Goo1@0017oo1@0017oo1@0017oo1@00
1goo1@0000=oo`0000001P001goo1@001Woo20005goo000BOol5000FOol30007Ool30006Ool30006
Ool50004Ool5000<Ool5000:Ool5000<Ool50004Ool60006Ool30006Ool3000FOol50004Ool50004
Ool50004Ool50008Ool30003Ool80007Ool30006Ool8000HOol0019oo`D000Ioo`<000Ioo`<000Io
o`<001Moo`D000Aoo`D000eoo`<000aoo`<000eoo`D000Aoo`H001Ioo`<000Ioo`<000Ioo`D000Ao
o`D000Aoo`D000Aoo`D00004Ool00000000=Ool5000@Ool5000KOol001=oo`<000Ioo`D000Aoo`D0
00Aoo`D001Ioo`D000Aoo`D002aoo`D000Aoo`H001Eoo`D000Aoo`D000Ioo`<000Ioo`<000Ioo`<0
00Ioo`<00003Ool0000000<000aoo`D0011oo`D001]oo`0077oo1@0017oo1@0017oo1@005goo0`00
1Woo0`001goo0`0037oo0`002goo0`001goo0`001Woo0`0000=oo`00Ool057oo1@0017oo1@009Goo
1@003Goo0`004Woo0`0077oo000LOol50004Ool50004Ool5000YOol5000:Ool50009Ool5000;Ool2
0006Ool00`00Oomoo`0COol50004Ool5000UOol50011Ool001eoo`<000Ioo`<000Ioo`<000Moo`<0
00Ioo`<000Ioo`<000ioo`D000Yoo`D000Uoo`D000Yoo`03001oogoo00@0009oo`04001oogooOol3
0006Ool30007Ool30006Ool3000WOol30007Ool3000<Ool30002Ool3000<Ool3000EOol003Qoo`D0
00Aoo`D000Aoo`D000eoo`D000Yoo`D000Uoo`D000eoo`D00004Ool00000Ool50004Ool50012Ool5
000:Ool:000:Ool5000DOol0011oo`<000=oo`<000Ioo`<001Ioo`D000Aoo`D000Aoo`D000ioo`<0
00aoo`<000]oo`<000Eoo`@000=oo`L00004Ool007ooOol50004Ool5000FOol30006Ool30007Ool3
0006Ool3000=Ool5000:Ool:000:Ool5000DOol000moo`D00003Ool0000000<000Aoo`D001Eoo`D0
00Aoo`D000Aoo`D000Moo`<000]oo`<000aoo`<000aoo`<000Aoo`03001oo`0000@00004Ool007oo
Ool50004Ool5000EOol50004Ool50005Ool50004Ool5000<Ool5000:Ool:000:Ool5000DOol000mo
o`D00003Ool0000000<000Aoo`D001Ioo`<000Ioo`<000Ioo`<000Moo`D000Uoo`D000Yoo`D000Yo
o`D000=oo`H0009oo`04001oogooOol30006Ool3000FOol50004Ool50005Ool50004Ool5000=Ool3
000<Ool30002Ool3000<Ool3000EOol000moo`D00003Ool0000000<000Aoo`P000Ioo`<000=oo`<0
021oo`D000Uoo`D000Yoo`D000Yoo`D000]oo`03001oogoo00Qoo`<000Ioo`<000Ioo`<000Ioo`D0
00Aoo`D000Eoo`D000Aoo`D000Ioo`<000]oo`<0019oo`<000]oo`<000ioo`0047oo0`000goo0`00
1Woo200017oo1@0000=oo`0000000`007goo20001Woo1@0000Aoo`00000000Ioo`D000Yoo`D000]o
o`03001oogoo00Moo`D000Aoo`D000Aoo`D000Ioo`<000Ioo`<000Moo`<000Ioo`<000Ioo`D000Uo
o`D0011oo`D000Uoo`D000eoo`008Woo1@0017oo1@0000=oo`0000000`0087oo20001Woo0`0000=o
o`0000000`001Woo0`0037oo0`0037oo00<007ooOol01goo1@0017oo1@0017oo1@00:goo1@002Goo
1@0047oo1@002Goo1@003Goo000ROol50004Ool500000goo00000003000017oo000000001Woo0`00
0Woo0`001Woo0`0027oo1@002Woo1@003Goo0`0037oo0`001Goo10001Woo1@0017oo1@0017oo1@00
:goo1@001Woo20001goo0`001Woo20001Woo1@003Goo000SOol30006Ool30003Ool300000goo0000
00030004Ool:0004Ool50007Ool5000:Ool5000<Ool5000:Ool50004Ool50006Ool30006Ool30006
Ool3000]Ool30006Ool80007Ool50006Ool80006Ool3000>Ool001=oo`<000Ioo`<001Moo`D000Ao
o`X000Aoo`D000Qoo`<000aoo`<000eoo`D000Yoo`D000Aoo`D001Moo`<000Ioo`<000Ioo`<000Io
o`<000Ioo`<0009oo`<000ioo`D000Yoo`D000Uoo`D001Moo`004Woo1@0017oo1@005Woo1@0017oo
2P0017oo1@009goo1@002Woo1@0017oo1@005Woo1@0017oo1@0017oo1@0017oo1@0017oo2P003Goo
1@002Woo1@002Goo1@005goo000BOol50004Ool5000GOol30006Ool30002Ool30006Ool30002Ool3
000;Ool3000<Ool30007Ool30002Ool30007Ool30005Ool4000GOol50004Ool50004Ool50004Ool5
0004Ool:000>Ool3000<Ool3000;Ool3000HOol0019oo`D000Aoo`D0039oo`D000Uoo`D000Yoo`D0
00Yoo`D000ioo`03001oogoo01Qoo`D000Aoo`D000Aoo`D000Aoo`D000Aoo`X004Ioo`004goo0`00
1Woo0`001goo0`001Woo0`001Woo0`005goo1@002Goo1@002Woo1@002Woo1@003Woo00<007ooOol0
1Goo0`001Woo0`0027oo0`001Woo0`001Woo0`001Woo0`001Woo0`000Woo0`000Woo0`000goo0`00
2goo0`0037oo0`0037oo0`0047oo000UOol50004Ool50004Ool5000FOol50009Ool5000:Ool5000:
Ool5000>Ool00`00Oomoo`04Ool50004Ool5000dOol500000goo000000030009Ool5000:Ool5000:
Ool5000?Ool002Eoo`D000Aoo`D000Aoo`D001Moo`<000]oo`<000aoo`<000aoo`<000moo`03001o
ogoo00Aoo`D000Aoo`D003Aoo`D00003Ool0000000<000Uoo`D000Yoo`D000Yoo`D000moo`009Goo
1@0017oo1@0017oo1@001Woo0`001Woo0`0037oo0`0037oo0`002goo0`0037oo0`001Woo0`001Woo
1@0017oo1@00=7oo1@0000=oo`0000001P001Woo1@002Woo1@001Woo0`0000=oo`0000000`003goo
000VOol30006Ool30006Ool30006Ool50004Ool5000:Ool5000:Ool50009Ool5000:Ool50004Ool5
0006Ool30006Ool3000fOol30003Ool80006Ool3000<Ool30006Ool5000017oo0000000047oo000@
Ool30003Ool30006Ool30006Ool3000FOol50004Ool5000:Ool5000:Ool50009Ool5000:Ool50004
Ool5000GOol30006Ool30006Ool30006Ool30006Ool30003Ool3000=Ool5000>Ool3000=Ool5000D
Ool000moo`D00003Ool0000000<000Aoo`D000Aoo`D001Eoo`D000Aoo`D00004Ool000000006Ool5
000017oo000000001Woo1@002Goo1@002Woo1@0017oo1@005Woo1@0017oo1@0017oo1@0017oo1@00
17oo1@0000=oo`0000000`0037oo1@003Goo1@0037oo1@0057oo000?Ool500000goo000000030004
Ool50004Ool5000FOol30006Ool300000goo000000030006Ool300000goo000000030006Ool3000;
Ool3000<Ool30006Ool3000GOol50004Ool50004Ool50004Ool50004Ool500000goo00000003000=
Ool3000>Ool5000=Ool3000EOol000moo`D00003Ool0000000<000Aoo`D000Aoo`D000Ioo`<000Io
o`<0015oo`D000Yoo`D000eoo`<000aoo`<000]oo`<00003Ool007oo00Aoo`<000Ioo`<000Ioo`D0
00Aoo`D000Aoo`D000Aoo`D000Aoo`D00003Ool0000000<000Ioo`<000]oo`<000Moo`D000Ioo`<0
00]oo`<000ioo`0047oo0`000goo0`001Woo0`001Woo0`001Woo1@0017oo1@0047oo1@002Woo1@00
37oo1@002Woo1@002Goo1P0017oo1@0017oo1@001Woo0`001Woo0`001Woo0`001Woo0`001Woo0`00
0goo0`001Woo1@002Goo1@001goo0`001Woo1@002Goo1@003Goo000aOol50004Ool5000AOol3000<
Ool3000=Ool5000:Ool50009Ool60004Ool50004Ool5000iOol50009Ool5000@Ool50009Ool5000=
Ool0035oo`D000Aoo`D0031oo`D000Yoo`D000Uoo`H000Aoo`D000Aoo`D003Uoo`D000Uoo`D0011o
o`D000Uoo`D000eoo`00<Woo0`001Woo0`000Woo0`001Woo0`002goo0`0037oo0`001goo0`000Woo
0`001goo0`002goo0`0000=oo`00Ool017oo0`001Woo0`00>goo0`002goo0`004Woo0`002goo0`00
3Woo000oOol50004Ool50009Ool5000:Ool5000:Ool5000HOol00`00Oomoo`2<Ool000Yoo`<000Io
o`<000Ioo`<000Ioo`<000=oo`<0015oo`D000Aoo`D000Uoo`D000Yoo`D000Yoo`D000eoo`<000Qo
o`8000]oo`<000Ioo`<000Ioo`<000Ioo`<000=oo`<000Ioo`<000Ioo`<0009oo`<000aoo`<000ao
o`<0009oo`<000aoo`<000Ioo`<000aoo`002Goo1@0017oo1@0017oo1@0017oo1@0000=oo`000000
0`0047oo1@0017oo1@002Goo1@002Woo1@002Woo1@0037oo1@001goo00<007ooOol02Goo1@0017oo
1@0017oo1@0017oo1@0000=oo`0000000`0017oo1@0017oo2P002Woo1@002Woo2P002Woo1@0017oo
1@002goo0009Ool50004Ool50004Ool50004Ool500000goo00000003000AOol30006Ool3000;Ool3
000<Ool3000<Ool3000=Ool50007Ool00`00Oomoo`09Ool50004Ool50004Ool50004Ool500000goo
000000030004Ool50004Ool:000:Ool5000:Ool:000:Ool50004Ool5000;Ool000Uoo`D000Aoo`D0
00Aoo`D000Aoo`D00003Ool0000000H000Ioo`<000Ioo`<000aoo`<000aoo`<000]oo`<000aoo`<0
00Ioo`D00004Ool000000003Ool00`00Oomoo`030006Ool50004Ool50004Ool50004Ool500000goo
000000030004Ool50004Ool:000017oo000000001Woo1@001Woo0`0000=oo`000000200000Aoo`00
000000Ioo`D000Aoo`D000]oo`002Woo0`001Woo0`001Woo0`001Woo0`000goo200017oo1@0017oo
1@002Woo1@002Woo1@002Goo1@002Woo1@001Woo0`0000=oo`0000000`000Woo00<007oo00001000
1Woo0`001Woo0`001Woo0`001Woo0`000goo0`001Woo0`001Woo0`000Woo0`0000=oo`0000000`00
1Woo0`001Woo1@0000Aoo`000000009oo`<00003Ool0000000<000Ioo`<000Ioo`<000aoo`00;Woo
1@0017oo1@0017oo1@002Woo1@002Woo1@002Goo1@002Woo1@002Woo1@000Woo00<007oo00001000
@Woo1@003goo1@002Woo1@007Woo000^Ool50004Ool50004Ool5000017oo000000001Woo1@0000Ao
o`00000000Ioo`D000Uoo`D000Yoo`D000Yoo`D0009oo`03001oo`0000@0049oo`D000moo`D000Yo
o`D001ioo`001goo1@000Woo0P007goo0`000Woo2@0017oo0`0000=oo`0000000`001Woo0`0000=o
o`0000000`001Woo0`000goo0P001Woo0`0037oo0`0037oo0`000goo00<007ooOol00`009Woo0P00
77oo0`0027oo1@000Woo1@0037oo0`004goo1@000Woo0P000goo0009Ool01@00Oomoogoo00000Woo
0`000goo0`001Woo0`001Woo0`001Woo0`000Woo00D007ooOomoo`00009oo`03001oogoo00Eoo`D0
00Yoo`D000]oo`03001oo`00008000aoo`<000]oo`<000Ioo`<0009oo`03001oogoo00Moo`<000Io
o`<000Ioo`<000=oo`<000Ioo`@000Eoo`<000Ioo`<000=oo`<000]oo`<000=oo`<00005Ool007oo
Ool00007Ool3000;Ool30006Ool30003Ool30003Ool01000Oomoo`000Woo0009Ool00`00Oomoo`03
Ool500000goo000000030004Ool50004Ool50004Ool500000goo001oo`02Ool01000Oomoo`001goo
1@002Woo1@0037oo1@002Woo1@002Goo1@0017oo1@0000=oo`00Ool01goo1@0017oo1@0017oo1@00
00=oo`0000000`0017oo1@0017oo1@0017oo1@0000=oo`0000000`002Goo1@0000=oo`0000001000
0Woo00<007ooOol017oo1@002Goo1@0017oo1@0000=oo`0000000`001Goo0@000Goo0Goo00000goo
000000020004Ool00`00Oomoo`02Ool600000goo000000030004Ool50004Ool50002Ool700000goo
001oo`02Ool01000Oomoo`0027oo0`0037oo0`001Woo10000goo1@002Woo1@002Goo1@0017oo1@00
00=oo`0000001goo1@0017oo1@0017oo1@0000=oo`0000000`0017oo1@0017oo1@0017oo1@0000=o
o`0000000`002Goo1@0000=oo`00000010000Woo00<007ooOol017oo1@002Goo1@0017oo1@0000=o
o`0000000`000goo0P000goo0009Ool00`00Oomoo`02Ool600000goo000000030004Ool50004Ool5
0004Ool500000goo001oo`02Ool01000Oomoo`009goo1@002Woo1@002Goo1@0017oo1@0000=oo`00
Ool01goo1@0017oo1@0017oo1@0000=oo`0000000`0017oo1@0017oo1@0017oo1@0000=oo`000000
0`002Goo1@0000=oo`00000010000Woo00<007ooOol017oo1@002Goo1@0017oo1@0000=oo`000000
0`000goo00<007ooOol00Woo0008Ool20004Ool50003Ool30006Ool30006Ool30006Ool3000017oo
000000000goo0P000Woo0`002goo0`0037oo0`001Woo10000Woo0`001goo0`002goo0`001Woo0`00
0Woo00<007ooOol01goo0`001Woo0`001Woo0`000goo0`001Woo10001Goo0`001Woo0`000goo0`00
2goo0`000Woo10000Woo0P0027oo0`002goo0`001Woo0`000goo0`0017oo0`000Woo000dOol50005
Ool50009Ool5000:Ool5000:Ool5000ROol00`00Oomoo`2<Ool003Aoo`D000Eoo`D000Uoo`D000Yo
o`D000Yoo`D000eoo`<000aoo`<000=oo`03001oogoo00<004Aoo`<0015oo`<000aoo`<001moo`00
=7oo1@001Goo1@002Goo1@002Woo1@002Woo1@0037oo1@002Woo1@000Woo00<007oo00001000@Woo
1@003goo1@002Woo1@007Woo000eOol30007Ool3000;Ool3000<Ool3000<Ool3000=Ool5000:Ool5
0002Ool00`00Ool000040012Ool5000?Ool5000:Ool5000NOol000Yoo`<000Ioo`<000Ioo`<000Io
o`<000Ioo`<000Ioo`<000aoo`<000aoo`<000]oo`<000aoo`<000Ioo`D00004Ool000000006Ool5
0002Ool00`00Ool000040006Ool30006Ool30006Ool30006Ool30003Ool30006Ool30006Ool30002
Ool300000goo000000030006Ool30006Ool5000017oo000000000Woo0`0000=oo`0000000`001Woo
0`001Woo0`0037oo0009Ool50004Ool50004Ool50004Ool50004Ool50004Ool5000:Ool5000:Ool5
0009Ool5000:Ool50006Ool300000goo000000030006Ool30003Ool00`00Oomoo`030006Ool50004
Ool50004Ool50004Ool500000goo000000030004Ool50004Ool:000017oo000000001Woo1@001Woo
0`0000=oo`000000200000Aoo`00000000Ioo`D000Aoo`D000]oo`0017ooo`0070000Goo0009Ool5
0004Ool50004Ool50004Ool50004Ool50004Ool50004Ool00`00Oomoo`03Ool50007Ool00`00Oomo
o`0500000goo001oo`06Ool50005Ool00`00Oomoo`02Ool50008Ool00`00Ool000040002Ool00`00
Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`05000017oo001oogoo1@0000Aoo`00Oomoo`D00004
Ool007ooOol500000goo000000030004Ool50004Ool:0008Ool00`00Ool000040002Ool00`00Oomo
o`05Ool;0008Ool60003Ool60004Ool00`00Oomoo`04Ool000Yoo`<000Ioo`<000Ioo`<000Ioo`<0
00Ioo`<000Ioo`<000aoo`<000aoo`<000]oo`<000aoo`<000aoo`<000eoo`03001oogoo00Yoo`<0
00Ioo`<000Ioo`<000Ioo`<000=oo`<000Ioo`<000Ioo`<0009oo`<000aoo`<000aoo`<0009oo`<0
00aoo`<000Ioo`<000aoo`00;7oo0`001Woo0`001goo0`002goo0`0037oo0`0037oo0`002goo0`00
37oo0`001Woo0`000goo0`00A7oo0`002goo0`004Woo0`002goo0`003Woo000[Ool50004Ool50005
Ool50009Ool5000:Ool5000:Ool50009Ool5000:Ool50004Ool500000goo000000030012Ool50009
Ool5000@Ool50009Ool5000=Ool002]oo`D000Aoo`D000Eoo`D000Uoo`D000Yoo`D000Yoo`D000Uo
o`D000Yoo`D000Aoo`D00003Ool0000000<0049oo`D000Uoo`D0011oo`D000Uoo`D000eoo`00:goo
1@0017oo1@001Goo1@002Goo1@002Woo1@002Woo1@002Goo1@002Woo1@0017oo1@0000=oo`000000
0`00@Woo1@002Goo1@0047oo1@002Goo1@003Goo000@Ool30003Ool30006Ool30006Ool3000017oo
000000001Woo0`001goo0`002goo0`0037oo0`0037oo0`002goo0`0037oo0`001Woo0`000goo0`00
00Aoo`00000000Ioo`<000Ioo`<000=oo`<000Ioo`<000Ioo`<000Ioo`<000=oo`<000Moo`<000]o
o`<000Qoo`<000Moo`<000]oo`<000ioo`003goo1@0000=oo`0000000`0017oo1@0017oo1@00IGoo
00<007ooOol01Woo1@0017oo1@0017oo1@0000=oo`0000000`0017oo1@0017oo1@0017oo1@0000=o
o`0000000`007Woo1@009Goo000?Ool500000goo000000030004Ool50004Ool5000AOol30006Ool3
000<Ool3000;Ool3000<Ool3000<Ool3000=Ool20007Ool50004Ool50004Ool500000goo00000003
0004Ool50004Ool50004Ool500000goo00000003000=Ool3000>Ool5000=Ool3000EOol000moo`D0
0003Ool0000000<000Aoo`D000Aoo`D0011oo`D000Aoo`D000Yoo`D000Uoo`D000Yoo`D000Yoo`D0
00aoo`03001oogoo00Ioo`D000Aoo`D000Aoo`D00003Ool0000000<000Aoo`D000Aoo`D000Aoo`D0
0003Ool0000000<000aoo`D000eoo`D000aoo`D001Aoo`0047oo0`000goo0`001Woo0`001Woo0`00
4Goo1@0017oo1@002Woo1@002Goo1@002Woo1@002Woo1@0037oo00<007ooOol01goo0`001Woo0`00
1Woo0`000goo0`001Woo0`001Woo0`001Woo0`000goo0`003Goo1@003Woo0`003Goo1@0057oo000V
Ool30006Ool30006Ool300000goo000000030004Ool5000:Ool50009Ool50006Ool300000goo0000
00030006Ool300000goo000000030006Ool30003Ool00`00Oomoo`030006Ool3000kOol30003Ool8
0006Ool3000<Ool30006Ool5000017oo000000001Woo0`001goo000UOol50004Ool50004Ool50000
17oo000000001Woo0`0037oo0`002goo0`001Woo1@0000Aoo`00000000Ioo`D00004Ool000000006
Ool50002Ool00`00Ool000040004Ool5000iOol500000goo000000060006Ool5000:Ool50006Ool3
00000goo000000030004Ool50006Ool002Eoo`D000Aoo`D000Aoo`D0015oo`<000aoo`<000eoo`D0
00Yoo`D000Yoo`D0009oo`03001oo`0000@000Aoo`D003Uoo`D00003Ool0000000<000Uoo`D000Yo
o`D000Yoo`D000Aoo`D000Ioo`002Woo0`001Woo0`001Woo0`001Woo1@0017oo1@0017oo1@0047oo
1@002Woo1@0037oo1@002Woo1@002Woo1@000Woo00<007oo0000100017oo1@001Woo0`001Woo0`00
1Woo0`000goo0`001Woo0`001Woo0`000Woo0`0000=oo`0000000`0000=oo`0000000`002Goo1@00
2Woo1@002Woo1@0017oo1@001Woo0009Ool50004Ool50004Ool50006Ool30006Ool30006Ool3000A
Ool5000:Ool5000=Ool3000<Ool3000<Ool30003Ool00`00Oomoo`030006Ool30006Ool50004Ool5
0004Ool500000goo000000030004Ool50004Ool:000017oo000000000goo0`002goo0`0037oo0`00
37oo0`001Woo0`001goo0009Ool50004Ool50004Ool5000GOol30006Ool30006Ool80006Ool30000
0goo000000030006Ool3000<Ool3000;Ool30006Ool30002Ool00`00Oomoo`0BOol50004Ool50004
Ool500000goo000000030004Ool50004Ool:000>Ool3000<Ool3000;Ool30006Ool3000?Ool000Uo
o`D000Aoo`D000Aoo`D001Ioo`D000Aoo`D000Aoo`P000Ioo`D00004Ool000000006Ool5000:Ool5
0009Ool50004Ool500000goo0000000COol50004Ool50004Ool500000goo000000030004Ool50004
Ool:000=Ool5000:Ool50009Ool50004Ool5000>Ool000Yoo`<000Ioo`<000Ioo`<001Moo`D000Ao
o`D000Aoo`D000Uoo`D000Yoo`D000Yoo`D000Uoo`D000Aoo`D00003Ool007oo01Aoo`<000Ioo`<0
00Ioo`<000=oo`<000Ioo`<000Ioo`<0009oo`<000ioo`D000Yoo`D000Uoo`D000Aoo`D000ioo`00
37oo0`0057oo0`001Woo0`000goo0`0000=oo`0000000`0017oo1@0017oo1@002Goo1@002Woo1@00
2Woo1@002Goo1@0017oo1@0000=oo`00Ool017oo0`001Woo0`00>goo0`001Woo20001goo1@001Woo
200017oo1@003Woo000;Ool5000BOol50004Ool500000goo00000003000017oo000000001Woo0`00
1Woo0`002goo0`0037oo0`0037oo0`002goo0`001Woo0`000Woo00<007ooOol00Woo1@0017oo1@00
>Goo1@001Woo20001goo0`001Woo20001Woo0`003goo000;Ool5000BOol50004Ool500000goo0000
0003001KOol00`00Oomoo`02Ool50004Ool5000iOol50009Ool5000@Ool5000KOol000]oo`D0019o
o`D000Aoo`D00003Ool0000000<001Yoo`<000aoo`<000]oo`<000aoo`<0019oo`03001oogoo009o
o`D000Aoo`D003Uoo`D000Uoo`D0011oo`D001]oo`0037oo0`0000Aoo`00000000=oo`<000Ioo`<0
0004Ool000000006Ool30003Ool3000JOol5000:Ool50009Ool5000:Ool5000AOol00`00Oomoo`03
Ool30006Ool30007Ool30006Ool30006Ool30006Ool30006Ool30003Ool30007Ool3000;Ool3000B
Ool3000LOol000moo`D00003Ool0000000<000Aoo`D002aoo`D000Yoo`D000Uoo`D000Yoo`D0015o
o`03001oogoo01Eoo`D000Aoo`D000Aoo`D000Aoo`D000Aoo`D00003Ool0000000<004Qoo`003goo
1@0000=oo`0000000`0017oo1@005Woo0`001Woo0`001Woo0`0000=oo`0000000`002Woo1@002Goo
1@001Woo0`0000=oo`0000000`001Woo0`001Woo0`005goo1@0017oo1@0017oo1@0017oo1@0017oo
1@0000=oo`0000000`003Goo0`0037oo0`000Woo0`0037oo0`001Woo0`0037oo000?Ool500000goo
000000030004Ool5000EOol50004Ool50004Ool5000017oo0000000037oo0`002goo0`001Woo1@00
00Aoo`00000000Ioo`D000Aoo`D001Ioo`D000Aoo`D000Aoo`D000Aoo`D000Aoo`D00003Ool00000
00<000aoo`D000Yoo`X000Yoo`D000Aoo`D000]oo`0047oo0`000goo0`001Woo0`005Woo1@0017oo
1@0017oo1@0027oo0`0037oo0`003Goo1@002Woo1@0017oo1@005goo0`001Woo0`001Woo0`001Woo
0`001Woo0`000goo0`003Goo1@002Woo2P002Woo1@0017oo1@002goo000MOol30006Ool30006Ool3
0006Ool50004Ool50004Ool50007Ool5000:Ool5000<Ool5000:Ool50004Ool50006Ool30006Ool3
0006Ool3000]Ool30006Ool5000:Ool:000:Ool50004Ool5000;Ool001aoo`D000Aoo`D000Aoo`D0
00Ioo`<000Ioo`<000Ioo`<000Qoo`D000Yoo`D000eoo`<000aoo`<000Ioo`<000Ioo`D000Aoo`D0
00Aoo`D002]oo`D000Ioo`<000aoo`<0009oo`<000aoo`<000Ioo`<000aoo`0077oo1@0017oo1@00
17oo1@005goo0`001Woo20001Woo0`0000=oo`0000000`001Woo0`0037oo0`003goo00<007ooOol0
17oo1@0017oo1@0017oo1@00:goo1@003Goo0`004Woo0`0077oo000COol30006Ool50004Ool50004
Ool5000FOol50004Ool80006Ool5000017oo000000001Woo1@002Woo1@003Woo00<007ooOol017oo
1@0017oo1@0017oo1@001goo0`001Woo0`001Woo0`001Woo0`001Woo1@0037oo1@0047oo1@006goo
000BOol50006Ool30006Ool30006Ool3000GOol50004Ool50009Ool5000:Ool5000:Ool5000>Ool0
0`00Oomoo`05Ool30006Ool30006Ool30007Ool50004Ool50004Ool50004Ool50006Ool3000=Ool5
000@Ool5000KOol0019oo`D001Ioo`<000Moo`<000Ioo`<000Ioo`D000Aoo`D000Uoo`D000Yoo`D0
00Yoo`D000Ioo`<000Eoo`@000Ioo`<001Moo`D000Aoo`D000Aoo`D000Aoo`D000eoo`<000=oo`P0
00Moo`<000Ioo`P000Ioo`<000moo`004Woo1@005Goo1@001Goo1@0017oo1@001Woo0`001Woo0`00
2goo0`0037oo0`0037oo0`001Woo1@0017oo1@0017oo1@005Woo1@0017oo1@0017oo1@0017oo1@00
37oo1@0000=oo`0000001P001goo1@001Woo200017oo1@003Woo000COol3000FOol50005Ool50004
Ool5000FOol3000<Ool3000;Ool3000>Ool50004Ool50004Ool5000GOol30006Ool30006Ool30006
Ool3000=Ool500000goo00000003000:Ool50009Ool50004Ool5000>Ool002aoo`D000Eoo`D000Ao
o`D001Eoo`D000Yoo`D000Uoo`D000eoo`D000Aoo`D000Aoo`D0049oo`D00003Ool0000000<000Yo
o`D000Uoo`D000Aoo`D000ioo`006Woo0`001Woo0`001goo0`001goo0`001Woo0`005Woo1@002Woo
1@002Goo1@003Woo0`001Goo10001Woo0`001goo0`001Woo0`001Woo0`007Woo0`000goo0`0000Ao
o`00000000=oo`<000aoo`<000]oo`<000Ioo`<000moo`006Goo1@0017oo1@00<Woo1@002Woo1@00
2Goo1@005Woo00<007ooOol047oo1@0017oo1@0017oo1@0077oo1@0000=oo`0000000`00?Woo000I
Ool50004Ool5000POol30003Ool30006Ool3000017oo0000000037oo0`002goo0`0027oo0`001Woo
0`000goo00<007ooOol047oo1@0017oo1@0017oo1@0077oo1@0000=oo`0000000`003Goo0`0037oo
0`007goo000IOol50004Ool5000OOol500000goo000000030004Ool5000WOol50004Ool50002Ool0
0`00Oomoo`0@Ool50004Ool50004Ool50006Ool30007Ool30006Ool800000goo00000003000<Ool5
000:Ool5000NOol001Yoo`<000Ioo`<0021oo`D00003Ool0000000<000Aoo`D000Moo`<000aoo`<0
00ioo`D000Aoo`D0009oo`03001oogoo015oo`<000Ioo`<000Ioo`<000Ioo`D000Eoo`D000Aoo`P0
00=oo`<000eoo`D000Yoo`D001ioo`004goo0`005Goo0`001Woo0`000Woo0`001Woo0`0000=oo`00
00000`0000=oo`0000000`0017oo1@001Woo1@002Woo1@003Goo1@000goo1P000Woo00@007ooOomo
o`<000Ioo`<000Ioo`<001Ioo`D000Eoo`D000Aoo`D000eoo`<000Ioo`D000Yoo`D000Ioo`<001Eo
o`004Woo1@004goo1@0017oo2P0017oo1@0000Aoo`00000000=oo`<000Ioo`<000Moo`D000Yoo`D0
00ioo`<000=oo`03001oogoo00<000=oo`03001oogoo00D000Aoo`D000Aoo`D001Eoo`D000Eoo`D0
00Aoo`D000aoo`D000Ioo`<000aoo`<000Ioo`D001Aoo`004Woo1@004goo1@0017oo2P0017oo1@00
5goo20001goo20001Woo0`003Woo00<007ooOol00goo0P0000=oo`0000000`0017oo1@0017oo1@00
5Woo0`001goo0`001Woo0`003Goo1@003Woo0`003Goo1@0057oo000BOol50006Ool30006Ool30000
0goo000000030004Ool:0004Ool5000FOol80007Ool80006Ool5000;Ool20006Ool00`00Oomoo`05
0004Ool50004Ool50006Ool30006Ool3000NOol30006Ool5000=Ool5000<Ool5000DOol001=oo`<0
00Ioo`D000Aoo`D00004Ool000000006Ool30002Ool30006Ool3000GOol5000:Ool50009Ool5000;
Ool00`00Oomoo`05Ool01000Oomoogoo0`001Woo0`001Woo0`001Woo1@0017oo1@0077oo1@001Woo
0`003Woo1@003Goo0`005Goo000LOol50004Ool5000GOol30006Ool30006Ool30006Ool5000:Ool5
0009Ool50006Ool30002Ool300001Woo00000000Ool000Eoo`<001Ioo`D000Aoo`D001aoo`D000eo
o`<000Moo`D000Ioo`<001aoo`0077oo1@0017oo1@005Woo1@0017oo1@0017oo1@001Woo0`0037oo
0`002goo0`001Woo1@0017oo1P0017oo1@005Goo1@0017oo1@0077oo1@0037oo1@001goo0`001Woo
1@006goo000MOol30006Ool3000GOol50004Ool50004Ool5000=Ool3000<Ool3000=Ool50004Ool6
0004Ool5000FOol30006Ool30007Ool30006Ool30006Ool30002Ool3000=Ool5000@Ool5000KOol0
041oo`D000Aoo`D000Aoo`D000aoo`D000Yoo`D000aoo`D000Aoo`H000Aoo`D002Qoo`D000Aoo`D0
00Aoo`D0015oo`D0011oo`D001]oo`005Woo0`001Woo0`002goo0`001goo0`001goo0`001Woo0`00
1Woo0`003Goo1@002Woo1@003Goo0`001Woo0`0000=oo`00Ool017oo0`001goo0`001Woo0`005Woo
1@0017oo1@0017oo1@0027oo0`001goo0`004Woo0`0077oo000EOol50004Ool50009Ool50005Ool5
000XOol5000:Ool5000JOol00`00Oomoo`0<Ool50004Ool5000EOol50004Ool50004Ool50007Ool5
000jOol001Eoo`D000Aoo`D000Uoo`D000Eoo`D001Ioo`<000Ioo`<000=oo`<00004Ool00000000<
Ool30007Ool30006Ool30008Ool2000=Ool50004Ool5000FOol30006Ool30006Ool30008Ool5000>
Ool30002Ool3000<Ool3000EOol001Eoo`D000Aoo`P000Ioo`D000Eoo`D001Eoo`D000Aoo`D00003
Ool0000000<001Qoo`D000Aoo`D000Moo`03001oogoo00aoo`D000Aoo`D000Ioo`<000Ioo`<000Io
o`<000aoo`<000Ioo`P000eoo`X000Yoo`D001Aoo`005Woo0`001Woo20001Woo0`001goo0`005Woo
1@0017oo1@0000=oo`0000000`0027oo0`003Goo1@0017oo1@001goo00<007ooOol03Goo0`001Woo
0`001Woo1@0017oo1@0017oo1@002Woo1@0017oo20003Woo2P002Woo1@0057oo000ROol5000GOol3
0006Ool30003Ool80004Ool500000goo000000030007Ool5000<Ool50004Ool50006Ool30006Ool3
000GOol50004Ool50004Ool5000:Ool50004Ool50008Ool30002Ool300000goo00000008000017oo
000000001Woo1@0057oo000ROol5000FOol50004Ool500000goo000000060006Ool30003Ool30008
Ool5000=Ool30006Ool30006Ool50004Ool5000FOol50004Ool50004Ool5000:Ool50004Ool50007
Ool:000017oo000000000Woo0`0000=oo`0000000`001Woo0`005Goo000SOol3000GOol50004Ool5
00000goo00000003000FOol300000goo000000030006Ool3000FOol50004Ool5000GOol30006Ool3
0006Ool3000<Ool30006Ool30008Ool:000:Ool5000NOol001aoo`<000aoo`<000Ioo`<0009oo`<0
0003Ool0000000<000Aoo`D00003Ool0000000<001Eoo`D00004Ool000000006Ool5000EOol50004
Ool50006Ool30007Ool30006Ool3000;Ool30006Ool3000<Ool30006Ool300000goo00000008000:
Ool5000NOol001]oo`D000Yoo`D000Aoo`X00004Ool000000006Ool30003Ool3000FOol5000:Ool5
000FOol30006Ool30006Ool50005Ool50004Ool50009Ool50004Ool5000:Ool50004Ool5000017oo
000000000Woo0`0037oo0`007goo000KOol5000:Ool50004Ool:000GOol30006Ool30006Ool5000:
Ool50006Ool30006Ool30005Ool00`00Oomoo`0>Ool50005Ool50004Ool50009Ool50004Ool5000:
Ool50004Ool5000>Ool3000;Ool3000HOol001]oo`D000Yoo`D000Aoo`X001Ioo`D000Aoo`D000Io
o`<000aoo`<000Ioo`D000Aoo`D000Aoo`8000moo`D000Eoo`D000Aoo`D000Uoo`D000Aoo`D000Yo
o`D000Aoo`D000eoo`D000Uoo`D001Moo`0077oo0`0037oo0`001Woo0`000Woo0`005goo1@0017oo
1@003Goo0`003Woo1@0017oo1@0017oo00<007ooOol03goo0`001goo0`001Woo0`002goo0`001Woo
0`0037oo0`001Woo0`003Woo1@002Goo1@005goo001COol50004Ool5000<Ool5000=Ool50004Ool5
0004Ool00`00Oomoo`1ROol50009Ool5000GOol001Yoo`<000Ioo`<001]oo`<000Ioo`<000Moo`<0
00Ioo`<000eoo`D000ioo`<000Ioo`<000Eoo`03001oo`00008000Ioo`<000Ioo`<000Ioo`<000ao
o`<000Ioo`<000aoo`<000Ioo`<000]oo`<000Qoo`<000]oo`<001Qoo`006Goo1@0017oo1@006Goo
1@0017oo1@007goo1@007goo1P0017oo1@0017oo1@0017oo1@002Woo1@0017oo1@002Woo1@0017oo
1@002Goo1@00<7oo000IOol50004Ool5000IOol50004Ool5000FOol30007Ool30008Ool3000EOol6
0004Ool50004Ool50004Ool5000:Ool50004Ool5000:Ool50004Ool50009Ool5000>Ool3000OOol0
01Uoo`D000Aoo`D000Ioo`<000Moo`<000Ioo`D000Aoo`D001Eoo`D0011oo`D001Aoo`H000Aoo`D0
00Aoo`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D000Aoo`D000Uoo`D000eoo`D001ioo`006Woo0`00
1Woo0`001Woo1@001Goo1@001Woo0`001Woo0`005Woo1@0047oo1@0057oo00<007oo00000P001Woo
0`001Woo0`001Woo0`0037oo0`001Woo0`0037oo0`001Woo0`002goo0`003Woo1@007Woo000/Ool5
0005Ool5000FOol30006Ool30006Ool5000@Ool50006Ool30006Ool30002Ool01000Oomoogoo0`00
1Woo0`0037oo0`001Woo0`002goo0`001Woo0`0037oo0`001Woo0`0037oo0`001Woo1@007Woo000/
Ool50005Ool5000EOol50004Ool50006Ool3000BOol30006Ool50004Ool5000017oo000007oo1@00
17oo1@002Woo1@0017oo1@002Goo1@0017oo1@002Woo1@0017oo1@002Woo1@001Woo0`007goo000]
Ool30007Ool3000FOol50004Ool5000>Ool30002Ool3000>Ool50004Ool5000017oo001oogoo1@00
17oo1@002Woo1@0017oo1@002Goo1@0017oo1@002Woo1@0017oo1@002Woo1@00:7oo000VOol3000<
Ool30006Ool30006Ool30006Ool50004Ool5000=Ool:000=Ool50004Ool5000017oo001oogoo1@00
17oo20001goo1@0017oo1@002Goo1@0017oo1@002Woo1@0017oo1@002Woo1@00:7oo000UOol5000:
Ool50004Ool50004Ool50006Ool30006Ool3000>Ool:000>Ool30006Ool30002Ool01000Oomoogoo
0`001Woo20001goo0`001Woo0`002goo0`001Woo0`0037oo0`001Woo0`0037oo0`00:Goo000UOol5
000:Ool50004Ool50004Ool5000FOol30003Ool300000goo000000080006Ool30006Ool3000:Ool0
0`00Oomoo`0=Ool5000GOol30006Ool3000<Ool30006Ool3000;Ool3000<Ool3000ROol002Eoo`D0
00Yoo`D000Aoo`D000Aoo`D001Eoo`D00003Ool0000000<00004Ool000000002Ool30006Ool50004
Ool50009Ool00`00Oomoo`0=Ool5000FOol50004Ool5000:Ool50004Ool50009Ool5000:Ool5000Q
Ool002Ioo`<000aoo`<000Ioo`<000Ioo`<001Ioo`D00003Ool0000000<000moo`D000Aoo`D000Uo
o`03001oogoo00ioo`<001Moo`D000Aoo`D000Yoo`D000Aoo`D000Uoo`D000Yoo`D0025oo`00H7oo
1@0000=oo`0000000`003goo1@0017oo1@002Goo00<007ooOol0:7oo1@0017oo1@002Woo1@0017oo
1@002Goo1@002Woo1@008Goo000]Ool30007Ool3000;Ool30006Ool30003Ool30006Ool3000017oo
000000000goo0`004Goo0`001Woo0`000Woo0`001Goo10001Woo0`0037oo0`001Woo0`001goo0`00
1Woo0`000Woo0`001goo0`001Woo0`002goo0`0037oo0`008Woo000/Ool50005Ool50009Ool50004
Ool500000goo000000030004Ool5000WOol50004Ool50004Ool5000:Ool50004Ool5000COol5001A
Ool002aoo`D000Eoo`D000Uoo`D000Aoo`D00003Ool0000000<000Aoo`D000eoo`<000=oo`<0015o
o`D000Aoo`D000Aoo`D000Yoo`D000Aoo`D001=oo`D001Ioo`<000aoo`<002Uoo`00;7oo1@001Goo
20000goo200017oo1@0000=oo`0000000`0017oo1@0037oo1@0000=oo`0000000`0047oo1@0017oo
1@0017oo1@002Woo1@0017oo1@004goo1@005Goo1@002Woo1@00:7oo000]Ool30007Ool800000goo
000000060006Ool30003Ool30006Ool3000=Ool500000goo00000003000AOol30005Ool40006Ool3
000<Ool30006Ool3000EOol3000FOol5000:Ool5000XOol003Yoo`D00003Ool0000000<001moo`<0
00Ioo`D00003Ool0000000<00004Ool000000006Ool30006Ool30003Ool00`00Oomoo`05Ool30006
Ool30006Ool3000<Ool30006Ool3000<Ool30006Ool30006Ool5000017oo000000001Woo1@00:7oo
000jOol500000goo00000003000NOol50006Ool30003Ool300000goo000000030004Ool50004Ool5
0002Ool00`00Oomoo`04Ool50004Ool50004Ool5000:Ool50004Ool5000:Ool50004Ool50006Ool3
00000goo000000030006Ool3000YOol003]oo`<000=oo`<001moo`D0011oo`D000Aoo`D000Aoo`D0
009oo`03001oogoo00Aoo`D000Aoo`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D0
039oo`00:goo0`001Woo0`004Goo0`001Woo0`001Woo0`001Woo1@0047oo1@0017oo1P000Woo2@00
1Woo1@0017oo1@0017oo1@002Woo1@0017oo1@002Woo1@0017oo1@002Woo1@00<Woo000ZOol50004
Ool5000?Ool50004Ool50004Ool50006Ool3000BOol30006Ool30003Ool00`00Oomoo`080006Ool3
0006Ool30006Ool3000<Ool30006Ool3000<Ool30006Ool3000<Ool3000cOol002Yoo`D000Aoo`D0
00moo`D000Aoo`D000Aoo`D000ioo`<0009oo`<000Ioo`<000Moo`05001oogooOol00002Ool00`00
Oomoo`05000GOol30006Ool3000;Ool30007Ool3000;Ool30006Ool3000<Ool3000/Ool002Yoo`D0
00Aoo`D000moo`D000Aoo`D000Aoo`D000eoo`X000Aoo`D000Ioo`05001oogooOol00002Ool00`00
Oomoo`05000FOol50004Ool50009Ool50005Ool50009Ool50004Ool5000:Ool5000[Ool002]oo`<0
00Ioo`<000Moo`<000Moo`<000Ioo`<000Ioo`<000ioo`X000Aoo`D000Ioo`05001oogooOol00002
Ool01000Oomoogoo0`005goo1@0017oo1@002Goo1@001Goo1@002Goo1@0017oo1@002Woo1@00:goo
000mOol5000YOol:0004Ool50005Ool20004Ool20006Ool00`00Oomoo`0EOol50004Ool50009Ool5
0005Ool50009Ool50004Ool5000:Ool5000[Ool003eoo`D001Ioo`<000Ioo`<000Qoo`<0009oo`<0
00Ioo`<0009oo`<000Ioo`<000Ioo`03001oogoo00=oo`<000Ioo`<000Moo`<000Ioo`<00004Ool0
00000007Ool30007Ool3000;Ool30006Ool3000<Ool3000/Ool003eoo`D001Eoo`D000Aoo`D001Uo
o`D000Aoo`D000Eoo`03001oogoo009oo`D000Aoo`D0019oo`D006Eoo`00?Woo0`005Woo1@0017oo
1@006Goo1@0017oo1@001Goo00<007ooOol00Woo1@0017oo1@004Woo1@005goo0`001Woo0`0037oo
0`00<goo000gOol3000;Ool30006Ool30006Ool50004Ool5000IOol50004Ool50005Ool00`00Oomo
o`02Ool50004Ool5000BOol5000FOol50004Ool5000:Ool5000bOol003Ioo`D000Uoo`D000Aoo`D0
00Ioo`<000Ioo`<001]oo`<000Ioo`<000Ioo`03001oogoo00=oo`<000Ioo`<001Aoo`<001Moo`D0
00Aoo`D000Yoo`D0039oo`00=Woo1@002Goo1@0017oo1@005goo0`000Woo0`001Woo0`001goo0`00
2goo10001Goo0`0037oo0`001Woo0`0037oo0`001Woo0`001Woo1@0017oo20001goo1@00<Woo000f
Ool50009Ool50004Ool5000FOol:0004Ool50005Ool50009Ool50004Ool5000:Ool50004Ool5000:
Ool50004Ool50006Ool30006Ool80007Ool3000cOol003Moo`<000]oo`<000Ioo`<001Moo`X000Ao
o`D000Eoo`D000Uoo`D000Aoo`D000Yoo`D000Aoo`D000Yoo`D000Aoo`D0019oo`D003eoo`00?Woo
0`005Goo0`000Woo0`001Woo0`0000=oo`000000200017oo1@001Goo20001Woo1@0017oo1@002Woo
1@0017oo1@002Woo1@0017oo1@004Woo1@00?Goo000mOol5000COol:0004Ool5000017oo00000000
0Woo0`001Woo0`001goo20001Woo0`001Woo0`0037oo0`001Woo0`0037oo0`001Woo0`0057oo0`00
?Woo000mOol5000COol:0004Ool5000LOol50008Ool00`00Oomoo`0<Ool3000DOol30006Ool3000<
Ool30006Ool30015Ool003eoo`D000Ioo`<000Ioo`<00003Ool0000000P000Aoo`D001aoo`D000Qo
o`03001oogoo00]oo`D0019oo`D000Aoo`D000Yoo`D000Aoo`D004Aoo`00?Woo0`001Woo1@0017oo
1@0000Aoo`000000009oo`<000Ioo`<001ioo`<000Uoo`03001oogoo00]oo`D0019oo`D000Aoo`D0
00Yoo`D000Aoo`D004Aoo`00Agoo1@0017oo1@005goo0`001Woo0`001Woo0`002goo0`000Woo00@0
07ooOomoo`<000Moo`P000Ioo`<000Ioo`D000Aoo`D000Yoo`D000Aoo`D004Aoo`00Agoo1@0017oo
1@005Woo1@0017oo1@0017oo1@002Goo1@0000Aoo`00001oo`D000Moo`P000Aoo`D000Ioo`<000Io
o`<000aoo`<000Ioo`<004Eoo`00B7oo0`001Woo0`005goo1@0017oo1@0017oo1@002Goo1@0000Ao
o`00Oomoo`D000Yoo`D000Aoo`D006moo`00Jgoo1@0017oo1@0017oo1@002Goo1@0000Aoo`00Oomo
o`D000Yoo`D000Aoo`D001Moo`<005Eoo`00Cgoo0`001Woo0`001Woo0`0027oo0`001Woo0`001Woo
0`002goo0`000Woo00@007ooOomoo`<000aoo`<000Ioo`<001Moo`D005Aoo`00CWoo1@0017oo1@00
17oo1@00;7oo00<007ooOol0<goo1@00E7oo001>Ool50004Ool50004Ool5000GOol30006Ool30009
Ool00`00Oomoo`030006Ool30006Ool3000<Ool30006Ool30006Ool80006Ool30018Ool004ioo`D0
00Aoo`D000Aoo`D001Ioo`D000Aoo`D000Qoo`03001oo`0000@000Aoo`D000Aoo`D000Yoo`D000Ao
o`D000Ioo`P000Aoo`D004Moo`00Cgoo0`001Woo0`001Woo0`005goo1@0017oo1@0027oo00<007oo
0000100017oo1@0017oo1@002Woo1@0017oo1@002Goo1@0017oo1@00Agoo001AOol3000<Ool30006
Ool30006Ool30006Ool50004Ool50008Ool00`00Ool000040004Ool50004Ool5000:Ool50004Ool5
0009Ool50004Ool50017Ool0051oo`D000Yoo`D000Aoo`D000Aoo`D000Ioo`<000Ioo`<000Uoo`80
0004Ool000000006Ool30006Ool3000<Ool30006Ool3000;Ool30006Ool30018Ool0051oo`D000Yo
o`D000Aoo`D000Aoo`D001Ioo`<0009oo`04001oogooOol3000<Ool30006Ool3000<Ool30006Ool3
001HOol0051oo`D00004Ool000000006Ool50004Ool50004Ool5000EOol5000017oo001oogoo1@00
2Woo1@0017oo1@002Woo1@0017oo1@00Egoo001AOol300000goo000000030006Ool30006Ool30006
Ool3000FOol5000017oo001oogoo1@002Woo1@0017oo1@002Woo1@0017oo1@00Egoo001EOol5000F
Ool30006Ool30006Ool30006Ool5000017oo001oogoo1@0000Aoo`00000000Ioo`D000Aoo`D000Yo
o`D000Aoo`D005Moo`00EGoo1@005Goo1@0017oo1@0017oo1@001Woo0`000Woo00@007ooOomoo`<0
0003Ool0000000<000Ioo`<000Ioo`<000aoo`<000Ioo`<005Qoo`00EWoo0`005Woo1@0017oo1@00
17oo1@002goo00<007ooOol01Goo1@005goo0`00J7oo001_Ool50004Ool50004Ool5000;Ool00`00
Oomoo`05Ool5000FOol5001WOol006Ioo`<000Moo`<000Ioo`<000Ioo`<000aoo`03001oogoo00Io
o`<001Moo`D006Moo`00IGoo1@009goo00<007ooOol087oo1@00Igoo001UOol5000GOol30006Ool3
0004Ool5000;Ool30006Ool30008Ool3000017oo00000000I7oo001UOol5000FOol50004Ool50003
Ool60009Ool50004Ool5000:Ool5001SOol006Ioo`<001Moo`D000Aoo`D000=oo`H000Uoo`D000Ao
o`D000Yoo`D006=oo`00MWoo0`001goo1@0017oo1@000goo1P002Goo1@0017oo1@002Woo1@00Hgoo
001eOol50007Ool30006Ool30004Ool00`00Ool00002000;Ool30006Ool3000<Ool3001TOol007Eo
o`D001Moo`<000Ioo`<008=oo`00MGoo1@005Woo1@0017oo1@00PWoo001fOol30009Ool50002Ool2
0005Ool50004Ool50022Ool008Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool50004Ool50022
Ool008Aoo`03001oogoo00Aoo`03001oogoo00=oo`<000Ioo`<008=oo`00Q7oo00<007ooOol00Woo
0P001Woo00<007ooOol0S7oo0024Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`2<Ool0
08=oo`8000Aoo`<000Eoo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {285.438, 0}} -> {-15.9928, -15.7218, \
0.110295, 0.110295}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[141]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tiling2D[SphericalCut[N[QL], 10], \ 1.0]\)], "Input",
  CellLabel->"In[142]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.01214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.502856 0.0483925 0.506068 0.0483925 [
[ 0 0 0 0 ]
[ 1 1.01214 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.01214 L
0 1.01214 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.40607 .20819 m
.36692 .17975 L
s
.40607 .20819 m
.44522 .23664 L
s
.40607 .20819 m
.36692 .17975 L
s
.40607 .20819 m
.42103 .16217 L
s
.40607 .20819 m
.39112 .25422 L
s
.40607 .20819 m
.42103 .16217 L
s
.40607 .80394 m
.45446 .80394 L
s
.40607 .80394 m
.36692 .83239 L
s
.40607 .80394 m
.44522 .7755 L
s
.40607 .80394 m
.36692 .83239 L
s
.40607 .80394 m
.42103 .84997 L
s
.40607 .80394 m
.39112 .75792 L
s
.40607 .80394 m
.42103 .84997 L
s
.45446 .80394 m
.49361 .7755 L
s
.45446 .80394 m
.46942 .84997 L
s
.45446 .80394 m
.46942 .84997 L
s
.50286 .0241 m
.51781 .07012 L
s
.50286 .0241 m
.51781 .07012 L
s
.18965 .50607 m
.2288 .47762 L
s
.18965 .50607 m
.2288 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .50607 m
.2288 .47762 L
s
.18965 .50607 m
.2288 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .44918 m
.2288 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.2288 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.20461 .40316 L
s
.18965 .44918 m
.20461 .40316 L
s
.18965 .56296 m
.2288 .53451 L
s
.18965 .56296 m
.2288 .5914 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.1505 .5914 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.2288 .53451 L
s
.18965 .56296 m
.2288 .5914 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.20461 .60898 L
s
.46371 .53451 m
.42456 .50607 L
s
.46371 .53451 m
.42456 .56296 L
s
.46371 .53451 m
.5121 .53451 L
s
.46371 .53451 m
.47866 .48849 L
s
.46371 .53451 m
.47866 .58054 L
s
.42456 .50607 m
.3854 .53451 L
s
.42456 .50607 m
.43951 .46004 L
s
.42456 .56296 m
.3854 .53451 L
s
.42456 .56296 m
.43951 .60898 L
s
.3854 .53451 m
.34625 .50607 L
s
.3854 .53451 m
.34625 .56296 L
s
.3854 .53451 m
.40036 .48849 L
s
.3854 .53451 m
.40036 .58054 L
s
.34625 .50607 m
.3071 .47762 L
s
.34625 .50607 m
.3071 .53451 L
s
.34625 .50607 m
.3071 .47762 L
s
.34625 .50607 m
.3071 .53451 L
s
.34625 .50607 m
.36121 .46004 L
s
.34625 .56296 m
.3071 .53451 L
s
.34625 .56296 m
.3071 .53451 L
s
.34625 .56296 m
.36121 .60898 L
s
.3071 .47762 m
.26795 .50607 L
s
.3071 .47762 m
.26795 .50607 L
s
.3071 .47762 m
.32206 .4316 L
s
.3071 .47762 m
.32206 .4316 L
s
.3071 .53451 m
.26795 .50607 L
s
.3071 .53451 m
.26795 .56296 L
s
.3071 .53451 m
.26795 .50607 L
s
.3071 .53451 m
.26795 .56296 L
s
.3071 .53451 m
.32206 .58054 L
s
.3071 .53451 m
.32206 .58054 L
s
.26795 .50607 m
.2288 .47762 L
s
.26795 .50607 m
.2288 .53451 L
s
.26795 .50607 m
.3071 .47762 L
s
.26795 .50607 m
.3071 .53451 L
s
.26795 .50607 m
.2288 .47762 L
s
.26795 .50607 m
.2288 .53451 L
s
.26795 .50607 m
.28291 .46004 L
s
.26795 .56296 m
.2288 .53451 L
s
.26795 .56296 m
.2288 .5914 L
s
.26795 .56296 m
.3071 .53451 L
s
.26795 .56296 m
.2288 .53451 L
s
.26795 .56296 m
.2288 .5914 L
s
.26795 .56296 m
.28291 .60898 L
s
.26795 .56296 m
.28291 .60898 L
s
.26795 .56296 m
.28291 .60898 L
s
.2288 .47762 m
.18965 .50607 L
s
.2288 .47762 m
.18965 .44918 L
s
.2288 .47762 m
.26795 .50607 L
s
.2288 .47762 m
.24376 .4316 L
s
.2288 .47762 m
.24376 .4316 L
s
.2288 .53451 m
.18965 .50607 L
s
.2288 .53451 m
.18965 .56296 L
s
.2288 .53451 m
.26795 .50607 L
s
.2288 .53451 m
.26795 .56296 L
s
.2288 .5914 m
.18965 .56296 L
s
.2288 .5914 m
.26795 .56296 L
s
.2288 .5914 m
.24376 .63743 L
s
.2288 .5914 m
.24376 .63743 L
s
.2288 .5914 m
.24376 .63743 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .50607 m
.2288 .47762 L
s
.18965 .50607 m
.2288 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .50607 m
.1505 .47762 L
s
.18965 .50607 m
.1505 .53451 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.2288 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.1505 .47762 L
s
.18965 .44918 m
.20461 .40316 L
s
.18965 .44918 m
.20461 .40316 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.1505 .5914 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.2288 .53451 L
s
.18965 .56296 m
.2288 .5914 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.1505 .53451 L
s
.18965 .56296 m
.20461 .60898 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .44918 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .56296 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .56296 L
s
.1505 .5914 m
.11135 .56296 L
s
.1505 .5914 m
.11135 .56296 L
s
.1505 .5914 m
.16546 .63743 L
s
.1505 .5914 m
.16546 .63743 L
s
.11135 .50607 m
.0722 .47762 L
s
.11135 .50607 m
.0722 .53451 L
s
.11135 .50607 m
.1505 .47762 L
s
.11135 .50607 m
.1505 .53451 L
s
.11135 .50607 m
.1505 .47762 L
s
.11135 .50607 m
.1505 .53451 L
s
.11135 .50607 m
.1505 .47762 L
s
.11135 .50607 m
.1505 .53451 L
s
.11135 .50607 m
.0722 .53451 L
s
.11135 .50607 m
.0722 .47762 L
s
.11135 .56296 m
.0722 .53451 L
s
.11135 .56296 m
.1505 .53451 L
s
.11135 .56296 m
.1505 .53451 L
s
.11135 .56296 m
.1505 .53451 L
s
.11135 .56296 m
.06296 .56296 L
s
.11135 .56296 m
.0722 .53451 L
s
.11135 .56296 m
.12631 .60898 L
s
.11135 .56296 m
.12631 .60898 L
s
.0722 .47762 m
.03305 .50607 L
s
.0722 .47762 m
.11135 .50607 L
s
.0722 .47762 m
.11135 .50607 L
s
.0722 .47762 m
.11135 .44918 L
s
.0722 .47762 m
.02381 .47762 L
s
.0722 .47762 m
.08716 .4316 L
s
.0722 .47762 m
.08716 .4316 L
s
.0722 .53451 m
.03305 .50607 L
s
.0722 .53451 m
.11135 .50607 L
s
.0722 .53451 m
.11135 .50607 L
s
.0722 .53451 m
.11135 .56296 L
s
.0722 .53451 m
.02381 .53451 L
s
.0722 .53451 m
.02381 .53451 L
s
.03305 .50607 m
.0722 .53451 L
s
.03305 .50607 m
.0722 .47762 L
s
.65946 .32197 m
.70785 .32197 L
s
.65946 .32197 m
.62031 .29353 L
s
.65946 .32197 m
.6445 .368 L
s
.70785 .32197 m
.75624 .32197 L
s
.70785 .32197 m
.6687 .29353 L
s
.70785 .32197 m
.7228 .27595 L
s
.70785 .32197 m
.6929 .368 L
s
.70785 .32197 m
.7228 .27595 L
s
.70785 .69016 m
.75624 .69016 L
s
.70785 .69016 m
.6687 .71861 L
s
.70785 .69016 m
.6929 .64414 L
s
.75624 .50607 m
.80463 .50607 L
s
.75624 .50607 m
.74129 .46004 L
s
.75624 .50607 m
.74129 .55209 L
s
.75624 .41402 m
.80463 .41402 L
s
.75624 .41402 m
.74129 .368 L
s
.75624 .41402 m
.74129 .46004 L
s
.75624 .59812 m
.80463 .59812 L
s
.75624 .59812 m
.74129 .55209 L
s
.75624 .59812 m
.74129 .64414 L
s
.75624 .32197 m
.80463 .32197 L
s
.75624 .32197 m
.7712 .27595 L
s
.75624 .32197 m
.74129 .368 L
s
.75624 .32197 m
.7712 .27595 L
s
.75624 .69016 m
.80463 .69016 L
s
.75624 .69016 m
.71709 .71861 L
s
.75624 .69016 m
.7712 .73619 L
s
.75624 .69016 m
.74129 .64414 L
s
.75624 .69016 m
.7712 .73619 L
s
.80463 .50607 m
.85303 .50607 L
s
.80463 .50607 m
.78968 .46004 L
s
.80463 .50607 m
.78968 .55209 L
s
.80463 .41402 m
.85303 .41402 L
s
.80463 .41402 m
.78968 .368 L
s
.80463 .41402 m
.78968 .46004 L
s
.80463 .59812 m
.85303 .59812 L
s
.80463 .59812 m
.78968 .55209 L
s
.80463 .59812 m
.78968 .64414 L
s
.80463 .32197 m
.85303 .32197 L
s
.80463 .32197 m
.81959 .27595 L
s
.80463 .32197 m
.78968 .368 L
s
.80463 .32197 m
.81959 .27595 L
s
.80463 .69016 m
.85303 .69016 L
s
.80463 .69016 m
.81959 .73619 L
s
.80463 .69016 m
.78968 .64414 L
s
.80463 .69016 m
.81959 .73619 L
s
.80463 .69016 m
.85303 .69016 L
s
.85303 .50607 m
.86798 .46004 L
s
.85303 .50607 m
.86798 .55209 L
s
.85303 .50607 m
.83807 .46004 L
s
.85303 .50607 m
.83807 .55209 L
s
.85303 .50607 m
.86798 .46004 L
s
.85303 .50607 m
.86798 .55209 L
s
.85303 .50607 m
.86798 .46004 L
s
.85303 .50607 m
.86798 .55209 L
s
.85303 .50607 m
.86798 .46004 L
s
.85303 .41402 m
.86798 .368 L
s
.85303 .41402 m
.86798 .46004 L
s
.85303 .41402 m
.86798 .368 L
s
.85303 .41402 m
.83807 .368 L
s
.85303 .41402 m
.83807 .46004 L
s
.85303 .41402 m
.86798 .368 L
s
.85303 .41402 m
.86798 .46004 L
s
.85303 .41402 m
.86798 .368 L
s
.85303 .41402 m
.86798 .46004 L
s
.85303 .41402 m
.86798 .46004 L
s
.85303 .59812 m
.86798 .55209 L
s
.85303 .59812 m
.86798 .64414 L
s
.85303 .59812 m
.83807 .55209 L
s
.85303 .59812 m
.83807 .64414 L
s
.85303 .59812 m
.86798 .55209 L
s
.85303 .59812 m
.86798 .64414 L
s
.85303 .59812 m
.86798 .64414 L
s
.85303 .59812 m
.86798 .55209 L
s
.85303 .32197 m
.86798 .368 L
s
.85303 .32197 m
.86798 .27595 L
s
.85303 .32197 m
.86798 .368 L
s
.85303 .32197 m
.83807 .368 L
s
.85303 .32197 m
.86798 .27595 L
s
.85303 .32197 m
.86798 .368 L
s
.85303 .32197 m
.86798 .368 L
s
.85303 .32197 m
.86798 .27595 L
s
.85303 .69016 m
.86798 .64414 L
s
.85303 .69016 m
.86798 .73619 L
s
.85303 .69016 m
.83807 .64414 L
s
.85303 .69016 m
.86798 .64414 L
s
.85303 .69016 m
.86798 .73619 L
s
.85303 .69016 m
.89218 .71861 L
s
.85303 .69016 m
.86798 .64414 L
s
.85303 .69016 m
.86798 .73619 L
s
.85303 .69016 m
.86798 .73619 L
s
.36692 .17975 m
.32777 .15131 L
s
.36692 .17975 m
.32777 .20819 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .17975 m
.35197 .22577 L
s
.36692 .17975 m
.35197 .22577 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .83239 m
.32777 .86083 L
s
.36692 .83239 m
.38187 .87841 L
s
.36692 .83239 m
.38187 .87841 L
s
.36692 .83239 m
.32777 .86083 L
s
.36692 .83239 m
.35197 .78636 L
s
.36692 .83239 m
.35197 .78636 L
s
.36692 .83239 m
.38187 .87841 L
s
.36692 .83239 m
.38187 .87841 L
s
.5121 .53451 m
.52705 .48849 L
s
.5121 .53451 m
.52705 .58054 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .44918 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .56296 L
s
.3071 .47762 m
.26795 .50607 L
s
.3071 .47762 m
.32206 .4316 L
s
.3071 .47762 m
.32206 .4316 L
s
.3071 .53451 m
.26795 .50607 L
s
.3071 .53451 m
.26795 .56296 L
s
.3071 .53451 m
.32206 .58054 L
s
.3071 .53451 m
.32206 .58054 L
s
.57191 .29353 m
.62031 .29353 L
s
.57191 .29353 m
.53276 .26508 L
s
.57191 .29353 m
.55696 .33955 L
s
.62031 .29353 m
.6687 .29353 L
s
.62031 .29353 m
.58116 .26508 L
s
.62031 .29353 m
.63526 .2475 L
s
.62031 .29353 m
.60535 .33955 L
s
.62031 .29353 m
.63526 .2475 L
s
.62031 .71861 m
.6687 .71861 L
s
.62031 .71861 m
.58116 .74705 L
s
.62031 .71861 m
.60535 .67258 L
s
.6687 .29353 m
.68365 .2475 L
s
.6687 .29353 m
.68365 .2475 L
s
.6687 .71861 m
.71709 .71861 L
s
.6687 .71861 m
.62955 .74705 L
s
.6687 .71861 m
.68365 .76463 L
s
.6687 .71861 m
.65375 .67258 L
s
.6687 .71861 m
.68365 .76463 L
s
.71709 .71861 m
.73205 .76463 L
s
.71709 .71861 m
.73205 .76463 L
s
.11135 .50607 m
.1505 .47762 L
s
.11135 .50607 m
.1505 .53451 L
s
.11135 .50607 m
.1505 .47762 L
s
.11135 .50607 m
.1505 .53451 L
s
.11135 .50607 m
.0722 .53451 L
s
.11135 .50607 m
.0722 .47762 L
s
.26795 .50607 m
.2288 .47762 L
s
.26795 .50607 m
.2288 .53451 L
s
.26795 .50607 m
.28291 .46004 L
s
.26795 .56296 m
.2288 .53451 L
s
.26795 .56296 m
.2288 .5914 L
s
.26795 .56296 m
.28291 .60898 L
s
.26795 .56296 m
.28291 .60898 L
s
.26795 .56296 m
.28291 .60898 L
s
.48437 .26508 m
.53276 .26508 L
s
.48437 .26508 m
.44522 .23664 L
s
.48437 .26508 m
.46942 .31111 L
s
.53276 .26508 m
.58116 .26508 L
s
.53276 .26508 m
.49361 .23664 L
s
.53276 .26508 m
.54772 .21906 L
s
.53276 .26508 m
.51781 .31111 L
s
.53276 .26508 m
.54772 .21906 L
s
.53276 .74705 m
.58116 .74705 L
s
.53276 .74705 m
.49361 .7755 L
s
.53276 .74705 m
.51781 .70103 L
s
.58116 .26508 m
.59611 .21906 L
s
.58116 .26508 m
.59611 .21906 L
s
.58116 .74705 m
.62955 .74705 L
s
.58116 .74705 m
.54201 .7755 L
s
.58116 .74705 m
.59611 .79308 L
s
.58116 .74705 m
.5662 .70103 L
s
.58116 .74705 m
.59611 .79308 L
s
.62955 .74705 m
.6445 .79308 L
s
.62955 .74705 m
.6445 .79308 L
s
.2288 .47762 m
.24376 .4316 L
s
.2288 .47762 m
.24376 .4316 L
s
.2288 .5914 m
.24376 .63743 L
s
.2288 .5914 m
.24376 .63743 L
s
.2288 .5914 m
.24376 .63743 L
s
.44522 .23664 m
.49361 .23664 L
s
.44522 .23664 m
.46018 .19061 L
s
.44522 .23664 m
.43027 .28266 L
s
.44522 .23664 m
.46018 .19061 L
s
.44522 .7755 m
.49361 .7755 L
s
.44522 .7755 m
.43027 .72947 L
s
.49361 .23664 m
.50857 .19061 L
s
.49361 .23664 m
.50857 .19061 L
s
.49361 .7755 m
.54201 .7755 L
s
.49361 .7755 m
.50857 .82152 L
s
.49361 .7755 m
.47866 .72947 L
s
.49361 .7755 m
.50857 .82152 L
s
.54201 .7755 m
.55696 .82152 L
s
.54201 .7755 m
.55696 .82152 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .44918 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .56296 L
s
.1505 .47762 m
.11135 .50607 L
s
.1505 .47762 m
.11135 .44918 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .47762 m
.16546 .4316 L
s
.1505 .53451 m
.11135 .50607 L
s
.1505 .53451 m
.11135 .56296 L
s
.36692 .17975 m
.32777 .15131 L
s
.36692 .17975 m
.32777 .20819 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .17975 m
.35197 .22577 L
s
.36692 .17975 m
.35197 .22577 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .17975 m
.38187 .13373 L
s
.36692 .83239 m
.32777 .86083 L
s
.36692 .83239 m
.38187 .87841 L
s
.36692 .83239 m
.38187 .87841 L
s
.36692 .83239 m
.32777 .86083 L
s
.36692 .83239 m
.35197 .78636 L
s
.36692 .83239 m
.35197 .78636 L
s
.36692 .83239 m
.38187 .87841 L
s
.36692 .83239 m
.38187 .87841 L
s
.06296 .56296 m
.11135 .56296 L
s
.06296 .56296 m
.02381 .53451 L
s
.06296 .56296 m
.02381 .53451 L
s
.06296 .56296 m
.07791 .60898 L
s
.11135 .50607 m
.0722 .53451 L
s
.11135 .50607 m
.0722 .47762 L
s
.11135 .56296 m
.0722 .53451 L
s
.11135 .56296 m
.12631 .60898 L
s
.11135 .56296 m
.12631 .60898 L
s
.11135 .44918 m
.0722 .47762 L
s
.11135 .44918 m
.12631 .40316 L
s
.11135 .44918 m
.12631 .40316 L
s
.32777 .15131 m
.28862 .17975 L
s
.32777 .15131 m
.28862 .17975 L
s
.32777 .15131 m
.34272 .10528 L
s
.32777 .15131 m
.28862 .17975 L
s
.32777 .15131 m
.34272 .10528 L
s
.32777 .15131 m
.34272 .10528 L
s
.32777 .20819 m
.28862 .17975 L
s
.32777 .20819 m
.28862 .17975 L
s
.32777 .20819 m
.28862 .17975 L
s
.32777 .20819 m
.31282 .25422 L
s
.32777 .20819 m
.31282 .25422 L
s
.32777 .86083 m
.28862 .83239 L
s
.32777 .86083 m
.31282 .90685 L
s
.32777 .86083 m
.34272 .90685 L
s
.32777 .86083 m
.28862 .83239 L
s
.32777 .86083 m
.34272 .90685 L
s
.32777 .86083 m
.31282 .81481 L
s
.32777 .86083 m
.34272 .90685 L
s
.32777 .86083 m
.34272 .90685 L
s
.02381 .53451 m
.0722 .53451 L
s
.02381 .53451 m
.03876 .58054 L
s
.02381 .53451 m
.03876 .58054 L
s
.0722 .53451 m
.02381 .53451 L
s
.0722 .47762 m
.02381 .47762 L
s
.0722 .47762 m
.08716 .4316 L
s
.0722 .47762 m
.08716 .4316 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.27367 .13373 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .17975 m
.27367 .22577 L
s
.28862 .17975 m
.27367 .22577 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.27367 .13373 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .17975 m
.27367 .22577 L
s
.28862 .17975 m
.27367 .22577 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .83239 m
.24947 .80394 L
s
.28862 .83239 m
.27367 .87841 L
s
.28862 .83239 m
.32777 .86083 L
s
.28862 .83239 m
.24947 .80394 L
s
.28862 .83239 m
.27367 .87841 L
s
.28862 .83239 m
.27367 .78636 L
s
.28862 .83239 m
.27367 .78636 L
s
.28862 .83239 m
.24947 .80394 L
s
.24947 .20819 m
.23452 .16217 L
s
.24947 .20819 m
.23452 .25422 L
s
.24947 .20819 m
.28862 .17975 L
s
.24947 .20819 m
.23452 .16217 L
s
.24947 .20819 m
.23452 .25422 L
s
.24947 .80394 m
.23452 .75792 L
s
.24947 .80394 m
.23452 .84997 L
s
.24947 .80394 m
.28862 .83239 L
s
.24947 .80394 m
.23452 .84997 L
s
.24947 .80394 m
.23452 .75792 L
s
.02381 .47762 m
.03876 .4316 L
s
.02381 .47762 m
.03876 .4316 L
s
.02381 .53451 m
.03876 .58054 L
s
.02381 .53451 m
.03876 .58054 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .35713 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.09287 .35713 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .35713 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.09287 .35713 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .26508 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.14126 .35713 L
s
.15621 .31111 m
.14126 .35713 L
s
.15621 .31111 m
.10782 .31111 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.14126 .26508 L
s
.15621 .31111 m
.14126 .26508 L
s
.31282 .90685 m
.27367 .87841 L
s
.31282 .90685 m
.32777 .86083 L
s
.31282 .90685 m
.32777 .95288 L
s
.31282 .90685 m
.27367 .87841 L
s
.31282 .90685 m
.32777 .95288 L
s
.31282 .90685 m
.32777 .95288 L
s
.27367 .13373 m
.23452 .16217 L
s
.27367 .13373 m
.28862 .17975 L
s
.27367 .13373 m
.28862 .0877 L
s
.27367 .13373 m
.23452 .16217 L
s
.27367 .13373 m
.28862 .0877 L
s
.27367 .13373 m
.28862 .0877 L
s
.27367 .87841 m
.23452 .84997 L
s
.27367 .87841 m
.28862 .83239 L
s
.27367 .87841 m
.28862 .92443 L
s
.27367 .87841 m
.23452 .84997 L
s
.27367 .87841 m
.28862 .92443 L
s
.27367 .87841 m
.28862 .92443 L
s
.18612 .84997 m
.23452 .84997 L
s
.18612 .84997 m
.14697 .82152 L
s
.18612 .84997 m
.23452 .84997 L
s
.18612 .84997 m
.14697 .82152 L
s
.18612 .84997 m
.17117 .80394 L
s
.18612 .84997 m
.14697 .82152 L
s
.23452 .16217 m
.19537 .19061 L
s
.23452 .16217 m
.19537 .19061 L
s
.23452 .16217 m
.21956 .11615 L
s
.23452 .16217 m
.24947 .20819 L
s
.23452 .16217 m
.24947 .11615 L
s
.23452 .16217 m
.19537 .19061 L
s
.23452 .16217 m
.19537 .19061 L
s
.23452 .16217 m
.24947 .11615 L
s
.23452 .16217 m
.21956 .20819 L
s
.23452 .16217 m
.24947 .20819 L
s
.23452 .16217 m
.24947 .11615 L
s
.23452 .25422 m
.19537 .28266 L
s
.23452 .25422 m
.19537 .28266 L
s
.23452 .25422 m
.24947 .20819 L
s
.23452 .25422 m
.21956 .30024 L
s
.23452 .25422 m
.27367 .22577 L
s
.23452 .25422 m
.27367 .28266 L
s
.23452 .25422 m
.27367 .22577 L
s
.23452 .25422 m
.27367 .28266 L
s
.23452 .25422 m
.19537 .28266 L
s
.23452 .25422 m
.19537 .28266 L
s
.23452 .25422 m
.21956 .20819 L
s
.23452 .25422 m
.24947 .20819 L
s
.23452 .75792 m
.19537 .72947 L
s
.23452 .75792 m
.19537 .72947 L
s
.23452 .75792 m
.24947 .80394 L
s
.23452 .75792 m
.21956 .71189 L
s
.23452 .75792 m
.27367 .78636 L
s
.23452 .75792 m
.27367 .78636 L
s
.23452 .75792 m
.19537 .72947 L
s
.23452 .75792 m
.19537 .72947 L
s
.23452 .75792 m
.21956 .80394 L
s
.23452 .75792 m
.24947 .80394 L
s
.23452 .84997 m
.21956 .89599 L
s
.23452 .84997 m
.24947 .80394 L
s
.23452 .84997 m
.27367 .87841 L
s
.23452 .84997 m
.18612 .84997 L
s
.23452 .84997 m
.21956 .80394 L
s
.23452 .84997 m
.24947 .80394 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .72947 m
.13202 .68345 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.13202 .68345 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .19061 m
.19537 .19061 L
s
.14697 .19061 m
.19537 .19061 L
s
.14697 .19061 m
.13202 .23664 L
s
.14697 .19061 m
.19537 .19061 L
s
.14697 .19061 m
.19537 .19061 L
s
.14697 .19061 m
.13202 .23664 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .72947 m
.13202 .68345 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.13202 .68345 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .82152 m
.13202 .7755 L
s
.14697 .82152 m
.18612 .84997 L
s
.14697 .82152 m
.13202 .7755 L
s
.14697 .82152 m
.13202 .7755 L
s
.19537 .19061 m
.23452 .16217 L
s
.19537 .19061 m
.14697 .19061 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.14697 .19061 L
s
.19537 .19061 m
.23452 .16217 L
s
.19537 .19061 m
.14697 .19061 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.14697 .19061 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.18041 .32869 L
s
.19537 .28266 m
.18041 .32869 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.23452 .25422 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.18041 .32869 L
s
.19537 .28266 m
.18041 .32869 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.23452 .25422 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .72947 m
.18041 .68345 L
s
.19537 .72947 m
.18041 .68345 L
s
.19537 .72947 m
.23452 .75792 L
s
.19537 .72947 m
.14697 .72947 L
s
.19537 .72947 m
.18041 .7755 L
s
.19537 .72947 m
.18041 .7755 L
s
.19537 .72947 m
.18041 .68345 L
s
.19537 .72947 m
.18041 .68345 L
s
.19537 .72947 m
.23452 .75792 L
s
.19537 .72947 m
.14697 .72947 L
s
.19537 .72947 m
.18041 .7755 L
s
.19537 .72947 m
.18041 .7755 L
s
.15621 .31111 m
.14126 .35713 L
s
.15621 .31111 m
.14126 .35713 L
s
.15621 .31111 m
.10782 .31111 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.14126 .26508 L
s
.15621 .31111 m
.14126 .26508 L
s
.09287 .26508 m
.13202 .23664 L
s
.09287 .26508 m
.07791 .31111 L
s
.09287 .26508 m
.10782 .31111 L
s
.09287 .26508 m
.14126 .26508 L
s
.09287 .26508 m
.13202 .23664 L
s
.09287 .26508 m
.14126 .26508 L
s
.21956 .11615 m
.23452 .16217 L
s
.21956 .89599 m
.23452 .84997 L
s
.13202 .23664 m
.09287 .26508 L
s
.13202 .23664 m
.14697 .19061 L
s
.13202 .23664 m
.09287 .26508 L
s
.13202 .23664 m
.18041 .23664 L
s
.13202 .23664 m
.18041 .23664 L
s
.13202 .23664 m
.09287 .26508 L
s
.13202 .23664 m
.14697 .19061 L
s
.13202 .7755 m
.14697 .82152 L
s
.13202 .7755 m
.11706 .72947 L
s
.13202 .7755 m
.14697 .72947 L
s
.13202 .7755 m
.09287 .74705 L
s
.13202 .7755 m
.17117 .80394 L
s
.13202 .7755 m
.18041 .7755 L
s
.13202 .7755 m
.18041 .7755 L
s
.13202 .7755 m
.09287 .74705 L
s
.13202 .7755 m
.14697 .82152 L
s
.09287 .26508 m
.07791 .31111 L
s
.09287 .26508 m
.10782 .31111 L
s
.09287 .26508 m
.14126 .26508 L
s
.09287 .26508 m
.13202 .23664 L
s
.09287 .26508 m
.14126 .26508 L
s
.42103 .16217 m
.38187 .13373 L
s
.42103 .16217 m
.46018 .19061 L
s
.42103 .16217 m
.38187 .13373 L
s
.42103 .16217 m
.38187 .13373 L
s
.42103 .16217 m
.46018 .19061 L
s
.42103 .16217 m
.38187 .13373 L
s
.42103 .16217 m
.43598 .11615 L
s
.42103 .16217 m
.43598 .11615 L
s
.42103 .84997 m
.46942 .84997 L
s
.42103 .84997 m
.38187 .87841 L
s
.42103 .84997 m
.38187 .87841 L
s
.42103 .84997 m
.46942 .84997 L
s
.42103 .84997 m
.38187 .87841 L
s
.42103 .84997 m
.38187 .87841 L
s
.42103 .84997 m
.43598 .89599 L
s
.46942 .84997 m
.50857 .82152 L
s
.46942 .84997 m
.42103 .84997 L
s
.46942 .84997 m
.50857 .82152 L
s
.46942 .84997 m
.48437 .89599 L
s
.46942 .84997 m
.48437 .89599 L
s
.5662 .46004 m
.6146 .46004 L
s
.5662 .46004 m
.52705 .4316 L
s
.5662 .46004 m
.52705 .48849 L
s
.5662 .46004 m
.58116 .50607 L
s
.5662 .46004 m
.58116 .41402 L
s
.5662 .55209 m
.6146 .55209 L
s
.5662 .55209 m
.52705 .58054 L
s
.5662 .55209 m
.58116 .50607 L
s
.6146 .46004 m
.66299 .46004 L
s
.6146 .46004 m
.62955 .50607 L
s
.6146 .46004 m
.62955 .41402 L
s
.6146 .55209 m
.66299 .55209 L
s
.6146 .55209 m
.57544 .58054 L
s
.6146 .55209 m
.62955 .50607 L
s
.6146 .55209 m
.62955 .59812 L
s
.66299 .46004 m
.67794 .50607 L
s
.66299 .46004 m
.67794 .41402 L
s
.66299 .55209 m
.67794 .50607 L
s
.66299 .55209 m
.67794 .59812 L
s
.20461 .40316 m
.24376 .37471 L
s
.20461 .40316 m
.24376 .4316 L
s
.20461 .40316 m
.16546 .4316 L
s
.20461 .40316 m
.24376 .37471 L
s
.20461 .40316 m
.24376 .4316 L
s
.20461 .40316 m
.16546 .37471 L
s
.20461 .40316 m
.16546 .4316 L
s
.20461 .40316 m
.21956 .35713 L
s
.36121 .46004 m
.32206 .4316 L
s
.36121 .46004 m
.40036 .4316 L
s
.36121 .46004 m
.40036 .48849 L
s
.36121 .46004 m
.32206 .4316 L
s
.36121 .40316 m
.32206 .4316 L
s
.36121 .40316 m
.40036 .4316 L
s
.36121 .40316 m
.32206 .4316 L
s
.36121 .40316 m
.37616 .35713 L
s
.36121 .60898 m
.32206 .58054 L
s
.36121 .60898 m
.32206 .63743 L
s
.36121 .60898 m
.32206 .63743 L
s
.36121 .60898 m
.40036 .58054 L
s
.36121 .60898 m
.40036 .63743 L
s
.36121 .60898 m
.32206 .58054 L
s
.36121 .60898 m
.37616 .655 L
s
.7228 .27595 m
.7712 .27595 L
s
.7228 .27595 m
.68365 .2475 L
s
.7228 .27595 m
.7712 .27595 L
s
.7228 .27595 m
.68365 .2475 L
s
.7228 .27595 m
.73776 .22992 L
s
.7712 .27595 m
.81959 .27595 L
s
.7712 .27595 m
.7228 .27595 L
s
.7712 .27595 m
.81959 .27595 L
s
.7712 .27595 m
.78615 .22992 L
s
.7712 .73619 m
.81959 .73619 L
s
.7712 .73619 m
.73205 .76463 L
s
.7712 .73619 m
.81959 .73619 L
s
.7712 .73619 m
.73205 .76463 L
s
.7712 .73619 m
.78615 .78221 L
s
.81959 .27595 m
.86798 .27595 L
s
.81959 .27595 m
.7712 .27595 L
s
.81959 .27595 m
.86798 .27595 L
s
.81959 .27595 m
.83454 .22992 L
s
.81959 .27595 m
.86798 .27595 L
s
.81959 .27595 m
.83454 .22992 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.7712 .73619 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.83454 .78221 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.83454 .78221 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .368 m
.90713 .33955 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .46004 m
.88294 .50607 L
s
.86798 .46004 m
.88294 .41402 L
s
.86798 .46004 m
.88294 .41402 L
s
.86798 .46004 m
.90713 .4316 L
s
.86798 .46004 m
.90713 .48849 L
s
.86798 .46004 m
.88294 .50607 L
s
.86798 .46004 m
.88294 .41402 L
s
.86798 .46004 m
.90713 .4316 L
s
.86798 .46004 m
.90713 .48849 L
s
.86798 .55209 m
.88294 .50607 L
s
.86798 .55209 m
.88294 .59812 L
s
.86798 .55209 m
.88294 .59812 L
s
.86798 .55209 m
.90713 .58054 L
s
.86798 .55209 m
.88294 .50607 L
s
.86798 .55209 m
.88294 .59812 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.85303 .69016 L
s
.86798 .64414 m
.90713 .67258 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.90713 .67258 L
s
.86798 .27595 m
.88294 .32197 L
s
.86798 .27595 m
.81959 .27595 L
s
.86798 .27595 m
.88294 .22992 L
s
.86798 .27595 m
.88294 .32197 L
s
.86798 .27595 m
.90713 .2475 L
s
.86798 .27595 m
.88294 .22992 L
s
.86798 .27595 m
.88294 .32197 L
s
.86798 .27595 m
.90713 .2475 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .368 m
.90713 .33955 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .73619 m
.81959 .73619 L
s
.86798 .73619 m
.88294 .78221 L
s
.86798 .73619 m
.85303 .69016 L
s
.86798 .73619 m
.90713 .76463 L
s
.86798 .73619 m
.90713 .76463 L
s
.86798 .73619 m
.88294 .78221 L
s
.86798 .73619 m
.90713 .76463 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.42103 .16217 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.42103 .84997 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.47866 .4316 m
.52705 .4316 L
s
.47866 .4316 m
.43951 .46004 L
s
.47866 .4316 m
.49361 .38558 L
s
.47866 .48849 m
.52705 .48849 L
s
.47866 .48849 m
.43951 .46004 L
s
.47866 .58054 m
.52705 .58054 L
s
.47866 .58054 m
.43951 .60898 L
s
.52705 .4316 m
.4879 .46004 L
s
.52705 .4316 m
.54201 .38558 L
s
.52705 .48849 m
.4879 .46004 L
s
.52705 .48849 m
.54201 .53451 L
s
.52705 .58054 m
.57544 .58054 L
s
.52705 .58054 m
.4879 .60898 L
s
.52705 .58054 m
.54201 .53451 L
s
.52705 .58054 m
.54201 .62656 L
s
.57544 .58054 m
.5904 .62656 L
s
.32206 .4316 m
.28291 .40316 L
s
.32206 .4316 m
.28291 .46004 L
s
.32206 .4316 m
.28291 .40316 L
s
.32206 .4316 m
.33701 .38558 L
s
.32206 .4316 m
.33701 .38558 L
s
.32206 .58054 m
.28291 .60898 L
s
.32206 .58054 m
.28291 .60898 L
s
.32206 .58054 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .66587 L
s
.32206 .63743 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .66587 L
s
.32206 .63743 m
.33701 .68345 L
s
.32206 .63743 m
.33701 .68345 L
s
.32206 .63743 m
.33701 .68345 L
s
.32206 .63743 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .66587 L
s
.32206 .63743 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .60898 L
s
.32206 .63743 m
.28291 .66587 L
s
.32206 .63743 m
.33701 .68345 L
s
.32206 .63743 m
.33701 .68345 L
s
.32206 .63743 m
.33701 .68345 L
s
.63526 .2475 m
.68365 .2475 L
s
.63526 .2475 m
.59611 .21906 L
s
.63526 .2475 m
.68365 .2475 L
s
.63526 .2475 m
.59611 .21906 L
s
.63526 .2475 m
.65022 .20148 L
s
.68365 .2475 m
.7228 .27595 L
s
.68365 .2475 m
.63526 .2475 L
s
.68365 .2475 m
.69861 .20148 L
s
.68365 .76463 m
.73205 .76463 L
s
.68365 .76463 m
.6445 .79308 L
s
.68365 .76463 m
.73205 .76463 L
s
.68365 .76463 m
.6445 .79308 L
s
.68365 .76463 m
.69861 .81066 L
s
.73205 .76463 m
.7712 .73619 L
s
.73205 .76463 m
.68365 .76463 L
s
.73205 .76463 m
.747 .81066 L
s
.73205 .76463 m
.747 .81066 L
s
.43951 .46004 m
.4879 .46004 L
s
.43951 .46004 m
.40036 .4316 L
s
.43951 .46004 m
.40036 .48849 L
s
.43951 .46004 m
.45446 .41402 L
s
.43951 .60898 m
.4879 .60898 L
s
.43951 .60898 m
.40036 .58054 L
s
.43951 .60898 m
.40036 .63743 L
s
.43951 .60898 m
.45446 .655 L
s
.4879 .60898 m
.50286 .655 L
s
.28291 .40316 m
.24376 .37471 L
s
.28291 .40316 m
.24376 .4316 L
s
.28291 .40316 m
.32206 .4316 L
s
.28291 .40316 m
.24376 .37471 L
s
.28291 .40316 m
.24376 .4316 L
s
.28291 .40316 m
.29786 .35713 L
s
.28291 .40316 m
.29786 .35713 L
s
.28291 .40316 m
.29786 .35713 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .60898 m
.32206 .58054 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .66587 m
.24376 .63743 L
s
.28291 .66587 m
.24376 .63743 L
s
.28291 .66587 m
.24376 .63743 L
s
.28291 .66587 m
.29786 .71189 L
s
.28291 .66587 m
.29786 .71189 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .60898 m
.32206 .58054 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .60898 m
.24376 .63743 L
s
.54772 .21906 m
.59611 .21906 L
s
.54772 .21906 m
.50857 .19061 L
s
.54772 .21906 m
.59611 .21906 L
s
.54772 .21906 m
.50857 .19061 L
s
.54772 .21906 m
.56267 .17304 L
s
.59611 .21906 m
.63526 .2475 L
s
.59611 .21906 m
.54772 .21906 L
s
.59611 .21906 m
.61106 .17304 L
s
.59611 .79308 m
.6445 .79308 L
s
.59611 .79308 m
.55696 .82152 L
s
.59611 .79308 m
.6445 .79308 L
s
.59611 .79308 m
.55696 .82152 L
s
.59611 .79308 m
.61106 .8391 L
s
.6445 .79308 m
.68365 .76463 L
s
.6445 .79308 m
.59611 .79308 L
s
.6445 .79308 m
.65946 .8391 L
s
.40036 .4316 m
.41531 .38558 L
s
.40036 .63743 m
.41531 .68345 L
s
.24376 .37471 m
.28291 .40316 L
s
.24376 .37471 m
.20461 .40316 L
s
.24376 .37471 m
.25871 .32869 L
s
.24376 .37471 m
.25871 .32869 L
s
.24376 .37471 m
.25871 .32869 L
s
.24376 .4316 m
.28291 .46004 L
s
.24376 .4316 m
.28291 .40316 L
s
.24376 .4316 m
.20461 .40316 L
s
.24376 .63743 m
.28291 .60898 L
s
.24376 .63743 m
.28291 .66587 L
s
.24376 .63743 m
.20461 .60898 L
s
.24376 .63743 m
.20461 .66587 L
s
.24376 .63743 m
.25871 .68345 L
s
.24376 .63743 m
.25871 .68345 L
s
.46018 .19061 m
.50857 .19061 L
s
.46018 .19061 m
.42103 .16217 L
s
.46018 .19061 m
.50857 .19061 L
s
.46018 .19061 m
.47513 .14459 L
s
.50857 .19061 m
.54772 .21906 L
s
.50857 .19061 m
.46018 .19061 L
s
.50857 .19061 m
.52352 .14459 L
s
.50857 .82152 m
.55696 .82152 L
s
.50857 .82152 m
.46942 .84997 L
s
.50857 .82152 m
.55696 .82152 L
s
.50857 .82152 m
.52352 .86755 L
s
.55696 .82152 m
.59611 .79308 L
s
.55696 .82152 m
.50857 .82152 L
s
.55696 .82152 m
.57191 .86755 L
s
.32206 .4316 m
.28291 .46004 L
s
.32206 .4316 m
.28291 .40316 L
s
.32206 .4316 m
.33701 .38558 L
s
.32206 .4316 m
.33701 .38558 L
s
.32206 .58054 m
.28291 .60898 L
s
.16546 .4316 m
.12631 .40316 L
s
.16546 .4316 m
.20461 .40316 L
s
.16546 .4316 m
.12631 .40316 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.42103 .16217 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.42103 .84997 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.28291 .46004 m
.24376 .4316 L
s
.28291 .40316 m
.24376 .37471 L
s
.28291 .40316 m
.24376 .4316 L
s
.28291 .40316 m
.29786 .35713 L
s
.28291 .40316 m
.29786 .35713 L
s
.28291 .40316 m
.29786 .35713 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .60898 m
.24376 .63743 L
s
.28291 .66587 m
.24376 .63743 L
s
.28291 .66587 m
.24376 .63743 L
s
.28291 .66587 m
.29786 .71189 L
s
.28291 .66587 m
.29786 .71189 L
s
.07791 .40316 m
.12631 .40316 L
s
.07791 .40316 m
.03876 .4316 L
s
.07791 .40316 m
.12631 .40316 L
s
.07791 .40316 m
.03876 .4316 L
s
.07791 .40316 m
.09287 .35713 L
s
.07791 .40316 m
.09287 .35713 L
s
.07791 .60898 m
.12631 .60898 L
s
.07791 .60898 m
.03876 .58054 L
s
.07791 .60898 m
.12631 .60898 L
s
.07791 .60898 m
.03876 .58054 L
s
.07791 .60898 m
.09287 .655 L
s
.07791 .60898 m
.09287 .655 L
s
.07791 .60898 m
.09287 .655 L
s
.07791 .60898 m
.09287 .655 L
s
.12631 .40316 m
.08716 .4316 L
s
.12631 .40316 m
.16546 .37471 L
s
.12631 .40316 m
.16546 .4316 L
s
.12631 .40316 m
.08716 .4316 L
s
.12631 .40316 m
.14126 .35713 L
s
.12631 .40316 m
.14126 .35713 L
s
.12631 .60898 m
.16546 .63743 L
s
.12631 .60898 m
.16546 .63743 L
s
.12631 .60898 m
.14126 .655 L
s
.12631 .60898 m
.14126 .655 L
s
.34272 .10528 m
.30357 .13373 L
s
.34272 .10528 m
.30357 .13373 L
s
.34272 .10528 m
.38187 .13373 L
s
.34272 .10528 m
.38187 .13373 L
s
.34272 .10528 m
.32777 .05926 L
s
.34272 .10528 m
.35768 .05926 L
s
.34272 .10528 m
.30357 .13373 L
s
.34272 .10528 m
.32777 .05926 L
s
.34272 .10528 m
.35768 .05926 L
s
.34272 .90685 m
.32777 .86083 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.38187 .87841 L
s
.34272 .90685 m
.38187 .87841 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.24376 .37471 m
.20461 .40316 L
s
.24376 .37471 m
.25871 .32869 L
s
.24376 .37471 m
.25871 .32869 L
s
.24376 .37471 m
.25871 .32869 L
s
.24376 .4316 m
.20461 .40316 L
s
.24376 .63743 m
.20461 .60898 L
s
.24376 .63743 m
.20461 .66587 L
s
.24376 .63743 m
.25871 .68345 L
s
.24376 .63743 m
.25871 .68345 L
s
.24376 .63743 m
.20461 .60898 L
s
.24376 .63743 m
.20461 .66587 L
s
.24376 .63743 m
.25871 .68345 L
s
.24376 .63743 m
.25871 .68345 L
s
.03876 .4316 m
.08716 .4316 L
s
.03876 .4316 m
.08716 .4316 L
s
.03876 .4316 m
.05372 .38558 L
s
.03876 .4316 m
.05372 .38558 L
s
.03876 .4316 m
.05372 .38558 L
s
.03876 .4316 m
.05372 .38558 L
s
.08716 .4316 m
.12631 .40316 L
s
.08716 .4316 m
.03876 .4316 L
s
.30357 .13373 m
.28862 .17975 L
s
.30357 .13373 m
.28862 .0877 L
s
.30357 .13373 m
.34272 .10528 L
s
.30357 .13373 m
.28862 .0877 L
s
.30357 .13373 m
.34272 .10528 L
s
.30357 .13373 m
.28862 .0877 L
s
.20461 .40316 m
.16546 .37471 L
s
.20461 .40316 m
.16546 .4316 L
s
.20461 .40316 m
.21956 .35713 L
s
.20461 .60898 m
.16546 .63743 L
s
.20461 .60898 m
.16546 .63743 L
s
.20461 .66587 m
.16546 .63743 L
s
.20461 .66587 m
.16546 .63743 L
s
.20461 .66587 m
.21956 .71189 L
s
.16546 .37471 m
.12631 .40316 L
s
.16546 .37471 m
.18041 .32869 L
s
.16546 .37471 m
.18041 .32869 L
s
.16546 .4316 m
.12631 .40316 L
s
.16546 .63743 m
.12631 .60898 L
s
.16546 .63743 m
.18041 .68345 L
s
.16546 .63743 m
.18041 .68345 L
s
.16546 .63743 m
.12631 .60898 L
s
.16546 .63743 m
.18041 .68345 L
s
.16546 .63743 m
.18041 .68345 L
s
.12631 .40316 m
.08716 .4316 L
s
.12631 .40316 m
.14126 .35713 L
s
.12631 .40316 m
.14126 .35713 L
s
.12631 .60898 m
.14126 .655 L
s
.12631 .60898 m
.14126 .655 L
s
.03876 .4316 m
.08716 .4316 L
s
.03876 .4316 m
.05372 .38558 L
s
.03876 .4316 m
.05372 .38558 L
s
.03876 .4316 m
.05372 .38558 L
s
.03876 .4316 m
.05372 .38558 L
s
.32777 .86083 m
.28862 .83239 L
s
.32777 .86083 m
.34272 .90685 L
s
.32777 .86083 m
.31282 .81481 L
s
.32777 .86083 m
.34272 .90685 L
s
.32777 .86083 m
.34272 .90685 L
s
.32777 .95288 m
.28862 .92443 L
s
.32777 .95288 m
.34272 .90685 L
s
.32777 .95288 m
.28862 .92443 L
s
.32777 .95288 m
.34272 .90685 L
s
.32777 .95288 m
.34272 .90685 L
s
.32777 .95288 m
.28862 .92443 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .17975 m
.27367 .22577 L
s
.28862 .17975 m
.27367 .22577 L
s
.28862 .17975 m
.24947 .20819 L
s
.28862 .17975 m
.30357 .13373 L
s
.28862 .0877 m
.24947 .11615 L
s
.28862 .0877 m
.30357 .13373 L
s
.28862 .0877 m
.24947 .11615 L
s
.28862 .0877 m
.32777 .05926 L
s
.28862 .0877 m
.30357 .13373 L
s
.28862 .0877 m
.32777 .05926 L
s
.28862 .0877 m
.24947 .11615 L
s
.28862 .83239 m
.24947 .80394 L
s
.28862 .83239 m
.27367 .87841 L
s
.28862 .83239 m
.27367 .78636 L
s
.28862 .83239 m
.27367 .78636 L
s
.28862 .83239 m
.24947 .80394 L
s
.28862 .92443 m
.27367 .87841 L
s
.28862 .92443 m
.32777 .95288 L
s
.28862 .92443 m
.32777 .95288 L
s
.24947 .20819 m
.23452 .16217 L
s
.24947 .20819 m
.23452 .25422 L
s
.24947 .11615 m
.23452 .16217 L
s
.24947 .11615 m
.28862 .0877 L
s
.24947 .11615 m
.28862 .0877 L
s
.24947 .80394 m
.23452 .84997 L
s
.24947 .80394 m
.23452 .75792 L
s
.27367 .87841 m
.23452 .84997 L
s
.27367 .87841 m
.28862 .92443 L
s
.27367 .87841 m
.28862 .92443 L
s
.18612 .84997 m
.23452 .84997 L
s
.18612 .84997 m
.14697 .82152 L
s
.18612 .84997 m
.17117 .80394 L
s
.18612 .84997 m
.14697 .82152 L
s
.23452 .16217 m
.19537 .19061 L
s
.23452 .16217 m
.19537 .19061 L
s
.23452 .16217 m
.24947 .11615 L
s
.23452 .16217 m
.21956 .20819 L
s
.23452 .16217 m
.24947 .20819 L
s
.23452 .16217 m
.24947 .11615 L
s
.23452 .84997 m
.21956 .80394 L
s
.23452 .84997 m
.24947 .80394 L
s
.14697 .19061 m
.19537 .19061 L
s
.14697 .19061 m
.19537 .19061 L
s
.14697 .19061 m
.13202 .23664 L
s
.14697 .82152 m
.13202 .7755 L
s
.14697 .82152 m
.13202 .7755 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.14697 .19061 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.18041 .23664 L
s
.19537 .19061 m
.14697 .19061 L
s
.58116 .50607 m
.62955 .50607 L
s
.58116 .50607 m
.54201 .53451 L
s
.58116 .41402 m
.62955 .41402 L
s
.58116 .41402 m
.54201 .38558 L
s
.62955 .50607 m
.67794 .50607 L
s
.62955 .41402 m
.67794 .41402 L
s
.62955 .41402 m
.5904 .38558 L
s
.62955 .41402 m
.6445 .368 L
s
.62955 .59812 m
.67794 .59812 L
s
.62955 .59812 m
.5904 .62656 L
s
.62955 .59812 m
.6445 .64414 L
s
.67794 .50607 m
.72633 .50607 L
s
.67794 .50607 m
.6929 .46004 L
s
.67794 .50607 m
.6929 .55209 L
s
.67794 .41402 m
.72633 .41402 L
s
.67794 .41402 m
.6929 .368 L
s
.67794 .41402 m
.6929 .46004 L
s
.67794 .59812 m
.72633 .59812 L
s
.67794 .59812 m
.6929 .55209 L
s
.67794 .59812 m
.6929 .64414 L
s
.72633 .50607 m
.74129 .46004 L
s
.72633 .50607 m
.74129 .55209 L
s
.72633 .41402 m
.74129 .368 L
s
.72633 .41402 m
.74129 .46004 L
s
.72633 .59812 m
.74129 .55209 L
s
.72633 .59812 m
.74129 .64414 L
s
.37616 .35713 m
.33701 .32869 L
s
.37616 .35713 m
.33701 .38558 L
s
.37616 .35713 m
.33701 .32869 L
s
.37616 .35713 m
.41531 .32869 L
s
.37616 .35713 m
.41531 .38558 L
s
.37616 .35713 m
.33701 .38558 L
s
.37616 .35713 m
.39112 .31111 L
s
.37616 .655 m
.33701 .68345 L
s
.37616 .655 m
.33701 .68345 L
s
.37616 .655 m
.41531 .68345 L
s
.37616 .655 m
.33701 .68345 L
s
.37616 .71189 m
.33701 .68345 L
s
.37616 .71189 m
.33701 .68345 L
s
.37616 .71189 m
.33701 .74034 L
s
.37616 .71189 m
.41531 .68345 L
s
.37616 .71189 m
.33701 .68345 L
s
.37616 .71189 m
.33701 .74034 L
s
.37616 .71189 m
.39112 .75792 L
s
.88294 .50607 m
.86798 .46004 L
s
.88294 .50607 m
.86798 .55209 L
s
.88294 .50607 m
.86798 .46004 L
s
.88294 .50607 m
.86798 .55209 L
s
.88294 .50607 m
.92209 .53451 L
s
.88294 .50607 m
.86798 .46004 L
s
.88294 .50607 m
.92209 .53451 L
s
.88294 .50607 m
.92209 .53451 L
s
.88294 .41402 m
.86798 .368 L
s
.88294 .41402 m
.86798 .46004 L
s
.88294 .41402 m
.86798 .368 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.86798 .46004 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.86798 .46004 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .59812 m
.86798 .55209 L
s
.88294 .59812 m
.86798 .64414 L
s
.88294 .59812 m
.86798 .64414 L
s
.88294 .59812 m
.92209 .62656 L
s
.88294 .59812 m
.86798 .55209 L
s
.88294 .59812 m
.92209 .62656 L
s
.88294 .59812 m
.92209 .62656 L
s
.88294 .32197 m
.86798 .27595 L
s
.88294 .32197 m
.86798 .368 L
s
.88294 .32197 m
.86798 .368 L
s
.88294 .32197 m
.92209 .29353 L
s
.88294 .32197 m
.86798 .27595 L
s
.88294 .32197 m
.92209 .29353 L
s
.88294 .32197 m
.92209 .29353 L
s
.49361 .38558 m
.54201 .38558 L
s
.49361 .38558 m
.45446 .41402 L
s
.49361 .38558 m
.45446 .35713 L
s
.54201 .38558 m
.5904 .38558 L
s
.54201 .38558 m
.50286 .35713 L
s
.54201 .38558 m
.55696 .33955 L
s
.54201 .62656 m
.5904 .62656 L
s
.54201 .62656 m
.50286 .655 L
s
.54201 .62656 m
.55696 .67258 L
s
.5904 .38558 m
.60535 .33955 L
s
.5904 .62656 m
.60535 .67258 L
s
.33701 .32869 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .30024 L
s
.33701 .32869 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .30024 L
s
.33701 .32869 m
.35197 .28266 L
s
.33701 .32869 m
.35197 .28266 L
s
.33701 .32869 m
.35197 .28266 L
s
.33701 .38558 m
.29786 .35713 L
s
.33701 .38558 m
.29786 .35713 L
s
.33701 .38558 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .30024 L
s
.33701 .32869 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .35713 L
s
.33701 .32869 m
.29786 .30024 L
s
.33701 .32869 m
.35197 .28266 L
s
.33701 .32869 m
.35197 .28266 L
s
.33701 .32869 m
.35197 .28266 L
s
.33701 .68345 m
.29786 .71189 L
s
.33701 .68345 m
.29786 .71189 L
s
.33701 .68345 m
.29786 .71189 L
s
.33701 .68345 m
.29786 .71189 L
s
.33701 .74034 m
.29786 .71189 L
s
.33701 .74034 m
.29786 .71189 L
s
.33701 .74034 m
.35197 .78636 L
s
.33701 .74034 m
.35197 .78636 L
s
.45446 .41402 m
.41531 .38558 L
s
.45446 .35713 m
.50286 .35713 L
s
.45446 .35713 m
.41531 .32869 L
s
.45446 .35713 m
.41531 .38558 L
s
.45446 .35713 m
.46942 .31111 L
s
.45446 .655 m
.50286 .655 L
s
.45446 .655 m
.41531 .68345 L
s
.45446 .655 m
.46942 .70103 L
s
.50286 .35713 m
.51781 .31111 L
s
.50286 .655 m
.51781 .70103 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .35713 m
.33701 .38558 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .30024 m
.25871 .32869 L
s
.29786 .30024 m
.25871 .32869 L
s
.29786 .30024 m
.25871 .32869 L
s
.29786 .30024 m
.31282 .25422 L
s
.29786 .30024 m
.31282 .25422 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .35713 m
.33701 .38558 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .71189 m
.33701 .68345 L
s
.29786 .71189 m
.33701 .74034 L
s
.29786 .71189 m
.25871 .68345 L
s
.29786 .71189 m
.25871 .74034 L
s
.29786 .71189 m
.25871 .68345 L
s
.29786 .71189 m
.25871 .74034 L
s
.29786 .71189 m
.31282 .75792 L
s
.41531 .32869 m
.43027 .28266 L
s
.41531 .68345 m
.43027 .72947 L
s
.25871 .32869 m
.29786 .35713 L
s
.25871 .32869 m
.29786 .30024 L
s
.25871 .32869 m
.21956 .35713 L
s
.25871 .32869 m
.21956 .30024 L
s
.25871 .32869 m
.27367 .28266 L
s
.25871 .32869 m
.27367 .28266 L
s
.33701 .38558 m
.29786 .35713 L
s
.33701 .68345 m
.29786 .71189 L
s
.33701 .74034 m
.29786 .71189 L
s
.33701 .74034 m
.35197 .78636 L
s
.33701 .74034 m
.35197 .78636 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .35713 m
.25871 .32869 L
s
.29786 .30024 m
.25871 .32869 L
s
.29786 .30024 m
.25871 .32869 L
s
.29786 .30024 m
.31282 .25422 L
s
.29786 .30024 m
.31282 .25422 L
s
.29786 .71189 m
.25871 .68345 L
s
.29786 .71189 m
.25871 .74034 L
s
.29786 .71189 m
.25871 .68345 L
s
.29786 .71189 m
.25871 .74034 L
s
.29786 .71189 m
.31282 .75792 L
s
.04448 .655 m
.09287 .655 L
s
.04448 .655 m
.09287 .655 L
s
.04448 .655 m
.09287 .655 L
s
.04448 .655 m
.09287 .655 L
s
.09287 .35713 m
.14126 .35713 L
s
.09287 .35713 m
.05372 .38558 L
s
.09287 .35713 m
.14126 .35713 L
s
.09287 .35713 m
.05372 .38558 L
s
.09287 .35713 m
.07791 .31111 L
s
.09287 .35713 m
.10782 .31111 L
s
.09287 .35713 m
.05372 .38558 L
s
.09287 .35713 m
.05372 .38558 L
s
.09287 .655 m
.14126 .655 L
s
.09287 .655 m
.13202 .68345 L
s
.09287 .655 m
.14126 .655 L
s
.09287 .655 m
.07791 .70103 L
s
.09287 .655 m
.07791 .70103 L
s
.09287 .655 m
.04448 .655 L
s
.09287 .655 m
.13202 .68345 L
s
.14126 .35713 m
.18041 .32869 L
s
.14126 .35713 m
.18041 .32869 L
s
.14126 .35713 m
.15621 .31111 L
s
.14126 .35713 m
.15621 .31111 L
s
.14126 .35713 m
.09287 .35713 L
s
.14126 .655 m
.18041 .68345 L
s
.14126 .655 m
.18041 .68345 L
s
.14126 .655 m
.09287 .655 L
s
.14126 .655 m
.09287 .655 L
s
.14126 .655 m
.09287 .655 L
s
.25871 .32869 m
.21956 .35713 L
s
.25871 .32869 m
.21956 .30024 L
s
.25871 .32869 m
.27367 .28266 L
s
.25871 .32869 m
.27367 .28266 L
s
.25871 .32869 m
.21956 .35713 L
s
.25871 .32869 m
.21956 .30024 L
s
.25871 .32869 m
.27367 .28266 L
s
.25871 .32869 m
.27367 .28266 L
s
.25871 .68345 m
.21956 .71189 L
s
.25871 .74034 m
.21956 .71189 L
s
.25871 .74034 m
.27367 .78636 L
s
.25871 .74034 m
.27367 .78636 L
s
.25871 .68345 m
.21956 .71189 L
s
.25871 .74034 m
.21956 .71189 L
s
.25871 .74034 m
.27367 .78636 L
s
.25871 .74034 m
.27367 .78636 L
s
.05372 .38558 m
.09287 .35713 L
s
.21956 .35713 m
.18041 .32869 L
s
.21956 .35713 m
.18041 .32869 L
s
.21956 .30024 m
.18041 .32869 L
s
.21956 .30024 m
.18041 .32869 L
s
.21956 .30024 m
.23452 .25422 L
s
.21956 .71189 m
.18041 .68345 L
s
.21956 .71189 m
.18041 .68345 L
s
.21956 .71189 m
.23452 .75792 L
s
.13202 .68345 m
.18041 .68345 L
s
.13202 .68345 m
.18041 .68345 L
s
.13202 .68345 m
.09287 .655 L
s
.13202 .68345 m
.11706 .72947 L
s
.13202 .68345 m
.14697 .72947 L
s
.13202 .68345 m
.09287 .655 L
s
.13202 .68345 m
.09287 .655 L
s
.18041 .32869 m
.14126 .35713 L
s
.18041 .32869 m
.19537 .28266 L
s
.18041 .32869 m
.19537 .28266 L
s
.18041 .32869 m
.14126 .35713 L
s
.18041 .32869 m
.19537 .28266 L
s
.18041 .32869 m
.19537 .28266 L
s
.18041 .68345 m
.14126 .655 L
s
.18041 .68345 m
.19537 .72947 L
s
.18041 .68345 m
.19537 .72947 L
s
.18041 .68345 m
.13202 .68345 L
s
.18041 .68345 m
.14126 .655 L
s
.18041 .68345 m
.19537 .72947 L
s
.18041 .68345 m
.19537 .72947 L
s
.18041 .68345 m
.13202 .68345 L
s
.09287 .655 m
.14126 .655 L
s
.09287 .655 m
.07791 .70103 L
s
.09287 .655 m
.07791 .70103 L
s
.09287 .655 m
.04448 .655 L
s
.09287 .655 m
.13202 .68345 L
s
.14126 .35713 m
.15621 .31111 L
s
.14126 .35713 m
.15621 .31111 L
s
.14126 .35713 m
.09287 .35713 L
s
.14126 .655 m
.09287 .655 L
s
.14126 .655 m
.09287 .655 L
s
.05372 .38558 m
.09287 .35713 L
s
.07791 .31111 m
.09287 .35713 L
s
.07791 .31111 m
.09287 .26508 L
s
.07791 .31111 m
.09287 .26508 L
s
.07791 .70103 m
.11706 .72947 L
s
.07791 .70103 m
.09287 .655 L
s
.07791 .70103 m
.09287 .74705 L
s
.07791 .70103 m
.09287 .655 L
s
.07791 .70103 m
.09287 .74705 L
s
.34272 .90685 m
.38187 .87841 L
s
.34272 .90685 m
.38187 .87841 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.30357 .13373 m
.34272 .10528 L
s
.30357 .13373 m
.28862 .0877 L
s
.30357 .13373 m
.34272 .10528 L
s
.30357 .13373 m
.28862 .0877 L
s
.11706 .72947 m
.07791 .70103 L
s
.11706 .72947 m
.13202 .68345 L
s
.11706 .72947 m
.13202 .7755 L
s
.11706 .72947 m
.13202 .7755 L
s
.07791 .70103 m
.09287 .655 L
s
.07791 .70103 m
.09287 .74705 L
s
.07791 .70103 m
.09287 .655 L
s
.07791 .70103 m
.09287 .74705 L
s
.28862 .92443 m
.32777 .95288 L
s
.28862 .92443 m
.32777 .95288 L
s
.24947 .11615 m
.28862 .0877 L
s
.24947 .11615 m
.28862 .0877 L
s
.6445 .368 m
.6929 .368 L
s
.6445 .368 m
.60535 .33955 L
s
.6445 .64414 m
.6929 .64414 L
s
.6445 .64414 m
.60535 .67258 L
s
.6929 .368 m
.74129 .368 L
s
.6929 .46004 m
.74129 .46004 L
s
.6929 .55209 m
.74129 .55209 L
s
.6929 .64414 m
.74129 .64414 L
s
.6929 .64414 m
.65375 .67258 L
s
.74129 .368 m
.78968 .368 L
s
.74129 .46004 m
.78968 .46004 L
s
.74129 .55209 m
.78968 .55209 L
s
.74129 .64414 m
.78968 .64414 L
s
.78968 .368 m
.83807 .368 L
s
.78968 .46004 m
.83807 .46004 L
s
.78968 .55209 m
.83807 .55209 L
s
.78968 .64414 m
.83807 .64414 L
s
.83807 .64414 m
.85303 .69016 L
s
.39112 .31111 m
.35197 .28266 L
s
.39112 .31111 m
.35197 .28266 L
s
.39112 .31111 m
.43027 .28266 L
s
.39112 .31111 m
.35197 .28266 L
s
.39112 .25422 m
.35197 .28266 L
s
.39112 .25422 m
.35197 .22577 L
s
.39112 .25422 m
.35197 .28266 L
s
.39112 .25422 m
.43027 .28266 L
s
.39112 .25422 m
.35197 .22577 L
s
.39112 .25422 m
.35197 .28266 L
s
.39112 .75792 m
.35197 .78636 L
s
.39112 .75792 m
.43027 .72947 L
s
.39112 .75792 m
.35197 .78636 L
s
.55696 .33955 m
.60535 .33955 L
s
.55696 .33955 m
.51781 .31111 L
s
.55696 .67258 m
.60535 .67258 L
s
.55696 .67258 m
.51781 .70103 L
s
.60535 .67258 m
.65375 .67258 L
s
.60535 .67258 m
.5662 .70103 L
s
.35197 .28266 m
.31282 .25422 L
s
.35197 .28266 m
.31282 .25422 L
s
.35197 .22577 m
.31282 .25422 L
s
.35197 .22577 m
.31282 .25422 L
s
.35197 .28266 m
.31282 .25422 L
s
.35197 .28266 m
.31282 .25422 L
s
.35197 .78636 m
.31282 .81481 L
s
.35197 .78636 m
.31282 .75792 L
s
.46942 .31111 m
.51781 .31111 L
s
.46942 .31111 m
.43027 .28266 L
s
.46942 .70103 m
.51781 .70103 L
s
.46942 .70103 m
.43027 .72947 L
s
.51781 .70103 m
.5662 .70103 L
s
.51781 .70103 m
.47866 .72947 L
s
.31282 .25422 m
.35197 .22577 L
s
.31282 .25422 m
.35197 .28266 L
s
.31282 .25422 m
.27367 .22577 L
s
.31282 .25422 m
.27367 .28266 L
s
.31282 .25422 m
.27367 .22577 L
s
.31282 .25422 m
.27367 .28266 L
s
.97619 .46004 m
.96124 .50607 L
s
.97619 .46004 m
.96124 .41402 L
s
.97619 .46004 m
.96124 .41402 L
s
.97619 .46004 m
.96124 .50607 L
s
.43027 .72947 m
.47866 .72947 L
s
.35197 .22577 m
.31282 .25422 L
s
.35197 .28266 m
.31282 .25422 L
s
.35197 .78636 m
.31282 .81481 L
s
.35197 .78636 m
.31282 .75792 L
s
.31282 .25422 m
.27367 .22577 L
s
.31282 .25422 m
.27367 .28266 L
s
.31282 .25422 m
.27367 .22577 L
s
.31282 .25422 m
.27367 .28266 L
s
.31282 .81481 m
.27367 .78636 L
s
.31282 .81481 m
.27367 .78636 L
s
.31282 .75792 m
.27367 .78636 L
s
.31282 .75792 m
.27367 .78636 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.15621 .31111 L
s
.10782 .31111 m
.09287 .35713 L
s
.10782 .31111 m
.09287 .26508 L
s
.10782 .31111 m
.09287 .26508 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.19537 .28266 L
s
.15621 .31111 m
.14126 .26508 L
s
.15621 .31111 m
.14126 .26508 L
s
.27367 .22577 m
.23452 .25422 L
s
.27367 .28266 m
.23452 .25422 L
s
.27367 .22577 m
.23452 .25422 L
s
.27367 .28266 m
.23452 .25422 L
s
.27367 .78636 m
.23452 .75792 L
s
.27367 .78636 m
.23452 .75792 L
s
.23452 .25422 m
.19537 .28266 L
s
.23452 .25422 m
.19537 .28266 L
s
.23452 .25422 m
.21956 .20819 L
s
.23452 .25422 m
.24947 .20819 L
s
.23452 .75792 m
.19537 .72947 L
s
.23452 .75792 m
.19537 .72947 L
s
.23452 .75792 m
.21956 .80394 L
s
.23452 .75792 m
.24947 .80394 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.19537 .72947 L
s
.14697 .72947 m
.13202 .68345 L
s
.14697 .72947 m
.13202 .7755 L
s
.14697 .72947 m
.13202 .7755 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .28266 m
.15621 .31111 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .28266 m
.18041 .23664 L
s
.19537 .72947 m
.18041 .7755 L
s
.19537 .72947 m
.18041 .7755 L
s
.19537 .72947 m
.18041 .7755 L
s
.19537 .72947 m
.18041 .7755 L
s
.15621 .31111 m
.14126 .26508 L
s
.15621 .31111 m
.14126 .26508 L
s
.04448 .655 m
.09287 .655 L
s
.04448 .655 m
.09287 .655 L
s
.09287 .35713 m
.05372 .38558 L
s
.09287 .35713 m
.05372 .38558 L
s
.09287 .655 m
.13202 .68345 L
s
.09287 .26508 m
.14126 .26508 L
s
.09287 .26508 m
.13202 .23664 L
s
.09287 .26508 m
.14126 .26508 L
s
.09287 .74705 m
.13202 .7755 L
s
.09287 .74705 m
.13202 .7755 L
s
.14126 .26508 m
.18041 .23664 L
s
.14126 .26508 m
.18041 .23664 L
s
.14126 .26508 m
.09287 .26508 L
s
.17117 .80394 m
.21956 .80394 L
s
.17117 .80394 m
.13202 .7755 L
s
.17117 .80394 m
.13202 .7755 L
s
.21956 .20819 m
.18041 .23664 L
s
.21956 .20819 m
.18041 .23664 L
s
.21956 .80394 m
.18041 .7755 L
s
.21956 .80394 m
.18041 .7755 L
s
.13202 .68345 m
.09287 .655 L
s
.13202 .23664 m
.18041 .23664 L
s
.13202 .23664 m
.18041 .23664 L
s
.13202 .23664 m
.09287 .26508 L
s
.13202 .23664 m
.14697 .19061 L
s
.13202 .7755 m
.18041 .7755 L
s
.13202 .7755 m
.18041 .7755 L
s
.13202 .7755 m
.09287 .74705 L
s
.13202 .7755 m
.14697 .82152 L
s
.13202 .7755 m
.18041 .7755 L
s
.13202 .7755 m
.18041 .7755 L
s
.13202 .7755 m
.09287 .74705 L
s
.13202 .7755 m
.14697 .82152 L
s
.18041 .23664 m
.14126 .26508 L
s
.18041 .23664 m
.14126 .26508 L
s
.09287 .26508 m
.14126 .26508 L
s
.7228 .27595 m
.7712 .27595 L
s
.7228 .27595 m
.68365 .2475 L
s
.7228 .27595 m
.73776 .22992 L
s
.7712 .27595 m
.81959 .27595 L
s
.7712 .27595 m
.78615 .22992 L
s
.7712 .73619 m
.81959 .73619 L
s
.7712 .73619 m
.73205 .76463 L
s
.7712 .73619 m
.78615 .78221 L
s
.81959 .27595 m
.86798 .27595 L
s
.81959 .27595 m
.83454 .22992 L
s
.81959 .27595 m
.86798 .27595 L
s
.81959 .27595 m
.83454 .22992 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.83454 .78221 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.86798 .73619 L
s
.81959 .73619 m
.83454 .78221 L
s
.86798 .27595 m
.88294 .22992 L
s
.86798 .27595 m
.88294 .32197 L
s
.86798 .27595 m
.90713 .2475 L
s
.86798 .27595 m
.88294 .22992 L
s
.86798 .27595 m
.88294 .32197 L
s
.86798 .27595 m
.90713 .2475 L
s
.86798 .368 m
.90713 .33955 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .46004 m
.88294 .41402 L
s
.86798 .46004 m
.90713 .4316 L
s
.86798 .46004 m
.90713 .48849 L
s
.86798 .46004 m
.88294 .50607 L
s
.86798 .46004 m
.88294 .41402 L
s
.86798 .46004 m
.90713 .4316 L
s
.86798 .46004 m
.90713 .48849 L
s
.86798 .55209 m
.88294 .59812 L
s
.86798 .55209 m
.90713 .58054 L
s
.86798 .55209 m
.88294 .50607 L
s
.86798 .55209 m
.88294 .59812 L
s
.86798 .64414 m
.85303 .69016 L
s
.86798 .64414 m
.90713 .67258 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.90713 .67258 L
s
.86798 .73619 m
.88294 .78221 L
s
.86798 .73619 m
.85303 .69016 L
s
.86798 .73619 m
.90713 .76463 L
s
.86798 .73619 m
.90713 .76463 L
s
.86798 .73619 m
.88294 .78221 L
s
.86798 .73619 m
.90713 .76463 L
s
.42103 .16217 m
.38187 .13373 L
s
.42103 .16217 m
.46018 .19061 L
s
.42103 .16217 m
.38187 .13373 L
s
.42103 .16217 m
.43598 .11615 L
s
.42103 .16217 m
.43598 .11615 L
s
.42103 .84997 m
.46942 .84997 L
s
.42103 .84997 m
.38187 .87841 L
s
.42103 .84997 m
.38187 .87841 L
s
.42103 .84997 m
.43598 .89599 L
s
.46942 .84997 m
.50857 .82152 L
s
.46942 .84997 m
.48437 .89599 L
s
.46942 .84997 m
.48437 .89599 L
s
.63526 .2475 m
.68365 .2475 L
s
.63526 .2475 m
.59611 .21906 L
s
.63526 .2475 m
.65022 .20148 L
s
.68365 .2475 m
.69861 .20148 L
s
.68365 .76463 m
.73205 .76463 L
s
.68365 .76463 m
.6445 .79308 L
s
.68365 .76463 m
.69861 .81066 L
s
.73205 .76463 m
.747 .81066 L
s
.73205 .76463 m
.747 .81066 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.54772 .21906 m
.59611 .21906 L
s
.54772 .21906 m
.50857 .19061 L
s
.54772 .21906 m
.56267 .17304 L
s
.59611 .21906 m
.61106 .17304 L
s
.59611 .79308 m
.6445 .79308 L
s
.59611 .79308 m
.55696 .82152 L
s
.59611 .79308 m
.61106 .8391 L
s
.6445 .79308 m
.65946 .8391 L
s
.46018 .19061 m
.50857 .19061 L
s
.46018 .19061 m
.47513 .14459 L
s
.50857 .19061 m
.52352 .14459 L
s
.50857 .82152 m
.55696 .82152 L
s
.50857 .82152 m
.52352 .86755 L
s
.55696 .82152 m
.57191 .86755 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.34272 .10528 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .13373 m
.39683 .0877 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.39683 .92443 L
s
.38187 .87841 m
.34272 .90685 L
s
.38187 .87841 m
.39683 .92443 L
s
.34272 .10528 m
.32777 .05926 L
s
.34272 .10528 m
.35768 .05926 L
s
.34272 .10528 m
.30357 .13373 L
s
.34272 .10528 m
.32777 .05926 L
s
.34272 .10528 m
.35768 .05926 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.32777 .05926 m
.28862 .0877 L
s
.32777 .05926 m
.34272 .10528 L
s
.32777 .05926 m
.28862 .0877 L
s
.32777 .95288 m
.34272 .90685 L
s
.32777 .95288 m
.28862 .92443 L
s
.28862 .0877 m
.30357 .13373 L
s
.28862 .0877 m
.32777 .05926 L
s
.28862 .0877 m
.24947 .11615 L
s
.73776 .22992 m
.78615 .22992 L
s
.73776 .22992 m
.69861 .20148 L
s
.78615 .22992 m
.83454 .22992 L
s
.78615 .22992 m
.747 .20148 L
s
.78615 .22992 m
.83454 .22992 L
s
.78615 .22992 m
.747 .20148 L
s
.78615 .78221 m
.83454 .78221 L
s
.78615 .78221 m
.747 .81066 L
s
.78615 .78221 m
.83454 .78221 L
s
.78615 .78221 m
.747 .81066 L
s
.83454 .22992 m
.88294 .22992 L
s
.83454 .22992 m
.79539 .20148 L
s
.83454 .22992 m
.87369 .20148 L
s
.83454 .22992 m
.88294 .22992 L
s
.83454 .22992 m
.79539 .20148 L
s
.83454 .22992 m
.87369 .20148 L
s
.83454 .78221 m
.88294 .78221 L
s
.83454 .78221 m
.79539 .81066 L
s
.83454 .78221 m
.87369 .81066 L
s
.83454 .78221 m
.88294 .78221 L
s
.83454 .78221 m
.79539 .81066 L
s
.83454 .78221 m
.87369 .81066 L
s
.88294 .22992 m
.86798 .27595 L
s
.88294 .22992 m
.83454 .22992 L
s
.88294 .78221 m
.86798 .73619 L
s
.88294 .78221 m
.86798 .73619 L
s
.88294 .78221 m
.83454 .78221 L
s
.43598 .11615 m
.48437 .11615 L
s
.43598 .11615 m
.39683 .0877 L
s
.43598 .11615 m
.47513 .14459 L
s
.43598 .11615 m
.39683 .0877 L
s
.43598 .11615 m
.42103 .07012 L
s
.43598 .11615 m
.48437 .11615 L
s
.43598 .11615 m
.39683 .0877 L
s
.43598 .11615 m
.39683 .0877 L
s
.43598 .89599 m
.48437 .89599 L
s
.43598 .89599 m
.39683 .92443 L
s
.43598 .89599 m
.39683 .92443 L
s
.43598 .89599 m
.48437 .89599 L
s
.43598 .89599 m
.39683 .92443 L
s
.48437 .11615 m
.53276 .11615 L
s
.48437 .11615 m
.52352 .14459 L
s
.48437 .11615 m
.46942 .07012 L
s
.48437 .11615 m
.43598 .11615 L
s
.48437 .11615 m
.53276 .11615 L
s
.48437 .11615 m
.46942 .07012 L
s
.48437 .89599 m
.53276 .89599 L
s
.48437 .89599 m
.44522 .92443 L
s
.48437 .89599 m
.52352 .86755 L
s
.48437 .89599 m
.46942 .94201 L
s
.48437 .89599 m
.53276 .89599 L
s
.48437 .89599 m
.44522 .92443 L
s
.48437 .89599 m
.44522 .92443 L
s
.53276 .11615 m
.57191 .14459 L
s
.53276 .11615 m
.51781 .07012 L
s
.53276 .11615 m
.48437 .11615 L
s
.53276 .11615 m
.57191 .14459 L
s
.53276 .11615 m
.51781 .07012 L
s
.53276 .89599 m
.58116 .89599 L
s
.53276 .89599 m
.57191 .86755 L
s
.53276 .89599 m
.51781 .94201 L
s
.53276 .89599 m
.48437 .89599 L
s
.53276 .89599 m
.58116 .89599 L
s
.53276 .89599 m
.51781 .94201 L
s
.53276 .89599 m
.51781 .94201 L
s
.53276 .89599 m
.51781 .94201 L
s
.58116 .89599 m
.62031 .86755 L
s
.58116 .89599 m
.5662 .94201 L
s
.58116 .89599 m
.53276 .89599 L
s
.58116 .89599 m
.62031 .86755 L
s
.58116 .89599 m
.62031 .86755 L
s
.58116 .89599 m
.5662 .94201 L
s
.58116 .89599 m
.5662 .94201 L
s
.58116 .89599 m
.62031 .86755 L
s
.65022 .20148 m
.69861 .20148 L
s
.65022 .20148 m
.61106 .17304 L
s
.69861 .20148 m
.747 .20148 L
s
.69861 .20148 m
.65946 .17304 L
s
.69861 .20148 m
.65946 .17304 L
s
.69861 .20148 m
.747 .20148 L
s
.69861 .81066 m
.747 .81066 L
s
.69861 .81066 m
.65946 .8391 L
s
.69861 .81066 m
.747 .81066 L
s
.747 .20148 m
.79539 .20148 L
s
.747 .20148 m
.70785 .17304 L
s
.747 .20148 m
.70785 .17304 L
s
.747 .20148 m
.78615 .17304 L
s
.747 .20148 m
.79539 .20148 L
s
.747 .20148 m
.70785 .17304 L
s
.747 .20148 m
.70785 .17304 L
s
.747 .81066 m
.79539 .81066 L
s
.747 .81066 m
.70785 .8391 L
s
.747 .81066 m
.78615 .8391 L
s
.747 .81066 m
.79539 .81066 L
s
.747 .81066 m
.70785 .8391 L
s
.79539 .20148 m
.83454 .22992 L
s
.79539 .20148 m
.83454 .17304 L
s
.79539 .20148 m
.747 .20148 L
s
.79539 .20148 m
.83454 .17304 L
s
.79539 .81066 m
.83454 .78221 L
s
.79539 .81066 m
.83454 .8391 L
s
.79539 .81066 m
.747 .81066 L
s
.79539 .81066 m
.83454 .8391 L
s
.39683 .0877 m
.35768 .05926 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .0877 m
.43598 .11615 L
s
.39683 .0877 m
.35768 .05926 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .92443 m
.44522 .92443 L
s
.39683 .92443 m
.35768 .95288 L
s
.39683 .92443 m
.38187 .97046 L
s
.39683 .92443 m
.44522 .92443 L
s
.39683 .92443 m
.44522 .92443 L
s
.39683 .92443 m
.35768 .95288 L
s
.44522 .92443 m
.39683 .92443 L
s
.44522 .92443 m
.43027 .97046 L
s
.44522 .92443 m
.43027 .97046 L
s
.44522 .92443 m
.48437 .89599 L
s
.44522 .92443 m
.39683 .92443 L
s
.44522 .92443 m
.43027 .97046 L
s
.56267 .17304 m
.61106 .17304 L
s
.56267 .17304 m
.52352 .14459 L
s
.61106 .17304 m
.65946 .17304 L
s
.61106 .17304 m
.57191 .14459 L
s
.61106 .17304 m
.65946 .17304 L
s
.61106 .17304 m
.57191 .14459 L
s
.61106 .8391 m
.65946 .8391 L
s
.61106 .8391 m
.57191 .86755 L
s
.65946 .17304 m
.70785 .17304 L
s
.65946 .17304 m
.62031 .14459 L
s
.65946 .17304 m
.6445 .12701 L
s
.65946 .17304 m
.70785 .17304 L
s
.65946 .17304 m
.62031 .14459 L
s
.65946 .17304 m
.70785 .17304 L
s
.65946 .17304 m
.70785 .17304 L
s
.65946 .8391 m
.70785 .8391 L
s
.65946 .8391 m
.62031 .86755 L
s
.65946 .8391 m
.62031 .86755 L
s
.65946 .8391 m
.62031 .86755 L
s
.65946 .8391 m
.70785 .8391 L
s
.65946 .8391 m
.62031 .86755 L
s
.70785 .17304 m
.6929 .12701 L
s
.70785 .17304 m
.65946 .17304 L
s
.70785 .17304 m
.747 .14459 L
s
.70785 .17304 m
.747 .20148 L
s
.70785 .17304 m
.6929 .12701 L
s
.70785 .17304 m
.747 .14459 L
s
.70785 .8391 m
.6687 .86755 L
s
.70785 .8391 m
.6687 .86755 L
s
.70785 .8391 m
.6687 .86755 L
s
.70785 .8391 m
.747 .81066 L
s
.70785 .8391 m
.747 .86755 L
s
.70785 .8391 m
.747 .86755 L
s
.47513 .14459 m
.52352 .14459 L
s
.47513 .14459 m
.43598 .11615 L
s
.52352 .14459 m
.57191 .14459 L
s
.52352 .14459 m
.48437 .11615 L
s
.52352 .14459 m
.57191 .14459 L
s
.52352 .86755 m
.57191 .86755 L
s
.52352 .86755 m
.48437 .89599 L
s
.57191 .14459 m
.62031 .14459 L
s
.57191 .14459 m
.55696 .09857 L
s
.57191 .14459 m
.53276 .11615 L
s
.57191 .14459 m
.62031 .14459 L
s
.57191 .86755 m
.62031 .86755 L
s
.57191 .86755 m
.53276 .89599 L
s
.57191 .86755 m
.62031 .86755 L
s
.57191 .86755 m
.62031 .86755 L
s
.57191 .86755 m
.62031 .86755 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .14459 m
.65946 .17304 L
s
.62031 .14459 m
.57191 .14459 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.60535 .91357 L
s
.62031 .86755 m
.58116 .89599 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.65946 .89599 L
s
.62031 .86755 m
.60535 .91357 L
s
.62031 .86755 m
.65946 .89599 L
s
.6687 .86755 m
.62031 .86755 L
s
.6687 .86755 m
.62031 .86755 L
s
.6687 .86755 m
.70785 .8391 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.62031 .86755 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .89599 L
s
.39683 .0877 m
.35768 .05926 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .0877 m
.43598 .11615 L
s
.39683 .0877 m
.35768 .05926 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .92443 m
.35768 .95288 L
s
.39683 .92443 m
.38187 .97046 L
s
.39683 .92443 m
.44522 .92443 L
s
.39683 .92443 m
.44522 .92443 L
s
.39683 .92443 m
.35768 .95288 L
s
.35768 .05926 m
.34272 .10528 L
s
.35768 .05926 m
.39683 .0877 L
s
.35768 .05926 m
.39683 .0877 L
s
.35768 .95288 m
.34272 .90685 L
s
.35768 .95288 m
.39683 .92443 L
s
.42103 .07012 m
.46942 .07012 L
s
.42103 .07012 m
.38187 .04168 L
s
.42103 .07012 m
.38187 .04168 L
s
.42103 .07012 m
.43598 .11615 L
s
.42103 .07012 m
.46942 .07012 L
s
.42103 .07012 m
.38187 .04168 L
s
.46942 .07012 m
.51781 .07012 L
s
.46942 .07012 m
.43027 .04168 L
s
.46942 .07012 m
.48437 .11615 L
s
.46942 .07012 m
.51781 .07012 L
s
.46942 .07012 m
.43027 .04168 L
s
.46942 .07012 m
.43027 .04168 L
s
.46942 .94201 m
.51781 .94201 L
s
.46942 .94201 m
.43027 .97046 L
s
.46942 .94201 m
.43027 .97046 L
s
.46942 .94201 m
.48437 .89599 L
s
.46942 .94201 m
.51781 .94201 L
s
.46942 .94201 m
.43027 .97046 L
s
.46942 .94201 m
.51781 .94201 L
s
.46942 .94201 m
.51781 .94201 L
s
.51781 .07012 m
.5662 .07012 L
s
.51781 .07012 m
.55696 .09857 L
s
.51781 .07012 m
.50286 .0241 L
s
.51781 .07012 m
.53276 .11615 L
s
.51781 .07012 m
.46942 .07012 L
s
.51781 .07012 m
.5662 .07012 L
s
.51781 .07012 m
.50286 .0241 L
s
.51781 .07012 m
.50286 .0241 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.47866 .97046 L
s
.51781 .94201 m
.50286 .98804 L
s
.51781 .94201 m
.53276 .89599 L
s
.51781 .94201 m
.47866 .97046 L
s
.51781 .94201 m
.47866 .97046 L
s
.51781 .94201 m
.55696 .97046 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.50286 .98804 L
s
.51781 .94201 m
.55696 .97046 L
s
.5662 .07012 m
.60535 .09857 L
s
.5662 .07012 m
.51781 .07012 L
s
.5662 .07012 m
.60535 .09857 L
s
.5662 .07012 m
.60535 .09857 L
s
.5662 .07012 m
.60535 .09857 L
s
.5662 .94201 m
.60535 .91357 L
s
.5662 .94201 m
.58116 .89599 L
s
.5662 .94201 m
.51781 .94201 L
s
.5662 .94201 m
.60535 .91357 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.51781 .94201 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.51781 .94201 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.60535 .97046 L
s
.38187 .04168 m
.43027 .04168 L
s
.38187 .04168 m
.39683 .0877 L
s
.38187 .04168 m
.39683 .0877 L
s
.38187 .04168 m
.43027 .04168 L
s
.38187 .04168 m
.43027 .04168 L
s
.43027 .04168 m
.38187 .04168 L
s
.43027 .04168 m
.46942 .07012 L
s
.43027 .04168 m
.38187 .04168 L
s
.43027 .97046 m
.47866 .97046 L
s
.43027 .97046 m
.38187 .97046 L
s
.43027 .97046 m
.44522 .92443 L
s
.43027 .97046 m
.44522 .92443 L
s
.43027 .97046 m
.47866 .97046 L
s
.43027 .97046 m
.47866 .97046 L
s
.47866 .97046 m
.43027 .97046 L
s
.47866 .97046 m
.51781 .94201 L
s
.47866 .97046 m
.43027 .97046 L
s
.47866 .97046 m
.51781 .94201 L
s
.47866 .97046 m
.51781 .94201 L
s
.6445 .12701 m
.6929 .12701 L
s
.6445 .12701 m
.60535 .09857 L
s
.6445 .12701 m
.65946 .17304 L
s
.6445 .12701 m
.60535 .09857 L
s
.6445 .12701 m
.60535 .09857 L
s
.6445 .12701 m
.6929 .12701 L
s
.6445 .12701 m
.60535 .09857 L
s
.6929 .12701 m
.65375 .09857 L
s
.6929 .12701 m
.70785 .17304 L
s
.6929 .12701 m
.70785 .17304 L
s
.6929 .12701 m
.65375 .09857 L
s
.6929 .12701 m
.65375 .09857 L
s
.6929 .12701 m
.73205 .09857 L
s
.6929 .12701 m
.70785 .17304 L
s
.6929 .12701 m
.73205 .09857 L
s
.55696 .09857 m
.60535 .09857 L
s
.55696 .09857 m
.57191 .14459 L
s
.55696 .09857 m
.51781 .07012 L
s
.55696 .09857 m
.60535 .09857 L
s
.55696 .09857 m
.60535 .09857 L
s
.55696 .09857 m
.60535 .09857 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.5904 .05254 L
s
.60535 .09857 m
.62031 .14459 L
s
.60535 .09857 m
.5662 .07012 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.6445 .07012 L
s
.60535 .09857 m
.5904 .05254 L
s
.60535 .09857 m
.6445 .07012 L
s
.60535 .91357 m
.62031 .86755 L
s
.60535 .91357 m
.62031 .86755 L
s
.60535 .91357 m
.5662 .94201 L
s
.60535 .91357 m
.6445 .94201 L
s
.60535 .91357 m
.5662 .94201 L
s
.60535 .91357 m
.62031 .86755 L
s
.65375 .09857 m
.60535 .09857 L
s
.65375 .09857 m
.60535 .09857 L
s
.65375 .09857 m
.6929 .12701 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.60535 .09857 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .07012 L
s
.38187 .04168 m
.39683 .0877 L
s
.38187 .04168 m
.39683 .0877 L
s
.38187 .04168 m
.43027 .04168 L
s
.38187 .04168 m
.43027 .04168 L
s
.38187 .97046 m
.43027 .97046 L
s
.38187 .97046 m
.39683 .92443 L
s
.38187 .97046 m
.43027 .97046 L
s
.43027 .97046 m
.44522 .92443 L
s
.43027 .97046 m
.44522 .92443 L
s
.43027 .97046 m
.47866 .97046 L
s
.43027 .97046 m
.47866 .97046 L
s
.34272 .10528 m
.30357 .13373 L
s
.34272 .10528 m
.32777 .05926 L
s
.34272 .10528 m
.35768 .05926 L
s
.34272 .90685 m
.32777 .95288 L
s
.34272 .90685 m
.35768 .95288 L
s
.30357 .13373 m
.28862 .0877 L
s
.50286 .0241 m
.51781 .07012 L
s
.50286 .98804 m
.51781 .94201 L
s
.50286 .98804 m
.51781 .94201 L
s
.50286 .98804 m
.51781 .94201 L
s
.5904 .05254 m
.60535 .09857 L
s
.5904 .05254 m
.60535 .09857 L
s
.5904 .05254 m
.60535 .09857 L
s
.32777 .05926 m
.28862 .0877 L
s
.32777 .95288 m
.28862 .92443 L
s
.28862 .0877 m
.24947 .11615 L
s
.43598 .11615 m
.48437 .11615 L
s
.43598 .11615 m
.39683 .0877 L
s
.43598 .11615 m
.39683 .0877 L
s
.48437 .11615 m
.53276 .11615 L
s
.48437 .11615 m
.46942 .07012 L
s
.48437 .89599 m
.53276 .89599 L
s
.48437 .89599 m
.44522 .92443 L
s
.48437 .89599 m
.44522 .92443 L
s
.53276 .11615 m
.57191 .14459 L
s
.53276 .11615 m
.51781 .07012 L
s
.53276 .89599 m
.58116 .89599 L
s
.53276 .89599 m
.51781 .94201 L
s
.53276 .89599 m
.51781 .94201 L
s
.53276 .89599 m
.51781 .94201 L
s
.58116 .89599 m
.62031 .86755 L
s
.58116 .89599 m
.62031 .86755 L
s
.58116 .89599 m
.5662 .94201 L
s
.58116 .89599 m
.5662 .94201 L
s
.58116 .89599 m
.62031 .86755 L
s
.39683 .0877 m
.35768 .05926 L
s
.39683 .0877 m
.38187 .04168 L
s
.44522 .92443 m
.39683 .92443 L
s
.44522 .92443 m
.43027 .97046 L
s
.65946 .17304 m
.70785 .17304 L
s
.65946 .17304 m
.62031 .14459 L
s
.65946 .17304 m
.70785 .17304 L
s
.65946 .17304 m
.70785 .17304 L
s
.70785 .17304 m
.747 .14459 L
s
.70785 .17304 m
.747 .20148 L
s
.70785 .17304 m
.6929 .12701 L
s
.70785 .17304 m
.747 .14459 L
s
.57191 .14459 m
.62031 .14459 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .14459 m
.60535 .09857 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.65946 .89599 L
s
.62031 .86755 m
.60535 .91357 L
s
.62031 .86755 m
.65946 .89599 L
s
.39683 .0877 m
.35768 .05926 L
s
.39683 .0877 m
.38187 .04168 L
s
.39683 .92443 m
.44522 .92443 L
s
.39683 .92443 m
.35768 .95288 L
s
.44522 .92443 m
.43027 .97046 L
s
.46942 .07012 m
.51781 .07012 L
s
.46942 .07012 m
.43027 .04168 L
s
.46942 .07012 m
.43027 .04168 L
s
.51781 .07012 m
.5662 .07012 L
s
.51781 .07012 m
.50286 .0241 L
s
.51781 .07012 m
.50286 .0241 L
s
.51781 .94201 m
.47866 .97046 L
s
.51781 .94201 m
.47866 .97046 L
s
.51781 .94201 m
.55696 .97046 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.50286 .98804 L
s
.51781 .94201 m
.55696 .97046 L
s
.5662 .07012 m
.60535 .09857 L
s
.5662 .07012 m
.60535 .09857 L
s
.5662 .07012 m
.60535 .09857 L
s
.43027 .04168 m
.38187 .04168 L
s
.47866 .97046 m
.43027 .97046 L
s
.47866 .97046 m
.51781 .94201 L
s
.47866 .97046 m
.51781 .94201 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.6445 .07012 L
s
.60535 .09857 m
.5904 .05254 L
s
.60535 .09857 m
.6445 .07012 L
s
.38187 .04168 m
.43027 .04168 L
s
.43027 .97046 m
.47866 .97046 L
s
.47866 .97046 m
.51781 .94201 L
s
.47866 .97046 m
.51781 .94201 L
s
.89218 .71861 m
.85303 .69016 L
s
.89218 .71861 m
.90713 .67258 L
s
.89218 .71861 m
.90713 .76463 L
s
.89218 .71861 m
.90713 .76463 L
s
.89218 .71861 m
.90713 .67258 L
s
.89218 .71861 m
.90713 .76463 L
s
.85303 .69016 m
.86798 .64414 L
s
.85303 .69016 m
.86798 .73619 L
s
.85303 .69016 m
.86798 .73619 L
s
.90713 .33955 m
.86798 .368 L
s
.90713 .33955 m
.92209 .29353 L
s
.90713 .33955 m
.92209 .38558 L
s
.90713 .33955 m
.92209 .38558 L
s
.90713 .33955 m
.92209 .29353 L
s
.90713 .33955 m
.92209 .38558 L
s
.90713 .33955 m
.92209 .38558 L
s
.90713 .33955 m
.92209 .29353 L
s
.90713 .33955 m
.92209 .38558 L
s
.90713 .67258 m
.86798 .64414 L
s
.90713 .67258 m
.92209 .71861 L
s
.90713 .67258 m
.92209 .62656 L
s
.90713 .67258 m
.92209 .62656 L
s
.90713 .67258 m
.92209 .71861 L
s
.90713 .67258 m
.92209 .62656 L
s
.90713 .67258 m
.92209 .71861 L
s
.90713 .76463 m
.86798 .73619 L
s
.90713 .76463 m
.92209 .71861 L
s
.90713 .76463 m
.86798 .73619 L
s
.90713 .76463 m
.92209 .71861 L
s
.90713 .76463 m
.92209 .71861 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .41402 L
s
.86798 .368 m
.88294 .32197 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.88294 .59812 L
s
.86798 .64414 m
.90713 .67258 L
s
.86798 .73619 m
.90713 .76463 L
s
.86798 .73619 m
.88294 .78221 L
s
.86798 .73619 m
.90713 .76463 L
s
.92209 .29353 m
.88294 .32197 L
s
.92209 .29353 m
.93704 .33955 L
s
.92209 .29353 m
.90713 .2475 L
s
.92209 .29353 m
.88294 .32197 L
s
.92209 .29353 m
.93704 .33955 L
s
.92209 .29353 m
.90713 .2475 L
s
.92209 .29353 m
.93704 .33955 L
s
.92209 .38558 m
.88294 .41402 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.90713 .4316 L
s
.92209 .38558 m
.88294 .41402 L
s
.92209 .38558 m
.96124 .35713 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.90713 .4316 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.96124 .35713 L
s
.92209 .71861 m
.90713 .76463 L
s
.92209 .71861 m
.90713 .67258 L
s
.92209 .71861 m
.90713 .76463 L
s
.92209 .62656 m
.88294 .59812 L
s
.92209 .62656 m
.90713 .58054 L
s
.92209 .62656 m
.88294 .59812 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.90713 .67258 L
s
.92209 .62656 m
.96124 .655 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.96124 .655 L
s
.88294 .32197 m
.86798 .27595 L
s
.88294 .32197 m
.92209 .29353 L
s
.88294 .32197 m
.92209 .29353 L
s
.88294 .41402 m
.86798 .46004 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.86798 .46004 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .59812 m
.86798 .55209 L
s
.88294 .59812 m
.92209 .62656 L
s
.88294 .59812 m
.92209 .62656 L
s
.93704 .33955 m
.92209 .38558 L
s
.93704 .33955 m
.92209 .29353 L
s
.93704 .33955 m
.92209 .38558 L
s
.93704 .33955 m
.92209 .38558 L
s
.93704 .33955 m
.92209 .29353 L
s
.93704 .33955 m
.92209 .38558 L
s
.90713 .2475 m
.86798 .27595 L
s
.90713 .2475 m
.92209 .29353 L
s
.90713 .2475 m
.92209 .29353 L
s
.90713 .4316 m
.86798 .46004 L
s
.90713 .4316 m
.92209 .38558 L
s
.90713 .4316 m
.92209 .38558 L
s
.90713 .4316 m
.94628 .46004 L
s
.90713 .4316 m
.86798 .46004 L
s
.90713 .4316 m
.92209 .38558 L
s
.90713 .4316 m
.92209 .38558 L
s
.90713 .48849 m
.86798 .46004 L
s
.90713 .48849 m
.92209 .53451 L
s
.90713 .48849 m
.94628 .46004 L
s
.90713 .48849 m
.86798 .46004 L
s
.90713 .48849 m
.92209 .53451 L
s
.90713 .48849 m
.92209 .53451 L
s
.90713 .58054 m
.86798 .55209 L
s
.90713 .58054 m
.92209 .53451 L
s
.90713 .58054 m
.92209 .62656 L
s
.90713 .58054 m
.92209 .62656 L
s
.90713 .58054 m
.92209 .53451 L
s
.90713 .58054 m
.92209 .53451 L
s
.90713 .76463 m
.86798 .73619 L
s
.90713 .76463 m
.92209 .71861 L
s
.90713 .76463 m
.92209 .71861 L
s
.86798 .27595 m
.88294 .22992 L
s
.86798 .27595 m
.88294 .32197 L
s
.86798 .27595 m
.90713 .2475 L
s
.86798 .46004 m
.88294 .50607 L
s
.86798 .46004 m
.88294 .41402 L
s
.86798 .46004 m
.90713 .4316 L
s
.86798 .46004 m
.90713 .48849 L
s
.86798 .55209 m
.88294 .50607 L
s
.86798 .55209 m
.88294 .59812 L
s
.86798 .73619 m
.88294 .78221 L
s
.86798 .73619 m
.90713 .76463 L
s
.87369 .20148 m
.83454 .22992 L
s
.87369 .20148 m
.83454 .17304 L
s
.87369 .20148 m
.83454 .17304 L
s
.87369 .81066 m
.83454 .78221 L
s
.87369 .81066 m
.83454 .8391 L
s
.87369 .81066 m
.83454 .8391 L
s
.92209 .53451 m
.88294 .50607 L
s
.92209 .53451 m
.93704 .58054 L
s
.92209 .53451 m
.93704 .58054 L
s
.92209 .53451 m
.90713 .48849 L
s
.92209 .53451 m
.96124 .50607 L
s
.92209 .53451 m
.96124 .56296 L
s
.92209 .53451 m
.93704 .58054 L
s
.92209 .53451 m
.96124 .50607 L
s
.92209 .53451 m
.96124 .56296 L
s
.92209 .38558 m
.88294 .41402 L
s
.92209 .38558 m
.96124 .35713 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.90713 .4316 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.96124 .35713 L
s
.92209 .62656 m
.88294 .59812 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.90713 .67258 L
s
.92209 .62656 m
.96124 .655 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.96124 .655 L
s
.92209 .29353 m
.88294 .32197 L
s
.92209 .29353 m
.93704 .33955 L
s
.92209 .29353 m
.90713 .2475 L
s
.92209 .29353 m
.93704 .33955 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.6687 .86755 L
s
.62031 .86755 m
.65946 .89599 L
s
.62031 .86755 m
.60535 .91357 L
s
.62031 .86755 m
.65946 .89599 L
s
.6687 .86755 m
.70785 .8391 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.62031 .86755 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .8391 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.62031 .86755 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .89599 L
s
.6687 .86755 m
.70785 .89599 L
s
.78615 .17304 m
.83454 .17304 L
s
.78615 .17304 m
.747 .14459 L
s
.78615 .17304 m
.747 .20148 L
s
.78615 .17304 m
.747 .14459 L
s
.78615 .17304 m
.83454 .17304 L
s
.78615 .8391 m
.83454 .8391 L
s
.78615 .8391 m
.747 .81066 L
s
.78615 .8391 m
.747 .86755 L
s
.78615 .8391 m
.83454 .8391 L
s
.78615 .8391 m
.747 .86755 L
s
.83454 .22992 m
.88294 .22992 L
s
.83454 .22992 m
.79539 .20148 L
s
.83454 .22992 m
.87369 .20148 L
s
.83454 .78221 m
.88294 .78221 L
s
.83454 .78221 m
.79539 .81066 L
s
.83454 .78221 m
.87369 .81066 L
s
.83454 .17304 m
.79539 .14459 L
s
.83454 .17304 m
.79539 .20148 L
s
.83454 .17304 m
.79539 .14459 L
s
.83454 .17304 m
.87369 .20148 L
s
.83454 .17304 m
.79539 .14459 L
s
.83454 .17304 m
.79539 .14459 L
s
.83454 .8391 m
.79539 .81066 L
s
.83454 .8391 m
.79539 .86755 L
s
.83454 .8391 m
.87369 .81066 L
s
.83454 .8391 m
.79539 .86755 L
s
.83454 .8391 m
.79539 .86755 L
s
.88294 .50607 m
.86798 .46004 L
s
.88294 .50607 m
.92209 .53451 L
s
.88294 .50607 m
.92209 .53451 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.86798 .46004 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .41402 m
.92209 .38558 L
s
.88294 .59812 m
.92209 .62656 L
s
.88294 .32197 m
.92209 .29353 L
s
.747 .14459 m
.79539 .14459 L
s
.747 .14459 m
.70785 .17304 L
s
.747 .14459 m
.73205 .09857 L
s
.747 .14459 m
.79539 .14459 L
s
.747 .14459 m
.70785 .17304 L
s
.747 .14459 m
.79539 .14459 L
s
.747 .14459 m
.73205 .09857 L
s
.747 .14459 m
.79539 .14459 L
s
.747 .20148 m
.79539 .20148 L
s
.747 .20148 m
.70785 .17304 L
s
.747 .20148 m
.70785 .17304 L
s
.747 .81066 m
.79539 .81066 L
s
.747 .81066 m
.70785 .8391 L
s
.747 .86755 m
.79539 .86755 L
s
.747 .86755 m
.70785 .8391 L
s
.747 .86755 m
.70785 .89599 L
s
.747 .86755 m
.70785 .89599 L
s
.747 .86755 m
.70785 .89599 L
s
.747 .86755 m
.78615 .89599 L
s
.747 .86755 m
.79539 .86755 L
s
.747 .86755 m
.79539 .86755 L
s
.747 .86755 m
.70785 .89599 L
s
.79539 .14459 m
.747 .14459 L
s
.79539 .14459 m
.83454 .17304 L
s
.79539 .20148 m
.83454 .17304 L
s
.79539 .81066 m
.83454 .8391 L
s
.79539 .86755 m
.83454 .8391 L
s
.79539 .86755 m
.747 .86755 L
s
.65946 .89599 m
.70785 .89599 L
s
.65946 .89599 m
.6445 .94201 L
s
.65946 .89599 m
.62031 .86755 L
s
.65946 .89599 m
.70785 .89599 L
s
.65946 .89599 m
.70785 .89599 L
s
.65946 .89599 m
.70785 .89599 L
s
.70785 .17304 m
.6929 .12701 L
s
.70785 .17304 m
.747 .14459 L
s
.70785 .8391 m
.747 .86755 L
s
.70785 .89599 m
.6929 .94201 L
s
.70785 .89599 m
.65946 .89599 L
s
.70785 .89599 m
.747 .86755 L
s
.70785 .89599 m
.6929 .94201 L
s
.55696 .97046 m
.60535 .97046 L
s
.55696 .97046 m
.51781 .94201 L
s
.55696 .97046 m
.60535 .97046 L
s
.55696 .97046 m
.51781 .94201 L
s
.55696 .97046 m
.60535 .97046 L
s
.55696 .97046 m
.60535 .97046 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.65375 .09857 L
s
.60535 .09857 m
.6445 .07012 L
s
.60535 .09857 m
.5904 .05254 L
s
.60535 .09857 m
.6445 .07012 L
s
.60535 .91357 m
.5662 .94201 L
s
.60535 .91357 m
.6445 .94201 L
s
.60535 .91357 m
.5662 .94201 L
s
.60535 .91357 m
.62031 .86755 L
s
.60535 .97046 m
.5662 .94201 L
s
.60535 .97046 m
.6445 .94201 L
s
.60535 .97046 m
.5662 .94201 L
s
.60535 .97046 m
.55696 .97046 L
s
.65375 .09857 m
.6929 .12701 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.60535 .09857 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .12701 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.60535 .09857 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .07012 L
s
.65375 .09857 m
.6929 .07012 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.5662 .94201 L
s
.51781 .94201 m
.50286 .98804 L
s
.51781 .94201 m
.55696 .97046 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.51781 .94201 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.60535 .97046 L
s
.73205 .09857 m
.6929 .12701 L
s
.73205 .09857 m
.6929 .07012 L
s
.73205 .09857 m
.747 .14459 L
s
.73205 .09857 m
.6929 .07012 L
s
.73205 .09857 m
.6929 .07012 L
s
.73205 .09857 m
.6929 .07012 L
s
.6445 .07012 m
.6929 .07012 L
s
.6445 .07012 m
.60535 .09857 L
s
.6445 .07012 m
.6929 .07012 L
s
.6445 .07012 m
.6929 .07012 L
s
.6445 .07012 m
.6929 .07012 L
s
.6445 .94201 m
.6929 .94201 L
s
.6445 .94201 m
.65946 .89599 L
s
.6445 .94201 m
.60535 .97046 L
s
.6445 .94201 m
.6929 .94201 L
s
.6445 .94201 m
.60535 .97046 L
s
.6445 .94201 m
.60535 .97046 L
s
.6929 .12701 m
.70785 .17304 L
s
.6929 .12701 m
.73205 .09857 L
s
.6929 .07012 m
.6445 .07012 L
s
.6929 .07012 m
.73205 .09857 L
s
.6929 .94201 m
.70785 .89599 L
s
.6929 .94201 m
.70785 .89599 L
s
.6929 .94201 m
.70785 .89599 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.51781 .94201 L
s
.5662 .94201 m
.60535 .97046 L
s
.5662 .94201 m
.60535 .97046 L
s
.5904 .05254 m
.60535 .09857 L
s
.50286 .98804 m
.51781 .94201 L
s
.93704 .58054 m
.92209 .62656 L
s
.93704 .58054 m
.92209 .53451 L
s
.93704 .58054 m
.92209 .53451 L
s
.62031 .86755 m
.65946 .89599 L
s
.747 .14459 m
.79539 .14459 L
s
.747 .14459 m
.70785 .17304 L
s
.747 .14459 m
.79539 .14459 L
s
.747 .14459 m
.73205 .09857 L
s
.747 .14459 m
.79539 .14459 L
s
.79539 .14459 m
.83454 .17304 L
s
.65946 .89599 m
.70785 .89599 L
s
.65946 .89599 m
.70785 .89599 L
s
.65946 .89599 m
.70785 .89599 L
s
.70785 .89599 m
.747 .86755 L
s
.70785 .89599 m
.6929 .94201 L
s
.55696 .97046 m
.60535 .97046 L
s
.55696 .97046 m
.51781 .94201 L
s
.55696 .97046 m
.60535 .97046 L
s
.55696 .97046 m
.60535 .97046 L
s
.60535 .09857 m
.6445 .07012 L
s
.6445 .07012 m
.6929 .07012 L
s
.6445 .07012 m
.6929 .07012 L
s
.6445 .07012 m
.6929 .07012 L
s
.6929 .07012 m
.73205 .09857 L
s
.90713 .67258 m
.92209 .71861 L
s
.90713 .67258 m
.92209 .62656 L
s
.90713 .67258 m
.92209 .71861 L
s
.96124 .35713 m
.92209 .38558 L
s
.96124 .35713 m
.92209 .38558 L
s
.96124 .35713 m
.92209 .38558 L
s
.96124 .655 m
.92209 .62656 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.90713 .4316 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.96124 .35713 L
s
.92209 .71861 m
.90713 .76463 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.93704 .58054 L
s
.92209 .62656 m
.96124 .655 L
s
.93704 .33955 m
.92209 .38558 L
s
.93704 .33955 m
.92209 .29353 L
s
.93704 .33955 m
.92209 .38558 L
s
.93704 .58054 m
.92209 .53451 L
s
.93704 .58054 m
.92209 .53451 L
s
.94628 .46004 m
.90713 .4316 L
s
.94628 .46004 m
.90713 .48849 L
s
.94628 .46004 m
.96124 .50607 L
s
.94628 .46004 m
.96124 .41402 L
s
.94628 .46004 m
.96124 .41402 L
s
.94628 .46004 m
.96124 .50607 L
s
.90713 .2475 m
.92209 .29353 L
s
.90713 .4316 m
.86798 .46004 L
s
.90713 .4316 m
.92209 .38558 L
s
.90713 .4316 m
.92209 .38558 L
s
.90713 .48849 m
.86798 .46004 L
s
.90713 .48849 m
.92209 .53451 L
s
.90713 .48849 m
.92209 .53451 L
s
.90713 .76463 m
.92209 .71861 L
s
.96124 .50607 m
.92209 .53451 L
s
.96124 .50607 m
.97619 .46004 L
s
.96124 .50607 m
.97619 .46004 L
s
.96124 .50607 m
.92209 .53451 L
s
.96124 .50607 m
.97619 .46004 L
s
.96124 .56296 m
.92209 .53451 L
s
.96124 .56296 m
.92209 .53451 L
s
.96124 .41402 m
.92209 .38558 L
s
.96124 .41402 m
.97619 .46004 L
s
.96124 .41402 m
.92209 .38558 L
s
.96124 .41402 m
.97619 .46004 L
s
.96124 .41402 m
.97619 .46004 L
s
.70785 .89599 m
.747 .86755 L
s
.70785 .89599 m
.6929 .94201 L
s
.87369 .20148 m
.83454 .17304 L
s
.87369 .81066 m
.83454 .8391 L
s
.92209 .53451 m
.93704 .58054 L
s
.92209 .53451 m
.96124 .50607 L
s
.92209 .53451 m
.96124 .56296 L
s
.92209 .38558 m
.93704 .33955 L
s
.92209 .38558 m
.96124 .41402 L
s
.92209 .38558 m
.96124 .35713 L
s
.92209 .29353 m
.93704 .33955 L
s
.78615 .89599 m
.747 .86755 L
s
.83454 .17304 m
.79539 .14459 L
s
.83454 .17304 m
.79539 .14459 L
s
.83454 .8391 m
.79539 .86755 L
s
.83454 .8391 m
.79539 .86755 L
s
.747 .86755 m
.79539 .86755 L
s
.747 .86755 m
.79539 .86755 L
s
.747 .86755 m
.70785 .89599 L
s
.6929 .07012 m
.73205 .09857 L
s
.6929 .94201 m
.70785 .89599 L
s
.73205 .09857 m
.6929 .07012 L
s
.97619 .46004 m
.96124 .41402 L
s
.97619 .46004 m
.96124 .50607 L
s
.93704 .58054 m
.92209 .53451 L
s
.93704 .33955 m
.92209 .38558 L
s
.96124 .41402 m
.92209 .38558 L
s
.96124 .41402 m
.97619 .46004 L
s
.96124 .41402 m
.97619 .46004 L
s
.96124 .35713 m
.92209 .38558 L
s
.97619 .46004 m
.96124 .50607 L
s
.96124 .50607 m
.92209 .53451 L
s
.96124 .50607 m
.97619 .46004 L
s
.96124 .56296 m
.92209 .53451 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[142]:=",
  ImageSize->{284.5, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004L00017a000`40O003h00Oogoo7Goo003oOolM
Ool00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00SWoo00<007ooOol0Rgoo002>Ool00`00
Oomoo`2;Ool008moo`03001oogoo08Yoo`00Sgoo00<007ooOol0RWoo002?Ool00`00Oomoo`2:Ool0
06aoo`h001Ioo`03001oogoo08Uoo`00K7oo0`002goo0P0057oo00<007ooOol0RGoo001]Ool00`00
Ool0000<Ool00`00Oomoo`0AOol00`00Oomoo`29Ool006eoo`04001oogoo000<Ool2000AOol00`00
Oomoo`0DOol00`00Oomoo`1bOol006eoo`04001oogooOol2000<Ool00`00Oomoo`0?Ool00`00Oomo
o`0COol00`00Oomoo`1bOol005aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo009oo`03
001oogoo00Yoo`8000moo`03001oogoo01Aoo`03001oogoo075oo`00FWoo0`0027oo0`001Woo00<0
07ooOol00goo00<007ooOol02goo00<007ooOol037oo00<007ooOol057oo00<007ooOol0LGoo001I
Ool01@00Oomoogoo00001Woo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`8000aoo`8000eoo`03
001oogoo01=oo`03001oogoo075oo`00F7oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01Woo:P001goo00<007ooOol02goo3`00Egoo001FOol20006
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00
Oomoo`0:Ool2000=Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Ool0001F
Ool005Eoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Ioo`04001oogoo0008Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool3000<Ool20005Ool00`00Oomoo`07Ool2000<Ool20003Ool2001D
Ool005Aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Moo`03001oo`0000Qoo`03001o
ogoo00]oo`03001oogoo00Yoo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`1AOol0059oo`8000]oo`05001oogooOol0000:Ool3
0007Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool01000Oomoo`003Goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol01goo00<007ooOol0D7oo001AOol00`00Oomoo`0;Ool0
1@00Oomoogoo000037oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomo
o`0000eoo`05001oogooOol00005Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`1?Ool0
04moo`<000eoo`04001oogoo000=Ool30006Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool01000Oomoo`0017oo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool0CWoo001>Ool01@00Ool007oo00003Goo00<007oo000037oo00D007ooOomoo`0000Eoo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo009oo`8000aoo`<0009oo`8000aoo`8000moo`8004io
o`00CGoo00H007ooOol007oo000=Ool00`00Ool0000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool3000=Ool00`00Oomo
o`0AOol00`00Oomoo`1;Ool004]oo`8000=oo`04001oogoo000=Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool20003Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`05OolM000EOol00`00Oomo
o`1:Ool004Yoo`03001oogoo009oo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`06
Ool01000Oomoo`003Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo0`0037oo0P00
4Goo0`00C7oo0019Ool00`00Oomoo`03Ool01@00Oomoogoo00002goo1@002Woo00<007ooOol01goo
00<007oo00003Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007oo00003Goo
00<007ooOol03Goo00D007ooOomoo`0004]oo`00Agoo0P001Woo00<007ooOol00Woo00<007ooOol0
1goo00<007oo00000goo00<007ooOol01goo00<007ooOol027oo0`003Goo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02goo00@007ooOol000eoo`03001oogoo00]oo`03001oogoo009oo`03
001oogoo04Uoo`00?Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
1Woo00@007ooOol000Aoo`03001oogoo00Ioo`03001oogoo00Yooad000Moo`03001oogoo00Yoo`04
001oogooOol2000<Ool20009Ool20005Ool00`00Oomoo`19Ool003ioo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo00Aoo`80009oo`03001oogoo00Aoo`8000Eoo`03001o
ogoo00]oo`8000eoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo04Qoo`00?goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00P0037oo0P0037oo0P0017oo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol0B7oo000oOol00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`04Ool01@00Oomoogoo
00001Goo00<007ooOol01goo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Aoo`8000aoo`800003Ool0
000000Yoo`03001oogoo04Qoo`00?goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo
0`001Goo00<007ooOol02Goo0`003Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol02goo
00D007ooOomoo`0000aoo`03001oogoo00Ioo`l000aoo`03001oogoo04Qoo`00?goo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol017oo00<007ooOol02goo00<007ooOol02goo00@007ooOol000eoo`03001oogoo
00Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo04Moo`00@7oo00D007ooOomoo`0000Mo
o`8000Qoo`03001oogoo00Eoo`03001oogoo00]oo`8000]oo`03001oogoo00Ioo`03001oogoo00]o
o`03001oogoo00]oo`04001oogoo000<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`17Ool0041oo`05001oogooOol00005Ool20002Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`0;Ool00`00Oomoo`020009Ool00`00Oomoo`07Ool2000<Ool2000<Ool3000<
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`17Ool0041oo`05001o
ogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool2
000<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`16Ool0045oo`03
001oo`0000Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00]oobX000Qoo`03001oogoo00]oo`03001oogoo
00Yoo`l003Yoo`00@Goo00<007oo00000goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol037oo00<007ooOol017oo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
2goo0`0037oo0P002goo0P001Woo00<007ooOol02goo00<007ooOol027oo0P0000=oo`00000037oo
0P00>7oo0011Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Ool0000<Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
1@00Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol02goo00<007ooOol0=Goo0011Ool00`00Ool000020009Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool20003Ool2000:Ool00`00Oomoo`07Ool20002Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomo
o`0dOol0049oo`8000]oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00
Oomoo`09Ool2000=Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool2000<Ool2000;Ool20003Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool20009Ool2000<Ool2000dOol0049oo`03001oogoo00]oo`04001o
ogoo0003Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool01000Oomoo`003Goo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol0<Goo0010Ool3000=Ool00`00
Ool00003Ool00`00Oomoo`09Ool20005Ool00`00Oomoo`0;Ool3000:Ool00`00Oomoo`0;Ool00`00
Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Ool0000=Ool01@00Oomoogoo00003goo
00<007ooOol02goo00<007ooOol0<7oo000oOol01@00Ool007oo000037oo00<007oo00000Woo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000Uoo`03001oogoo00]o
o`03001oogoo00Qoo`8000aoo`8000]oo`<000eoo`<0015oo`8000aoo`80031oo`00?Woo00H007oo
Ool007oo000<Ool00`00Ool00002000@Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol02Woo:P005Goo3`00;goo000lOol20003Ool00`00Ool0
000=Ool2000COol3000=Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool3000;Ool2000<Ool2000AOol2000<Ool200000goo0000000]Ool003]oo`03001o
ogoo009oo`05001oogooOol0000<Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01@00Oomoogoo0000
37oo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
:Woo000jOol00`00Oomoo`03Ool01@00Oomoogoo00002Woo1@004Woo1@002Woo00<007ooOol01goo
00D007ooOomoo`0000eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo
00Yoo`8000aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo02Uoo`00
>7oo0P001Woo00D007ooOomoo`0000Uoo`03001oo`0000=oo`03001oogoo00ioo`03001oo`0000=o
o`03001oogoo00Moo`03001oogoo00Qoo`<000eoo`03001oogoo00]oo`03001oogoo00Yoo`03001o
ogoo00Aoo`8000aoo`03001oogoo00Yoo`8000Uoo`8000aoo`8000Uoo`8002Uoo`00:Goo3`0027oo
00D007ooOomoo`0000Qoo`04001oogoo0004Ool00`00Oomoo`0;Ool20002Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`0:Ool?000<Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool2000<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0VOol0
02Uoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`8000=oo`03
001oogoo00=oo`8000Yoo`05001oogooOol00006Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool3000:Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol002Qoo`03001oogoo00]o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo00Eoo`8000Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo00]oo`05001oogooOol00009Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool2000<Ool2000;Ool2
00000goo0000000<Ool2000AOol2000UOol002Qoo`03001oogoo00]oo`03001oogoo00Ioo`03001o
ogoo00=oo`05001oogooOol00005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`07Ool01@00Oomoogoo000037oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol02Woo00<007ooOol02goo:P005Goo00<007ooOol08Woo000XOol00`00Oomoo`0;
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool30006Ool00`00Oomoo`08Ool200000goo00000006Ool0
0`00Oomoo`09Ool3000=Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool20005Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool3000;Ool2000<Ool2000AOol2000UOol002Moo`03001oogoo
00]oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
00Ioo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
009oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`05001oogooOol0000<Ool00`00
Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol002Moo`03001oogoo00]oo`03001oogoo00Ao
o`<000Moo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`<000Yo
o`03001oogoo00]oo`03001oogoo00Moo`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomo
o`0;Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo
o`0VOol002Moo`03001oogoo00]oo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`06
Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool01@00Oomoogoo00002Goo00<007oo
Ool02Woo00<007ooOol02Goo0`0037oo00<007ooOol037oo00<007ooOol02Woo00<007ooOol017oo
0P002goo0P0037oo0P002Goo0P00:Goo000WOol00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool>000=Ool0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool0
0`00Oomoo`0YOol002Ioo`03001oogoo00]oo`04001oogooOol20005Ool00`00Oomoo`03Ool00`00
Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool20005
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool3000;Ool00`00Oomoo`0;Ool00`00
Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0ZOol002Io
o`03001oogoo00]oo`04001oogoo0008Ool01@00Oomoogoo000027oo00<007ooOol02Woo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool02goo00<007ooOol02Woo00D007ooOomoo`0000Yoo`03001oogoo00Yoo`03001oogoo00Uoo`80
00]oo`8000aoo`800003Ool0000002eoo`009Woo00<007ooOol02goo00<007oo00002Goo00D007oo
Oomoo`0000Ioo`800003Ool0000000Yoo`03001oogoo00Aoo`800003Ool0000000]oo`03001oogoo
00Moo`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool20008
Ool00`00Oomoo`0:Ool00`00Oomoo`0;OolZ000QOol002Eoo`03001oogoo00]oo`<000Yoo`05001o
ogooOol00005Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`09Ool3000<Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0OOol002Eoo`l000aoo`05001oogooOol00004Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`0;Ool>000=Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0POol002=o
o`8000aoo`<000eoo`03001oo`0000=oo`8000Uoo`8000Eoo`04001oogooOol20009Ool20006Ool0
0`00Oomoo`0;Ool3000;Ool2000;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool01@00Oomoogoo0000
37oo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
87oo000ROol00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<007oo00000Woo00<007ooOol02goo
00<007ooOol00Woo00@007ooOol000eoo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0
000<Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool3000<Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0POol0025oo`03001oogoo
00]oo`03001oogoo009oo`03001oogoo00Yoo`05001oo`00Ool0000?Ool01`00Oomoogoo001oo`00
00moo`05001oogooOol0000=Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool20008Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool>000=Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool00`00Oomoo`0HOol001moo`8000aoo`8000Eoo`03001oogoo00]oo`<0015oo`D0015o
o`<000eoo`03001oogoo00Aoo`8000aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00ao
o`03001oogoo00Yoo`<000]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00Aoo`<001Yoo`007Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02Woo00<007oo
Ool04goo00<007ooOol04goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02Woo0P0017oo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomoo`0000Uoo`03001oogoo
00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`05001oogooOol0000IOol001eo
o`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Qoo`D0015oo`D0015oo`800003Ool00000
00]oo`03001oogoo00Moo`03001oogoo00]oo`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol001]oo`8000aoo`8000Yo
o`03001oogoo00Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`0000=oo`03001oogoo00eo
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`8000aoo`<000aoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00=oo`8000Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001o
ogoo00]oo`04001oogooOol20005Ool00`00Oomoo`0GOol001Yoo`l000aoo`03001oogoo00Ioo`04
001oogoo0004Ool00`00Oomoo`0;Ool01000Oomoo`0017oo00<007ooOol02goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol02goo70003Goo00<007ooOol02Woo00<007ooOol01Woo00<007oo
Ool00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00@007ooOol000Qoo`03001o
ogoo01Ioo`006Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo0P000goo00<007oo
Ool00goo0P002Goo0P000goo00<007ooOol00goo0P002Goo0P002Goo0P001Woo00<007ooOol02goo
00<007ooOol02goo0`002goo0P002goo00<007ooOol02Woo00<007ooOol01goo00D007ooOomoo`00
00eoo`03001oogoo00]oo`03001oogoo00]oo`03001oo`0000Uoo`03001oogoo01Ioo`006Goo00<0
07oo00003Goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol01Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol02goo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo00Mo
o`03001oogoo00]oo`03001oogoo00Qoo`<000eoo`03001oogoo00]oo`03001oogoo00]oo`<000Yo
o`03001oogoo01Ioo`006Goo00<007oo00003Goo00<007ooOol02Woo00D007ooOomoo`0000Eoo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00eoo`05001oogooOol0000=Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool[000<Ool00`00Oomoo`0FOol001Uo
o`03001oo`0000eoo`03001oogoo00]oo`<000Ioo`03001oogoo00Qoo`800003Ool0000000Ioo`03
001oogoo00Qoo`800003Ool00000015oo`<000ioo`03001oogoo00Yoo`03001oogoo00Aoo`8000]o
o`8000Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo01Eoo`0067oo00D007ooOomoo`0000eoo`03001oogoo
00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
01=oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo
00]oo`03001oo`0000aoo`03001oogoo01Eoo`0067oo00D007ooOomoo`0000eoo`03001oogoo00Qo
o`<000Moo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00]oo`<0015oo`D000]oo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`05001oogooOol0000=Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Ool0000<Ool00`00Oomoo`0EOol0
01Qoo`05001oogooOol0000=Ool00`00Oomoo`07Ool00`00Ool00008Ool00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`0:Ool01@00Oomoogoo00003goo00<007oo00000goo00<007ooOol027oo
00<007ooOol02Woo00<007ooOol02Goo0P002goo0`003Goo00<007ooOol02goo00<007ooOol02goo
00<007ooOol02goo00<007ooOol02Woo00@007ooOol000eoo`03001oogoo01Aoo`0067oo00D007oo
Oomoo`0000eoo`03001oogoo00Ioo`04001oogoo0008Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01000Oomoo`0017oo0P0027oo00<007oo
Ool02Woo00<007ooOol02goo700037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo
00D007ooOomoo`0000aoo`03001oogoo01Aoo`005goo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol00goo0P000goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol0
2goo00<007ooOol00goo0P002Goo0P000goo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02Woo0`0037oo0P002Woo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol02goo00D007ooOomoo`0000Yoo`<001Ioo`005goo00<007ooOol00goo00<007oo
Ool02goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Woo00<007oo
Ool01Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool01Woo0P0017oo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomoo`00
00eoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00Moo`05001oo`00Ool0000EOol001Moo`03001oogoo00=oo`03001oogoo00]o
o`05001oogooOol00005Ool00`00Oomoo`04Ool200000goo0000000:Ool00`00Oomoo`04Ool20000
0goo0000000:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`08Ool0
1@00Oomoogoo000037oo00<007ooOol02goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0
0Woo00<007ooOol01Woo00H007ooOol007oo000EOol001Ioo`03001oogoo00Eoo`03001oogoo00]o
o`<000Ioo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Moo`03001oogoo00Qoo`800003Ool0000000Ioo`03001oogoo00Uoo`<0
00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`8000aoo`8000Eoo`03001oogoo
00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00=oo`8000=oo`03
001oo`0001Eoo`005Woo00<007ooOol01Goo3`0027oo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol02Woo00<0
07ooOol01Woo00<007ooOol02goo3P003Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol0
2goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0001Aoo`005Woo00<007ooOol01Goo
00<007ooOol02goo00<007ooOol01Goo00@007ooOomoo`8000Uoo`8000Eoo`04001oogooOol20009
Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool3000;
Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool01@00Oomoogoo00003Goo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`05001oogooOol0000D
Ool001Moo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Ioo`04001oogoo000=Ool00`00
Oomoo`02Ool01000Oomoo`003Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol01Woo00<0
07ooOol02goo00<007ooOol02Woo00D007ooOomoo`0000Uoo`03001oogoo00]oo`03001oogoo00Qo
o`8000aoo`<000eoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`<000Ioo`05001o
ogooOol0000DOol001Moo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Ioo`03001oo`00
00moo`07001oogooOol007oo00003goo00D007ooOomoo`0000aoo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
00YoocP000Qoo`03001oogoo00Ioo`05001oogooOol0000DOol001Moo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00Eoo`<0015oo`D0015oo`<000eoo`03001oogoo00Eoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00=oo`8000Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo015oo`0067oo00D007ooOomoo`0000eoo`03001oogoo
00Ioo`03001oogoo01=oo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oo`00
00Ioo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo015oo`0067oo00D007ooOomoo`0000eo
o`03001oogoo00Aoo`D0015oo`D0015oo`800003Ool0000000Yoo`03001oogoo00Aoo`800003Ool0
000000]oo`03001oogoo00Yoo`03001oogoo00Moo`05001oogooOol0000=Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Ool00006Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0AOol001Qoo`05001oogooOol0000=Ool00`00
Oomoo`03Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool3000=Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol047oo000HOol01@00Oomoogoo00003Goo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00]oo`04001oogoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool?000<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool01@00
Oomoogoo000017oo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol047oo000IOol00`00Ool0
000=Ool01000Oomoogoo0P000Woo00<007ooOol017oo0P002Goo0P000goo00<007ooOol00goo0P00
2Goo0P002Goo0P001Goo00@007ooOomoo`8000Uoo`8000Ioo`03001oogoo00Yoo`03001oogoo00]o
o`03001oogoo00]oo`<000Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`04Ool30007Ool00`00Oomoo`0@Ool001Uoo`03
001oo`0000eoo`04001oogoo0004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01000Oomoo`003Goo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00D007ooOomoo`00
00Uoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
009oo`05001oogooOol00005Ool01@00Oomoogoo00001Goo00<007ooOol04Goo000IOol00`00Ool0
000=Ool00`00Ool00005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01`00Oomoogoo001oo`0000moo`05001oogooOol0
000=Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol04Goo000JOol00`00Oomoo`0;
Ool30005Ool00`00Oomoo`09Ool200000goo00000006Ool00`00Oomoo`08Ool200000goo0000000A
Ool5000AOol3000=Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool01000
Oomoo`000goo0P001Goo00<007ooOol00goo00<007ooOol04Goo000JOol?0007Ool00`00Oomoo`0;
Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0COol00`00Oomoo`0COol?000<Ool00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00
Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00Oomoo`06Ool01@00
Oomoogoo000027oo00<007ooOol02Goo000HOol3000=Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool0
0`00Oomoo`05Ool00`00Oomoo`0;Ool3000AOol5000AOol200000goo0000000<Ool2000:Ool00`00
Oomoo`0;Ool00`00Oomoo`07Ool01@00Oomoogoo00003Goo00<007ooOol02goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol017oo00D007oo001oo`0000Uoo`05001oogooOol00006Ool2000<
Ool001Moo`03001oo`0000eoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001o
ogoo00Yoo`05001oogooOol0000?Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool3000=Ool00`00Oomo
o`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool3000:Ool01@00Oomoogoo0000
1Goo00<007ooOol037oo000FOol01000Oomoo`003Goo00<007ooOol01Goo00<007ooOol02goo00<0
07ooOol01Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol02goo00@007ooOol000Aoo`03
001oogoo00]oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03
001oogoo00YoocP000Qoo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`0=Ool001Ao
o`8000=oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00]oo`03001oogoo00=oo`8000Uoo`8000=oo`03001oogoo00=oo`8000Uoo`8000Uoo`8000ao
o`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oo`0000=oo`80011o
o`004goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007oo
Ool01Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007oo000037oo00<007oo
Ool02goo00<007ooOol017oo00<007oo000037oo00<007oo00000Woo00<007ooOol047oo000BOol0
0`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool200000goo0000000;Ool00`00Oomoo`04
Ool200000goo0000000:Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool01@00Oomoogoo00003Goo00<0
07ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007oo000037oo00<007ooOol02goo00<0
07ooOol017oo00<007oo000037oo00D007oo001oo`0001=oo`0047oo0P001Woo00<007ooOol02Woo
00<007ooOol00goo00<007ooOol00goo00<007ooOol027oo00<007ooOol00goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol027oo0P0000=oo`0000001Woo00<007ooOol027oo0P0000=oo`00
00004Goo0P0037oo0`003Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00@007oo
Ool000eoo`03001oogoo00Yoo`03001oogoo00=oo`04001oogoo000=Ool3000DOol000moo`03001o
ogoo00Ioo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Eoo`8000Qoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yo
o`03001oogoo01=ooad000aoo`03001oogoo00]oo`03001oogoo00]oo`05001oogooOol0000<Ool0
0`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Oomoogoo000037oo00<007ooOol057oo000?Ool00`00
Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`02000:Ool00`00Oomoo`04Ool01000Oomoogoo0P00
2Goo0P001Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo0`004Goo0`003Goo0`00
37oo0P002Woo00<007ooOol02goo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo00]o
o`03001oogoo009oo`05001oogooOol0000:Ool5000DOol000ioo`03001oogoo00Ioo`03001oogoo
00Yoo`04001oogoo000=Ool20004Ool01000Oomoo`003Goo00<007ooOol00Woo00<007ooOol02Woo
00<007ooOol01Woo00<007ooOol02Woo00D007ooOomoo`0000moo`03001oo`0000eoo`05001oogoo
Ool0000=Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007oo00000goo
00<007ooOol04Goo000>Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Ool0000@Ool01`00Oomo
ogoo001oo`0000moo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool01000Oomoo`003Goo00<007ooOol00Woo00<007ooOol02goo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol02goo00<007oo
Ool02Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`04001oogoo0004Ool00`00Oomoo`0@Ool0
00eoo`03001oogoo00Ioo`03001oogoo00Yoo`<0019oo`D0015oo`<000eoo`03001oogoo00Eoo`03
001oogoo00]oo`03001oogoo00=oo`8000Uoo`8000=oo`03001oogoo00]oo`03001oogoo00=oo`80
00aoo`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`03
001oogoo00]oo`04001oogoo0005Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`03Ool2000@Ool0
00eoo`03001oogoo00Ioo`h001Ioo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo00Ioo`03
001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oo`0000Ioo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Ioo`03001oogoo00eoo`003Goo00<007ooOol017oo0P002goo1@00
4Woo1@004Goo0P0000=oo`0000002Woo00<007ooOol017oo0P0000=oo`0000002Woo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol00goo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
2goo00D007ooOomoo`0000eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oo`0000Ioo`05001oogooOol00005Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool0
00aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oo`0000=oo`03001oogoo00ioo`03001oo`00
00=oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00Qoo`800003Ool0000000Ioo`03001oogoo00]oo`03001o
ogoo00Qoo`8000aoo`<000eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo00Ioo`<000Ioo`03001oogoo00Qoo`8000aoo`0037oo00<007ooOol00Woo
0P0037oo00@007ooOol000Aoo`03001oogoo00]oo`80009oo`03001oogoo009oo`03001oogoo00]o
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00YoobX000Qooa`000Qo
o`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Uoo`0037oo00D007ooOomoo`0000aoo`80
00=oo`03001oogoo00=oo`8000Yoo`05001oogooOol00006Ool20009Ool20009Ool20005Ool01000
Oomoogoo0P002Goo0P001Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol01Woo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol02goo00<007oo
Ool02Goo000;Ool00`00Oomoo`02000<Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool20004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01000
Oomoo`003Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02goo00<0
07ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007oo000037oo00<007ooOol017oo00<0
07ooOol02goo00<007ooOol02Woo00<007oo00001Woo00<007ooOol01Woo00<007ooOol02Woo00<0
07oo00002Woo000;Ool00`00Ool0000=Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01`00Oomoogoo
001oo`0000moo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Ool0000<Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`0:Ool00`00Ool00006Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Ool0000:
Ool000Yoo`<000aoo`8000Ioo`03001oogoo00Qoo`800003Ool0000000Ioo`03001oogoo00Uoo`80
0003Ool00000015oo`D0015oo`<000eoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00Yoo`04001oogoo000=Ool00`00Oomoo`03Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol02goo00<007oo0000
2Woo000:Ool?0008Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0C
Ool00`00Oomoo`0COol00`00Oomoo`0:Ool00`00Oomoo`06Ool?000<Ool00`00Oomoo`0;Ool00`00
Oomoo`0;Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo
00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo00Yoo`05001oogooOol00009Ool000Yo
o`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]o
o`<0015oo`D0015oo`800003Ool0000000Yoo`03001oogoo00Aoo`8000aoo`800003Ool0000000Yo
o`03001oogoo00]oo`03001oogoo00]oo`05001oogooOol0000<Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool00`00Oomoo`0:Ool01@00Oomoogoo000017oo00<007ooOol017oo0P0000=oo`0000002Woo
00D007ooOomoo`0000Uoo`002Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02Woo00<0
07ooOol01Woo00<007ooOol02goo00D007ooOomoo`0000moo`03001oo`0000=oo`03001oogoo00eo
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00]o
o`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<0
07ooOol00goo00<007ooOol01goo00D007ooOomoo`0000Uoo`002Goo00<007ooOol02goo00<007oo
Ool01Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol00Woo00<007oo
Ool02goo00@007ooOol000Aoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00Ioo`03001o
ogoo009oo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0000<Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol01Woo00D007ooOomo
o`0000Uoo`002Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Goo
00<007ooOol02goo00<007ooOol017oo0P002Goo0P000goo00<007ooOol00goo0P002Goo0P002Goo
0P001Goo00@007ooOomoo`8000aoo`8000Uoo`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00Yoo`04001oogoo000=Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool0
1000Oomoo`000goo0P002Goo0P001Goo00<007ooOol00goo00<007ooOol01Woo0008Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`0;Ool00`00Oomoo`02Ool01000Oomoo`003Goo00<007ooOol02goo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007oo000037oo00<007oo
Ool02goo00<007ooOol017oo00<007oo00000Woo00<007ooOol02goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol01Woo0008Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool200000goo0000000:
Ool00`00Oomoo`04Ool200000goo0000000;Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool01`00Oomoogoo001oo`0000eo
o`03001oogoo00eoo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomo
o`0;Ool00`00Ool0000<Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool01@00Ool007oo00003goo00D0
07ooOomoo`0000Eoo`03001oogoo00Ioo`0027oo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool02Goo0P0000=oo`0000001Woo00<007ooOol027oo0P0000=oo`0000004Goo1@0037oo0P004Goo
0`003Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo00<007oo
Ool02goo00<007ooOol01Woo0`004Goo0`001goo00<007ooOol01Goo0008Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0COol?
000EOolL0008OolZ0008Ool00`00Oomoo`0COol00`00Oomoo`05Ool00`00Oomoo`05Ool000Moo`03
001oogoo00]oo`04001oogooOol20009Ool20005Ool01000Oomoogoo0P002Goo0P001Woo00<007oo
Ool02goo00<007ooOol01Goo00<007ooOol02goo0`004Goo1@0037oo0P004Goo0`003Goo00<007oo
Ool02Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007oo
Ool01Woo0`004Goo0`001goo00<007ooOol01Goo0007Ool00`00Oomoo`0;Ool01000Oomoo`003Goo
00<007ooOol00Woo00@007ooOol000eoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Io
o`03001oogoo00Yoo`05001oogooOol0000?Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Oomo
o`0=Ool01@00Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<0
07oo000037oo00<007ooOol02goo00<007ooOol017oo00D007oo001oo`0000moo`05001oogooOol0
0005Ool00`00Oomoo`06Ool000Moo`03001oogoo00]oo`03001oo`0000moo`07001oogooOol007oo
00003goo00D007ooOomoo`0000eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00]oo`04001oogoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Ool0000<Ool0
0`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Ool00002Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool000Ioo`03001oogoo00]oo`<0015oo`D0015oo`<000eoo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00=oo`8000Uoo`8000=oo`03001oogoo00=oo`80
00aoo`8000Uoo`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo
00Yoo`04001oogoo000=Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool01000Oomoo`000goo0P002Goo
0P001Goo00<007ooOol00goo00<007ooOol01Woo0006Ool?000EOol00`00Oomoo`0COol00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<0
07ooOol02goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo00Io
o`05001oogooOol00009Ool0019oo`800003Ool00000015oo`800003Ool00000015oo`800003Ool0
000000]oo`03001oogoo00Aoo`800003Ool0000000Yoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Moo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0000<
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007oo
Ool01goo00D007ooOomoo`0000Uoo`004Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0
0goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol027oo0P0000=oo`0000001Woo00<007ooOol027oo0P0037oo
0P0000=oo`0000002Woo00<007ooOol02goo00<007ooOol02goo00D007ooOomoo`0000aoo`03001o
ogoo009oo`03001oogoo00]oo`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`04Ool2
00000goo0000000:Ool01@00Oomoogoo00002Goo000@Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool0
0`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`02Ool2
0007Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool?000<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol0
2goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo00Yoo`05001o
ogooOol00009Ool000ioo`8000Uoo`8000Uoo`8000Uoo`8000Uoo`8000Uoo`8000Ioo`05001oogoo
Ool0000:Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool01000Oomoo`003Goo00<007ooOol0
0goo00<007ooOol02Woo00<007ooOol02goo00@007ooOol000Eoo`03001oogoo00Eoo`03001oogoo
00]oo`03001oo`0000Yoo`003Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol00Woo00<007ooOol00P003Goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol02goo00<007oo000037oo
00<007ooOol02goo00<007ooOol02goo00<007oo000037oo00<007ooOol017oo00<007ooOol02goo
00<007ooOol02Woo00<007oo00001Woo00<007ooOol01Woo00<007ooOol02Woo00<007oo00002Woo
000<Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomo
o`0=Ool01`00Oomoogoo001oo`00011oo`05001oogooOol0000<Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Ool0000<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Ool0
000<Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Ool00006Ool00`00Oomo
o`06Ool00`00Oomoo`0:Ool00`00Ool0000:Ool000Yoo`80015oo`800003Ool00000015oo`800003
Ool00000015oo`D0019oo`<000eoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00]oo`03
001oo`0000eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00]oo`03
001oogoo00Uoo`002Goo00<007ooOol04goo00<007ooOol04goo00<007ooOol04goo00<007ooOol0
57oo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol02goo00D007ooOomo
o`0000aoobX000Qooa`000Qoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Uoo`002Woo
0P004Goo0P0000=oo`0000004Goo0P0000=oo`0000004Goo0P0000=oo`0000004Woo0P0000=oo`00
00002Woo00<007ooOol017oo0P0000=oo`0000002Woo00<007ooOol02goo00D007ooOomoo`0000Yo
o`<000eoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo00Ioo`<000Ioo`03001oogoo00Qoo`8000aoo`0037oo00<007ooOol03Goo
00<007ooOol00goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol01goo00<007ooOol02goo00D007ooOomoo`0000Uoo`03001oo`0000eoo`03001oogoo
00]oo`03001oo`0000aoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oo`00
00Ioo`05001oogooOol00005Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool000eoo`03001oogoo00]o
o`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Eo
o`8000eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00]oo`05001oogooOol00008Ool01000Oomoo`003Goo00<007ooOol02goo
00<007oo000037oo00<007ooOol017oo00<007ooOol02goo00<007ooOol02Woo00<007oo00001Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol03Goo000>Ool20009Ool2
0009Ool20009Ool20009Ool20009Ool2000:Ool00`00Oomoo`08Ool20009Ool20005Ool01000Oomo
ogoo0P002Goo0P001Goo00<007ooOol02goo00<007ooOol00goo00<007ooOol00goo0P000goo00<0
07ooOol02goo00<007ooOol02Woo00@007ooOol000eoo`03001oogoo00=oo`03001oogoo00Yoo`03
001oogoo00]oo`04001oogoo0005Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`03Ool2000@Ool0
011oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo
00Eoo`03001oogoo00]oo`8000Moo`03001oogoo00]oo`03001oogoo009oo`04001oogoo000=Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol0
2goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`04001oogoo0004Ool00`00
Oomoo`0@Ool0015oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00eo
o`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00eoo`07001oogooOol0
07oo00003goo00D007ooOomoo`0000eoo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<007ooOol00Woo00<007ooOol02goo00<0
07ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oo`0000=oo`03001oogoo015o
o`004Woo0P0000=oo`0000004Goo0P0000=oo`0000004Goo0P0000=oo`0000004Woo0P0000=oo`00
00004Goo1@004Goo0`003Goo00<007ooOol01Goo0`001Woo00<007ooOol02goo00<007ooOol02Woo
00<007ooOol00Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo00]oo`03001oogoo
009oo`05001oogooOol0000:Ool5000DOol000Ioo`l001Eoo`03001oogoo01=oo`03001oogoo01Ao
o`03001oogoo01=oo`03001oogoo01=oo`l000Moo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0000<Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool01@00Oomoogoo000037oo00<007ooOol057oo0006Ool3000<Ool2000AOol20000
0goo0000000AOol200000goo0000000BOol5000AOol5000AOol3000=Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool01000
Oomoo`003Goo00<007ooOol02Woo00<007ooOol00goo00@007ooOol000eoo`<001Aoo`001goo00<0
07oo00003Goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol00goo00<0
07ooOol03Woo00L007ooOomoo`00Ool0000?Ool01`00Oomoogoo001oo`0000moo`05001oogooOol0
000=Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0;Ool00`00Ool0000<Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Ool0
000<Ool01@00Ool007oo00004goo0007Ool01000Oomoo`003Goo00<007ooOol02goo00<007ooOol0
1Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo0P0017oo00@007ooOol000eoo`03
001oogoo009oo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool0
0`00Ool0000<Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Ool0000<Ool00`00Ool00002Ool0
0`00Oomoo`0@Ool000Moo`04001oogooOol2000<Ool20009Ool20009Ool20009Ool20009Ool2000:
Ool00`00Oomoo`04Ool01000Oomoogoo0P002Goo0P001Goo00@007ooOomoo`8000Uoo`8000Eoo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Ioo`03
001oogoo00]oo`03001oo`0000=oo`80011oo`0027oo00<007ooOol00Woo00<007ooOol02goo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol01Goo0P00
27oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol02goo00D007ooOomoo`0000Qooa`000QoobX000Qoo`03001o
ogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`0=Ool000Qoo`03001oogoo00=oo`03001oogoo
00]oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo
00=oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00]oo`05001oogooOol00006Ool2000<
Ool3000<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool3000:Ool01@00Oomoogoo00001Goo00<007ooOol037oo0008Ool00`00Oomoo`04Ool2
000<Ool200000goo0000000AOol200000goo0000000AOol200000goo0000000;Ool00`00Oomoo`04
Ool200000goo0000000:Ool00`00Oomoo`04Ool200000goo0000000:Ool00`00Oomoo`0;Ool01@00
Oomoogoo00001Goo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo00Aoo`03001oogoo
00]oo`03001oo`0000aoo`03001oogoo00]oo`03001oogoo00Aoo`05001oo`00Ool00009Ool01@00
Oomoogoo00001Woo0P0037oo0008Ool00`00Oomoo`06Ool?000EOol00`00Oomoo`0COol00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomo
o`0;Ool01@00Oomoogoo000017oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02goo00<007oo000037oo00<007ooOol02goo00<007ooOol017oo00<0
07oo00000Woo00<007ooOol01Woo00D007ooOomoo`0000Qoo`03001oogoo00Uoo`002Goo00<007oo
Ool01Goo00<007ooOol02goo0`004Goo1@004Goo0`003Woo00<007ooOol01Goo00<007ooOol02goo
00<007ooOol01Goo00<007ooOol02goo00<007ooOol02goo00<007oo00000goo0P0037oo0P001Goo
00<007ooOol02goo00<007ooOol00goo00<007ooOol02Woo00@007ooOol000eoo`03001oogoo00Yo
o`03001oogoo00=oo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`0AOol000Uo
o`03001oogoo00Ioo`03001oogoo00]oo`03001oo`0000moo`07001oogooOol007oo00003goo00D0
07ooOomoo`0000eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yo
o`03001oogoo00]oo`03001oo`00009oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yo
o`03001oogoo009oo`03001oogoo00]oo`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol04Goo0009
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool01000Oomoo`003Goo00<007ooOol00Woo00@007ooOol0
00eoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
00Ioo`03001oogoo00Yoo`03001oogoo00]oo`05001oo`00Ool0000=Ool00`00Oomoo`07Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo00<007ooOol02goo
00<007ooOol00Woo00D007ooOomoo`0000Eoo`05001oogooOol00005Ool00`00Oomoo`0AOol000Yo
o`03001oogoo00Ioo`03001oogoo00Yoo`04001oogooOol20009Ool20006Ool00`00Oomoo`020009
Ool20006Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool3000<Ool2000:Ool00`00Oomoo`0;Ool01@00Oomoogoo000037oo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`<000Moo`03001oogoo011oo`002Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
1Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol0
2Woo7@0037oo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo009oo`03001oogoo00]o
o`03001oogoo00Yoo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`0@Ool000]oo`8000Ioo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Uoo`800003Ool0
000000Ioo`03001oogoo00Qoo`800003Ool0000000Ioo`03001oogoo00Qoo`8000aoo`<000eoo`03
001oogoo00]oo`03001oogoo00Yoo`04001oogoo000=Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool01000Oomoo`001Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol047oo
000=Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool200000goo0000000;Ool00`00
Oomoo`03Ool200000goo0000000;Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool0
1@00Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol02goo00<007oo000037oo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol02Woo00<007oo00001Woo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol04Goo000>Ool20004Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;
Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0;
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Ool0000<
Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Ool00006Ool00`00Oomoo`06
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol0011oo`05001oogooOol0000=Ool00`00Oomoo`05Ool0
0`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool20009Ool20003Ool0
0`00Oomoo`03Ool20009Ool20003Ool00`00Oomoo`03Ool2000<Ool20005Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0AOol0
015oo`80009oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03
001oogoo00]oo`03001oogoo009oo`03001oogoo00]oo`04001oogoo0004Ool00`00Oomoo`0;Ool0
1000Oomoo`0017oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo
700027oo700027oo00<007ooOol01Woo00D007ooOomoo`0001Aoo`004goo00<007oo000037oo00<0
07ooOol01Woo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00D007ooOomoo`0000mo
o`03001oo`0000=oo`03001oogoo00eoo`03001oo`0000=oo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo00]oo`03001oogoo00Qoo`<000eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo00Ioo`<000Ioo`05001oogooOol0000DOol001Aoo`<0
00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00]oo`<0015oo`D0
015oo`D000aoo`8000Yoo`03001oogoo00]oo`03001oogoo00Moo`05001oogooOol0000=Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Ool00006Ool01@00
Oomoogoo00001Goo00D007ooOomoo`0001Aoo`005Woo3P0027oo00<007ooOol02goo00<007ooOol0
1Goo00<007ooOol02goo00<007ooOol04goo00<007ooOol04goo3`0037oo00<007ooOol02goo00<0
07ooOol01Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02goo00<007ooOol02Woo00<007oo00001Woo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`0001Aoo`005Woo00<007ooOol02Woo0`001Woo00<007ooOol02Goo0P0000=oo`000000
1Goo00<007ooOol02Goo0P0000=oo`0000004Goo1@004Goo0`003Goo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol00goo0P001Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo
00<007ooOol02Woo00<007ooOol02goo00@007ooOol000Eoo`03001oogoo00=oo`8000=oo`03001o
o`0001Eoo`005goo00<007ooOol02Woo00<007oo00001Goo00<007ooOol027oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol01goo00<007ooOol00goo00<007ooOol03Goo00L007ooOomoo`00
Ool0000?Ool01@00Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol02goo
00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`06001oogoo001oo`005Goo000G
Ool00`00Oomoo`0:Ool01000Oomoo`0017oo00<007ooOol01Woo0P001goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol01Goo00<007ooOol02goo00<007ooOol00Woo00@007ooOol000eoo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`05001oogooOol00009
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool01@00Oomoogoo000017oo00<007ooOol01goo00D007oo001oo`0001Eoo`005goo00<007ooOol0
2goo00<007ooOol00P000goo00<007ooOol017oo00<007ooOol027oo0P000Woo00<007ooOol017oo
0P002Goo0P002Goo0P001Goo00@007ooOomoo`8000Uoo`8000Eoo`03001oogoo00]oo`03001oogoo
00]oo`03001oogoo00]oo`<000Yoo`03001oogoo00]oo`03001oogoo00]oo`05001oogooOol0000<
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Oomoogoo00002Woo0`005Woo000HOol00`00Oomo
o`0:Ool00`00Oomoo`02Ool01000Oomoo`0017oo0P003Goo00@007ooOol000Aoo`03001oogoo00]o
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00]oo`03001oogoo00Yoo`l000aoo`03001oogoo00]oo`03001oogoo00]oo`05001o
ogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool01@00Oomoogoo000037oo00<007ooOol0
57oo000HOol00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Ool00003Ool00`00Oomoo`0>Ool00`00
Ool00003Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool3000=Ool00`00Oomoo`0;
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool01000Oomoo`003Goo00<007ooOol02Woo00<007ooOol0
0goo00@007ooOol000eoo`<001Aoo`0067oo00<007ooOol02goo00<007ooOol00goo1@004Woo1@00
4Goo0P0000=oo`0000002Woo00<007ooOol017oo0P0000=oo`0000002Woo00<007ooOol02goo00<0
07ooOol01goo00D007ooOomoo`0000eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]o
o`03001oo`0000aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oo`0000aoo`05001oogooOol0
000COol001Qoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo01Aoo`03001oogoo01=oo`03
001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Ioo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03
001oo`0000aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oo`0000aoo`03001oogoo009oo`03
001oogoo011oo`006Goo00<007ooOol02Woo00<007ooOol01Goo0`004Woo1@004Goo0`003Goo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo0P001Goo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol00goo0P0047oo000IOol00`00Oomoo`0;
Ool00`00Oomoo`05Ool00`00Ool0000@Ool01`00Oomoogoo001oo`0000moo`05001oogooOol0000<
Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Oolh0008Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00
Oomoo`0=Ool001Uoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo008000eoo`03001oogoo
009oo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool01@00Oomoogoo00002Goo00<007ooOol02goo00<007ooOol027oo0P00
37oo0`003Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol01Woo0`002Woo00<007ooOol0
1goo00<007ooOol037oo000JOol00`00Oomoo`0;Ool00`00Oomoo`05Ool01@00Oomoogoo00002Woo
0P001Goo00@007ooOomoo`8000Uoo`8000Eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo
00]oo`03001oogoo00]oo`<000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00]oo`05
001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool01@00Oomoogoo
00002Goo00<007ooOol027oo0P0037oo000<OolM0007Ool00`00Oomoo`02Ool20007Ool00`00Oomo
o`06Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomo
o`06Ool00`00Oomoo`0:Ool?000<Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool001Yoo`<000aoo`80
00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Moo`03001oogoo00Qoo`800003Ool0000000Ioo`03001oogoo00Qoo`<000eo
o`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`8000aoo`8000Eoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00Aoo`8000Eoo`03001o
ogoo01Moo`006Goo00D007ooOomoo`0000eoo`03001oogoo00=oo`03001oogoo00Aoo`800003Ool0
000000Yoo`03001oogoo00Aoo`800003Ool0000000Yoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00=oo`03001oogoo00Moo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`0;
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0G
Ool001Uoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Yoo`03001o
ogoo00]oo`05001oogooOol0000=Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Oomoogoo00006Goo000IOol00`00
Oomoo`03Ool2000<Ool20002Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool20009Ool20003Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`0:
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool3000<Ool2000:Ool00`00Oomoo`0;Ool00`00Oomoo`0;
Ool00`00Oomoo`0:Ool01@00Oomoogoo00002goo0`006Woo000HOol00`00Oomoo`06Ool00`00Oomo
o`0;Ool01000Oomoo`0027oo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02Woo00<007oo
Ool00Woo00<007ooOol02goo00@007ooOol000Aoo`03001oogoo00Ioo`03001oogoo00]oo`03001o
ogoo00Yooad000aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`05001oogooOol0
000=Ool00`00Oomoo`0HOol001Qoo`03001oogoo00Moo`03001oogoo00]oo`03001oo`0000Qoo`03
001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Yoo`05001oogooOol0000?Ool00`00Ool00003
Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool2000<Ool3000=Ool00`00Oomoo`0;
Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01000Oomoo`003Goo00<007ooOol0
67oo000HOol00`00Oomoo`08Ool2000<Ool30007Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00
Oomoo`0;Ool3000AOol5000;Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool01@00
Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo
00<007oo00003Goo00<007oo00006Goo000HOol00`00Oomoo`0:Ool?0008Ool00`00Oomoo`0:Ool0
0`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0COol00`00Oomoo`0;Ool00`00Oomoo`0:Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Ool0000=Ool00`00Ool0000IOol0
01Moo`03001oogoo00]oo`03001oogoo00]oo`<000Ioo`03001oogoo00Qoo`800003Ool0000000Io
o`03001oogoo00Qoo`800003Ool00000015oo`<000eoo`03001oogoo00]oo`03001oogoo00=oo`80
00aoo`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00]oo`04001oogoo000IOol001Moo`03001oogoo00Yoo`03001oo`00
00eoo`03001oo`0000Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo00eoo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:OolZ000=
Ool01@00Oomoogoo000067oo000GOol00`00Oomoo`0:Ool00`00Ool0000=Ool01000Oomoo`0017oo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol02goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomoo`00
00eoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Qoo`8000aoo`<000eoo`03001oogoo
00Yoo`<000]oo`05001oogooOol0000HOol001Ioo`03001oogoo00]oo`03001oo`0000eoo`04001o
ogooOol20003Ool00`00Oomoo`03Ool20009Ool20003Ool00`00Oomoo`03Ool20009Ool20009Ool2
0005Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool3000<Ool2000:Ool00`00Oomoo`0;Ool00`00Oomo
o`07Ool00`00Oomoo`0;Ool01@00Oomoogoo00003Goo00<007ooOol02Woo00<007oo00002Goo00<0
07ooOol00Woo00<007ooOol05Woo000FOol00`00Oomoo`0:Ool01@00Oomoogoo00003Goo00<007oo
Ool00Woo00@007ooOol000Aoo`03001oogoo00]oo`04001oogoo0004Ool00`00Oomoo`0;Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0;OolL000<Ool00`00Oomoo`0;Ool00`00Oomoo`06
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool01000Oomoo`00
27oo00<007ooOol00Woo00<007ooOol05Woo000FOol3000:Ool01@00Oomoogoo00003Goo00<007oo
Ool00goo00<007oo00000goo00<007ooOol03Goo00<007oo00000goo00<007ooOol03Goo00<007oo
Ool00goo00<007ooOol01goo00<007ooOol02Goo0P002goo0`003Goo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol00goo0P0037oo0P001Goo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool00P001Woo00<007ooOol00goo00<007ooOol05Goo000GOol00`00Ool00009Ool01@00Oomoogoo
00003Goo00<007ooOol017oo1@004Goo1@004Goo0P0000=oo`0000002Woo00<007ooOol027oo00<0
07ooOol02Woo00D007ooOomoo`0000eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01Eoo`005goo00@007ooOol000Qoo`05001o
ogooOol0000=Ool00`00Oomoo`06Ool00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`0:Ool0
0`00Oomoo`06Ool2000<Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomo
o`0;Ool01@00Oomoogoo00003Goo00<007ooOol01goo00<007ooOol02goo00<007ooOol02Woo00<0
07ooOol00goo00D007ooOomoo`0000Ioo`03001oogoo01Eoo`005goo00@007ooOomoo`8000Eoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00Eoo`<0015oo`D0015oo`<000eoo`03001oogoo
00Aoo`03001oogoo00Yoo`8000Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`<0
00aoo`8000Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`<000Qoo`03001oogoo
01Aoo`0067oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02goo00<0
07ooOol01Woo00<007oo00003goo00L007ooOomoo`00Ool0000?Ool01@00Oomoogoo000037oo00<0
07ooOol00Woo0P0037oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo7@0037oo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol057oo000H
Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo00<007ooOol02goo00<007ooOol01Woo00@007oo
Ool000eoo`03001oogoo009oo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00
Oomoogoo00003Goo00<007ooOol01goo00<007ooOol02goo00<007ooOol027oo0P0037oo0`003Goo
00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol057oo000HOol00`00Oomoo`04Ool30007Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool0
1000Oomoogoo0P002Goo0P001Goo00@007ooOomoo`8000Uoo`8000Eoo`03001oogoo00]oo`<000ao
o`8000]oo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00]oo`05001oogooOol0000=Ool0
0`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`0EOol001Qoo`03001oogoo00Ioo`03001oogoo00Eoo`l000Qoo`03001oogoo009oo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Yoo`l000eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo
009oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo01Eoo`006Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol02goo0`001Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01goo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol01goo00<007ooOol027oo0`003Goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol00goo0P0037oo0P001Goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol05Goo000I
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool01@00Oomoogoo00001Goo00<007oo
Ool017oo0P0000=oo`0000002Woo00<007ooOol017oo0P0000=oo`0000002Woo00<007ooOol01goo
00D007ooOomoo`0000eoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo
00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Yooad000Moo`03001oogoo009oo`03
001oogoo01Ioo`006Goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol0
2Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol0
2Woo00D007ooOomoo`0000eoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Qoo`<000eo
o`03001oogoo00]oo`<000Eoo`03001oogoo009oo`03001oogoo01Ioo`006Woo00<007ooOol01Goo
00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo0P000goo00<007ooOol01Goo00<007oo
Ool02goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol00goo0P001Woo00<007ooOol02Woo
00<007ooOol037oo00<007ooOol02Woo0`0037oo0P002Woo00<007ooOol02goo00<007ooOol01goo
00D007ooOomoo`0000eoo`03001oogoo00]oo`03001oo`0000Eoo`05001oogooOol0000HOol001Yo
o`03001oogoo00Ioo`05001oogooOol0000=Ool00`00Oomoo`06Ool01000Oomoo`0027oo00<007oo
Ool02Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool02goo00<007ooOol02goo700037oo00<007ooOol02goo00<007ooOol01Woo00<007ooOol00Woo
00<007ooOol02goo00<007ooOol02goo00@007ooOol000Aoo`05001oogooOol0000HOol001]oo`80
00Ioo`05001oogooOol0000=Ool00`00Oomoo`07Ool00`00Ool00008Ool00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`0:Ool01@00Oomoogoo00002Goo00<007ooOol02goo00<007ooOol02Goo
0P002goo0`003Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo0P001Goo00<007oo
Ool02goo00<007ooOol02goo00@007ooOomoo`80009oo`04001oogoo000IOol001eoo`03001oogoo
00=oo`05001oogooOol0000=Ool00`00Oomoo`08Ool30007Ool00`00Oomoo`0;Ool00`00Oomoo`05
Ool00`00Oomoo`0;Ool3000;Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool01@00
Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00Woo00<007ooOol01Woo
00<007ooOol02goo00<007ooOol02goo00<007ooOol00Woo00H007ooOol007oo000IOol001ioo`03
001oogoo009oo`05001oogooOol0000=Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0:
Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`06
Ool2000<Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01@00
Oomoogoo00002Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo00D007oo001oo`00
01Uoo`007goo0P000goo00<007oo00003Goo00<007ooOol02goo0`001Woo00<007ooOol027oo0P00
00=oo`0000001Woo00<007ooOol027oo0`003Goo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Woo0P001Goo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo0`002Woo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol017oo0`006Woo000QOol01P00Oomoo`00Ool000eoo`03
001oogoo00Yoo`05001oo`00Ool00005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool01@00Oomoogoo00003Goo00<007ooOol02Woo00<007ooOol00Woo0P0037oo
00<007ooOol01Woo00<007ooOol02goo00<007ooOol02Woo3`0037oo00<007ooOol02goo00<007oo
Ool02goo00<007ooOol01Woo00<007ooOol067oo000ROol01@00Ool007oo00003Goo00<007ooOol0
2Woo00<007oo00000Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomo
o`0000eoo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo00Qoo`<000eoo`03001oogoo00]o
o`03001oogoo00]oo`03001oogoo00]oo`03001oogoo021oo`008goo0`003Goo00<007ooOol02goo
00<007oo00000goo0P000goo00<007ooOol00goo0P002Goo0P000goo00<007ooOol00goo0P001Woo
00<007ooOol02goo00<007ooOol02Woo0`0037oo0P002Woo00<007ooOol02goo00<007ooOol01goo
00D007ooOomoo`0000eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo
021oo`009Goo3`0037oo00D007ooOomoo`0000Aoo`04001oogoo0004Ool00`00Oomoo`0;Ool01000
Oomoo`0017oo00<007ooOol01Woo00<007ooOol02goo700037oo00<007ooOol02goo00<007ooOol0
1Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol087oo000UOol3000<Ool2000:Ool01@00Oomoogoo00001Goo00<007oo00000goo
00<007ooOol03Goo00<007oo00000goo00<007ooOol01goo00<007ooOol02Goo0P002goo0`003Goo
00<007ooOol02goo00<007ooOol02goo00<007ooOol00goo0P001Woo00<007ooOol02Woo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol07goo000VOol00`00Ool0000=Ool0
0`00Oomoo`07Ool01@00Oomoogoo00001Woo1@004Goo1@002goo00<007ooOol01goo00<007ooOol0
2Woo00D007ooOomoo`0000eoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo009oo`03001o
ogoo00Ioo`03001oogoo00]oo`03001oogoo00Yooad0025oo`009Woo00@007ooOol000eoo`03001o
ogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`0COol00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
1@00Oomoogoo00002Goo00<007ooOol02goo00<007ooOol027oo0P0037oo0P0000=oo`000000;Goo
000VOol01000Oomoogoo0P0037oo0P001Goo00<007ooOol00goo00<007ooOol01Goo0P004goo0P00
3Goo00<007ooOol017oo0P002goo0P001Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol0
2goo0`002goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol0:Woo000WOol00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`06Ool3000?Ool20002Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool?000=Ool00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0YOol002Moo`03001oogoo00=o
o`03001oogoo00]oo`05001oogooOol00005Ool00`00Oomoo`06Ool01000Oomoo`003Goo00<007oo
Ool00Woo00<007ooOol02goo00D007ooOomoo`0000aoo`03001oogoo00Moo`03001oogoo00]oo`03
001oogoo00Qoo`<000eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00=oo`8000aoo`80
00Uoo`8002Uoo`009goo00<007ooOol017oo0P0037oo0`001goo00<007ooOol01Goo00D007ooOomo
o`0000]oo`03001oogoo00=oo`03001oogoo00aoo`<000]oo`8000]oo`03001oogoo00Yoo`03001o
ogoo00Moo`05001oogooOol0000=Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0VOol002Moo`03001oogoo00Ioo`l000Moo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00]oo`h0
00eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00]oo`03001oogoo
00]oo`03001oogoo00Yoo`05001oogooOol0000=Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol002Qo
o`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Eoo`8000Moo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Yoo`8000aoo`03001oogoo00]oo`03001oogoo00]o
o`03001oogoo00=oo`8000Ioo`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo00Yoo`<000ao
o`80015oo`8002Eoo`00:7oo00<007ooOol01Woo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool00P001Goo00<007ooOol00goo0P000goo0P002Woo00<007ooOol01goo0P000Woo00<007ooOol0
2Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
2goo00<007ooOol02goo70005Goo00<007ooOol08Woo000XOol00`00Oomoo`06Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool0000<
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool01@00Oomoogoo00002Goo00<007ooOol02goo00<007ooOol02Goo0P002goo0P0000=oo`000000
37oo0P004Goo0P009Goo000YOol00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool3000;Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0=
Ool00`00Oomoo`0UOol002Uoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool>000=Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool2000<Ool0
0`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0VOol002Yoo`03001oogoo
00Eoo`03001oogoo00]oo`05001oogooOol00008Ool01000Oomoo`0027oo00<007ooOol02goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol02Woo0P0037oo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo0P002Goo0P0037oo0P002Goo0P00
:Goo000[Ool20005Ool00`00Oomoo`0;Ool01@00Oomoogoo00002Goo0`0027oo00<007ooOol02goo
00<007ooOol00P002Goo00<007ooOol02goo00<007ooOol01goo0P000Woo00<007ooOol02Woo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol00Woo0P0037oo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol01Goo00<007ooOol0:Goo000]Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00
Oomoogoo00002goo0P001goo00<007ooOol037oo0P002goo00<007ooOol02goo00<007ooOol01Woo
00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Woo00D007ooOomoo`00
00eoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo02Yoo`00;Woo00<0
07ooOol00Woo00<007ooOol02goo00<007oo00003Goo00<007ooOol01Woo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol02Woo00<0
07ooOol037oo00<007ooOol02Woo0`0037oo0P004Goo0P0037oo0P0000=oo`000000;Goo000_Ool0
1@00Oomoogoo00003Goo00<007oo00003Goo0`001Woo00<007ooOol02Goo0`003Goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol017oo00<007ooOol02goo00<007ooOol02goo70005Goo3`00
;goo000`Ool01000Oomoo`003Goo00<007oo000037oo00D007ooOomoo`0000Eoo`03001oogoo00Qo
o`05001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Ool0000COol00`00Oomo
o`0;Ool00`00Oomoo`0^Ool0035oo`<000eoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Ioo`8000Aoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo008000Uo
o`03001oogoo00]oo`03001oogoo00Moo`8000]oo`8000aoo`8000=oo`8000moo`8000aoo`80035o
o`00<goo0P003Goo00<007ooOol02goo00<007ooOol00goo0P000goo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol02goo0P002goo00<007ooOol02goo00<007ooOol01Woo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol02goo
00<007ooOol0<Goo000dOol?000<Ool00`00Oomoo`06Ool01000Oomoo`0017oo0P0027oo00<007oo
Ool02Woo3`003Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol01goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol0<Woo0012Ool3000:Ool0
0`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`08Ool00`00Oomoo`08Ool3000=Ool00`00Oomo
o`0;Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomo
o`09Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`0cOol0045oo`05001oogooOol00009
Ool00`00Oomoo`08Ool5000;Ool00`00Oomoo`07Ool01@00Oomoogoo00003Goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo
00<007ooOol01Goo00<007ooOol02goo00<007ooOol0=7oo0011Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`02000;Ool2000<Ool2000?Ool20003
Ool2000<Ool2000gOol0045oo`03001oogoo00=oo`8000Eoo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00=oo`8000Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`8000ao
o`03001oogoo00]oo`03001oogoo015oo`03001oo`0000eoo`03001oogoo03Moo`00@7oo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol02Woo00<007oo00003Goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol02goo00<007ooOol02Woo:P005Goo3`00>Woo0010Ool00`00Oomoo`07Ool0
1@00Oomoogoo000037oo00<007oo00003Goo00D007ooOomoo`0000Uoo`03001oogoo00]oo`03001o
ogoo00Qoo`8000aoo`8000]oo`D000aoo`80015oo`800003Ool0000004Ioo`00@7oo00<007ooOol0
27oo0`003Goo00@007ooOol000eoo`<000Yoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00]oo`03001oogoo00Yoo`03001oo`0000=oo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo
00=oo`03001oogoo04=oo`00@7oo00<007ooOol02Woo00<007ooOol02Woo00D007ooOomoo`0000eo
o`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Yo
o`04001oogoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`12
Ool003moo`03001oogoo00]oo`<000Yoo`05001oogooOol0000;Ool3000=Ool00`00Oomoo`0;Ool0
0`00Oomoo`03Ool2000<Ool2000;Ool20003Ool00`00Oomoo`03Ool2000<Ool20009Ool20009Ool2
0012Ool003moo`03001oogoo00aoo`03001oo`0000Uoo`03001oogoo009oo`03001oogoo00Moo`05
001oogooOol0000<Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0;
Ool00`00Oomoo`0oOol003moo`03001oogoo00aoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool01@00Oomoogoo00003Goo
00<007ooOol02Woo00<007ooOol00goo00<007ooOol01goo00<007ooOol02goo00<007ooOol00goo
00<007ooOol03Goo00<007ooOol0?Woo000nOol00`00Oomoo`0=Ool01000Oomoogoo0P001Goo00<0
07ooOol00goo00<007ooOol017oo0P001Goo00<007ooOol02goo00<007ooOol02goo0`0037oo0P00
2goo0P001Woo00<007ooOol027oo0P0037oo0P0000=oo`0000004Goo0P00?Woo000nOol00`00Oomo
o`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0:OolZ0008Ool00`00Oomoo`0:Ool?000EOol00`00Oomoo`0kOol004moo`03
001oogoo00=oo`05001oogooOol00006Ool01@00Oomoogoo00002Goo00<007ooOol027oo0P0037oo
0`003Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool0DGoo001?Ool00`00Oomoo`04Ool30008Ool3000:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool0
0`00Ool0000=Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool0
0`00Oomoo`1BOol004moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo
00Ioo`03001oogoo00]oo`04001oogoo000=Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`0:Ool00`00Oomoo`0;Ool00`00Oomoo`1BOol0051oo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00]oo`03001oogoo00=oo`8000aoo`8000=oo`03001oogoo00Yoo`03001oogoo00]oo`03
001oogoo00Eoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo059oo`00D7oo00<007ooOol0
1Woo00<007ooOol017oo00<007oo000037oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol0
0Woo00<007ooOol02goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol0
2goo00<007ooOol0Dgoo001@Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Ool0000<Ool01@00
Oomoogoo00003Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol017oo
0P0000=oo`0000002Woo00<007ooOol02goo00<007ooOol0Dgoo001AOol00`00Oomoo`05Ool00`00
Oomoo`03Ool01000Oomoo`003Goo0`0037oo0P001Woo00<007ooOol02Woo00<007ooOol02goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol01goo00<007ooOol02goo00<007ooOol0Dgoo001A
Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo000037oo3`0027oo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol02goo
00<007ooOol0Dgoo001BOol20006Ool00`00Oomoo`02Ool01@00Oomoogoo00002Woo0`003Goo00<0
07ooOol01Goo00<007ooOol02goo00<007ooOol02Woo00@007ooOomoo`8000Uoo`8000Eoo`03001o
ogoo00]oo`03001oogoo05Aoo`00E7oo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo
00Moo`03001oo`0000eoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00]oo`04001oogoo
000=Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`1DOol005Eoo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`06Ool01000Oomoo`003Goo00<007ooOol01Woo00<007ooOol0
2Woo00<007ooOol02goo00<007oo00003goo00D007ooOomoo`0000eoo`03001oogoo05Aoo`00EWoo
0P000goo00@007ooOol000Eoo`03001oogoo00=oo`8000=oo`03001oogoo00Yoo`03001oogoo00Io
o`03001oogoo00Yoo`03001oogoo00]oo`<0015oo`<000eoo`03001oogoo05Eoo`00F7oo00H007oo
Ool007oo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`06OolL
000EOol?001GOol005Uoo`05001oo`00Ool00006Ool01@00Oomoogoo00001Goo00<007ooOol02goo
00<007ooOol017oo0P002goo1@0037oo0P004Goo0P00IWoo001JOol30008Ool30006Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Ool00003Ool00`00Oomoo`0;Ool00`00Oomo
o`0=Ool00`00Oomoo`1VOol005aoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Yoo`03
001oogoo009oo`8000aoo`04001oogoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomo
o`1WOol006eoo`03001oogoo00]oo`05001oogooOol0000<Ool20003Ool00`00Oomoo`03Ool2000<
Ool20009Ool2001ZOol006eoo`03001oogoo00Yoo`03001oogoo008000aoo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo06Yoo`00KGoo00<007ooOol0
2Woo00<007oo00003Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol02goo00<007ooOol0
0goo00<007ooOol0Jgoo001/Ool00`00Oomoo`0:Ool3000<Ool20006Ool00`00Oomoo`08Ool2000<
Ool200000goo0000001^Ool006aooa`000Qoo`03001oogoo00Yoo`l0071oo`00Sgoo00<007ooOol0
RWoo002?Ool00`00Oomoo`2:Ool008moo`03001oogoo08Yoo`00SWoo00<007ooOol0Rgoo002>Ool0
0`00Oomoo`2;Ool00?mooaeoo`00ogoo7Goo003oOolMOol00?mooaeoo`00ogoo7Goo003oOolMOol0
0001\
\>"],
  ImageRangeCache->{{{0, 283.5}, {286.938, 0}} -> {-10.3915, -10.4577, \
0.072892, 0.072892}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[142]="]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\[AliasDelimiter]\(\
\[AliasDelimiter]\(\[AliasDelimiter]\[AliasDelimiter]\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)], "Input"],

Cell[BoxData[
    \(SaveDat[Union[SphericalCut[QL, 10]], \ "\<test.dat\>"]\)], "Input",
  CellLabel->"In[281]:="]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
CellGrouping->Manual,
WindowSize->{791, 499},
WindowMargins->{{Automatic, -11}, {-14, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{36, 36}, {36, 36}},
"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{"usr", "people", "joseluis", \
"Mathematica"}, "averageDif-octa.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 114, 4, 111, "Title"],

Cell[CellGroupData[{
Cell[1856, 57, 57, 1, 72, "Section"],

Cell[CellGroupData[{
Cell[1938, 62, 87, 1, 27, "Text"],
Cell[2028, 65, 137, 3, 32, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2202, 73, 80, 1, 27, "Text"],
Cell[2285, 76, 89, 2, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2411, 83, 122, 4, 27, "Text"],
Cell[2536, 89, 849, 17, 155, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3422, 111, 197, 5, 27, "Text"],
Cell[3622, 118, 297, 6, 71, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3956, 129, 162, 4, 27, "Text"],
Cell[4121, 135, 628, 11, 71, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4786, 151, 84, 1, 27, "Text"],
Cell[4873, 154, 1092, 20, 151, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6014, 180, 63, 1, 72, "Section"],
Cell[6080, 183, 550, 11, 131, "Input"],

Cell[CellGroupData[{
Cell[6655, 198, 226, 4, 51, "Input"],
Cell[6884, 204, 11377, 324, 296, 2648, 211, "GraphicsData", "PostScript", \
"Graphics"],
Cell[18264, 530, 155, 4, 30, "Output"]
}, Open  ]],
Cell[18434, 537, 132, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[18591, 545, 71, 2, 31, "Input"],
Cell[18665, 549, 1119, 22, 240, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19833, 577, 77, 1, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[19935, 582, 79, 1, 43, "Text"],

Cell[CellGroupData[{
Cell[20039, 587, 532, 11, 54, "DisplayFormula"],
Cell[20574, 600, 224, 5, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20835, 610, 74, 1, 27, "Text"],
Cell[20912, 613, 210, 5, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21159, 623, 68, 1, 27, "Text"],
Cell[21230, 626, 90, 2, 31, "Input"],
Cell[21323, 630, 336, 6, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21696, 641, 70, 1, 27, "Text"],
Cell[21769, 644, 170, 3, 45, "Input"],
Cell[21942, 649, 539, 11, 81, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22518, 665, 195, 5, 27, "Text"],
Cell[22716, 672, 501, 9, 87, "Input"],
Cell[23220, 683, 452, 9, 66, "Input"],
Cell[23675, 694, 552, 10, 87, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24264, 709, 101, 3, 27, "Text"],
Cell[24368, 714, 905, 16, 219, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25322, 736, 60, 1, 43, "Text"],
Cell[25385, 739, 788, 14, 167, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26210, 758, 82, 2, 27, "Text"],
Cell[26295, 762, 2125, 50, 211, "Input"]
}, Open  ]],
Cell[28435, 815, 221, 5, 71, "Input"],

Cell[CellGroupData[{
Cell[28681, 824, 213, 5, 51, "Input"],
Cell[28897, 831, 30752, 711, 305, 6728, 409, "GraphicsData", "PostScript", \
"Graphics"],
Cell[59652, 1544, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59845, 1553, 53, 0, 43, "Subsection"],
Cell[59901, 1555, 1540, 40, 211, "Input"],
Cell[61444, 1597, 1540, 40, 211, "Input"],

Cell[CellGroupData[{
Cell[63009, 1641, 1610, 40, 211, "Input"],
Cell[64622, 1683, 214, 4, 22, "Message"]
}, Open  ]],
Cell[64851, 1690, 413, 7, 91, "Input"],

Cell[CellGroupData[{
Cell[65289, 1701, 188, 4, 31, "Input"],
Cell[65480, 1707, 75946, 2434, 295, 34685, 1919, "GraphicsData", \
"PostScript", "Graphics"],
Cell[141429, 4143, 156, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[141634, 4153, 99, 2, 31, "Input"],
Cell[141736, 4157, 162802, 8704, 296, 86870, 7761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[304541, 12863, 156, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[304724, 12871, 1709, 22, 31, "Input"],
Cell[306436, 12895, 113, 2, 31, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

